from __future__ import annotations

from typing import TYPE_CHECKING, Mapping, cast

from ..atoms import ASCII
from ..common import always, dictget
from .common import BuiltinFont, BuiltinTypeface

if TYPE_CHECKING:  # pragma: no cover
    # The real fonts have huge literal values which slow down type checking.
    # For type checking only, we can substitute them for dummy values.
    helvetica = cast(BuiltinTypeface, object())
    times_roman = cast(BuiltinTypeface, object())
    courier = cast(BuiltinTypeface, object())
    zapf_dingbats = cast(BuiltinTypeface, object())
    symbol = cast(BuiltinTypeface, object())
else:
    helvetica = BuiltinTypeface(
        BuiltinFont(
            b"Helvetica",
            b"f0",
            dictget(
                {
                    " ": 278,
                    "!": 278,
                    '"': 355,
                    "#": 556,
                    "$": 556,
                    "%": 889,
                    "&": 667,
                    "'": 191,
                    "(": 333,
                    ")": 333,
                    "*": 389,
                    "+": 584,
                    ",": 278,
                    "-": 333,
                    ".": 278,
                    "/": 278,
                    "0": 556,
                    "1": 556,
                    "2": 556,
                    "3": 556,
                    "4": 556,
                    "5": 556,
                    "6": 556,
                    "7": 556,
                    "8": 556,
                    "9": 556,
                    ":": 278,
                    ";": 278,
                    "<": 584,
                    "=": 584,
                    ">": 584,
                    "?": 556,
                    "@": 1015,
                    "A": 667,
                    "B": 667,
                    "C": 722,
                    "D": 722,
                    "E": 667,
                    "F": 611,
                    "G": 778,
                    "H": 722,
                    "I": 278,
                    "J": 500,
                    "K": 667,
                    "L": 556,
                    "M": 833,
                    "N": 722,
                    "O": 778,
                    "P": 667,
                    "Q": 778,
                    "R": 722,
                    "S": 667,
                    "T": 611,
                    "U": 722,
                    "V": 667,
                    "W": 944,
                    "X": 667,
                    "Y": 667,
                    "Z": 611,
                    "[": 278,
                    "\\": 278,
                    "]": 278,
                    "^": 469,
                    "_": 556,
                    "`": 333,
                    "a": 556,
                    "b": 556,
                    "c": 500,
                    "d": 556,
                    "e": 556,
                    "f": 278,
                    "g": 556,
                    "h": 556,
                    "i": 222,
                    "j": 222,
                    "k": 500,
                    "l": 222,
                    "m": 833,
                    "n": 556,
                    "o": 556,
                    "p": 556,
                    "q": 556,
                    "r": 333,
                    "s": 500,
                    "t": 278,
                    "u": 556,
                    "v": 500,
                    "w": 722,
                    "x": 500,
                    "y": 500,
                    "z": 500,
                    "{": 334,
                    "|": 260,
                    "}": 334,
                    "~": 584,
                    "¡": 333,
                    "¢": 556,
                    "£": 556,
                    "¤": 556,
                    "¥": 556,
                    "¦": 260,
                    "§": 556,
                    "©": 737,
                    "ª": 370,
                    "«": 556,
                    "¬": 584,
                    "®": 737,
                    "°": 400,
                    "±": 584,
                    "²": 333,
                    "³": 333,
                    "¶": 537,
                    "·": 278,
                    "¹": 333,
                    "º": 365,
                    "»": 556,
                    "¼": 834,
                    "½": 834,
                    "¾": 834,
                    "¿": 611,
                    "À": 667,
                    "Á": 667,
                    "Â": 667,
                    "Ã": 667,
                    "Ä": 667,
                    "Å": 667,
                    "Æ": 1000,
                    "Ç": 722,
                    "È": 667,
                    "É": 667,
                    "Ê": 667,
                    "Ë": 667,
                    "Ì": 278,
                    "Í": 278,
                    "Î": 278,
                    "Ï": 278,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 778,
                    "Ó": 778,
                    "Ô": 778,
                    "Õ": 778,
                    "Ö": 778,
                    "×": 584,
                    "Ø": 778,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 667,
                    "Þ": 667,
                    "ß": 611,
                    "à": 556,
                    "á": 556,
                    "â": 556,
                    "ã": 556,
                    "ä": 556,
                    "å": 556,
                    "æ": 889,
                    "ç": 500,
                    "è": 556,
                    "é": 556,
                    "ê": 556,
                    "ë": 556,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 556,
                    "ñ": 556,
                    "ò": 556,
                    "ó": 556,
                    "ô": 556,
                    "õ": 556,
                    "ö": 556,
                    "÷": 584,
                    "ø": 611,
                    "ù": 556,
                    "ú": 556,
                    "û": 556,
                    "ü": 556,
                    "ý": 500,
                    "þ": 556,
                    "ÿ": 500,
                    "ı": 278,
                    "Ł": 556,
                    "ł": 222,
                    "Œ": 1000,
                    "œ": 944,
                    "Š": 667,
                    "š": 500,
                    "Ÿ": 667,
                    "Ž": 611,
                    "ž": 500,
                    "ƒ": 556,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 556,
                    "–": 556,
                    "—": 1000,
                    "‘": 222,
                    "’": 222,
                    "‚": 222,
                    "“": 333,
                    "”": 333,
                    "„": 333,
                    "†": 556,
                    "‡": 556,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 556,
                    "™": 1000,
                    "−": 584,
                    "ﬁ": 500,
                    "ﬂ": 500,
                },
                556,
            ),
            dictget(
                {
                    (" ", "T"): -50,
                    (" ", "V"): -50,
                    (" ", "W"): -40,
                    (" ", "Y"): -90,
                    (" ", "Ý"): -90,
                    (" ", "Ÿ"): -90,
                    (" ", "‘"): -60,
                    (" ", "“"): -30,
                    (",", "’"): -100,
                    (",", "”"): -100,
                    (".", " "): -60,
                    (".", "’"): -100,
                    (".", "”"): -100,
                    (":", " "): -50,
                    (";", " "): -50,
                    ("A", "C"): -30,
                    ("A", "G"): -30,
                    ("A", "O"): -30,
                    ("A", "Q"): -30,
                    ("A", "T"): -120,
                    ("A", "U"): -50,
                    ("A", "V"): -70,
                    ("A", "W"): -50,
                    ("A", "Y"): -100,
                    ("A", "u"): -30,
                    ("A", "v"): -40,
                    ("A", "w"): -40,
                    ("A", "y"): -40,
                    ("A", "Ç"): -30,
                    ("A", "Ò"): -30,
                    ("A", "Ó"): -30,
                    ("A", "Ô"): -30,
                    ("A", "Õ"): -30,
                    ("A", "Ö"): -30,
                    ("A", "Ø"): -30,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -100,
                    ("A", "ù"): -30,
                    ("A", "ú"): -30,
                    ("A", "û"): -30,
                    ("A", "ü"): -30,
                    ("A", "ý"): -40,
                    ("A", "ÿ"): -40,
                    ("A", "Ÿ"): -100,
                    ("B", ","): -20,
                    ("B", "."): -20,
                    ("B", "U"): -10,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("C", ","): -30,
                    ("C", "."): -30,
                    ("D", ","): -70,
                    ("D", "."): -70,
                    ("D", "A"): -40,
                    ("D", "V"): -70,
                    ("D", "W"): -40,
                    ("D", "Y"): -90,
                    ("D", "À"): -40,
                    ("D", "Á"): -40,
                    ("D", "Â"): -40,
                    ("D", "Ã"): -40,
                    ("D", "Ä"): -40,
                    ("D", "Å"): -40,
                    ("D", "Ý"): -90,
                    ("D", "Ÿ"): -90,
                    ("F", ","): -150,
                    ("F", "."): -150,
                    ("F", "A"): -80,
                    ("F", "a"): -50,
                    ("F", "e"): -30,
                    ("F", "o"): -30,
                    ("F", "r"): -45,
                    ("F", "À"): -80,
                    ("F", "Á"): -80,
                    ("F", "Â"): -80,
                    ("F", "Ã"): -80,
                    ("F", "Ä"): -80,
                    ("F", "Å"): -80,
                    ("F", "à"): -50,
                    ("F", "á"): -50,
                    ("F", "â"): -50,
                    ("F", "ã"): -50,
                    ("F", "ä"): -50,
                    ("F", "å"): -50,
                    ("F", "è"): -30,
                    ("F", "é"): -30,
                    ("F", "ê"): -30,
                    ("F", "ë"): -30,
                    ("F", "ò"): -30,
                    ("F", "ó"): -30,
                    ("F", "ô"): -30,
                    ("F", "õ"): -30,
                    ("F", "ö"): -30,
                    ("F", "ø"): -30,
                    ("J", ","): -30,
                    ("J", "."): -30,
                    ("J", "A"): -20,
                    ("J", "a"): -20,
                    ("J", "u"): -20,
                    ("J", "À"): -20,
                    ("J", "Á"): -20,
                    ("J", "Â"): -20,
                    ("J", "Ã"): -20,
                    ("J", "Ä"): -20,
                    ("J", "Å"): -20,
                    ("J", "à"): -20,
                    ("J", "á"): -20,
                    ("J", "â"): -20,
                    ("J", "ã"): -20,
                    ("J", "ä"): -20,
                    ("J", "å"): -20,
                    ("J", "ù"): -20,
                    ("J", "ú"): -20,
                    ("J", "û"): -20,
                    ("J", "ü"): -20,
                    ("K", "O"): -50,
                    ("K", "e"): -40,
                    ("K", "o"): -40,
                    ("K", "u"): -30,
                    ("K", "y"): -50,
                    ("K", "Ò"): -50,
                    ("K", "Ó"): -50,
                    ("K", "Ô"): -50,
                    ("K", "Õ"): -50,
                    ("K", "Ö"): -50,
                    ("K", "Ø"): -50,
                    ("K", "è"): -40,
                    ("K", "é"): -40,
                    ("K", "ê"): -40,
                    ("K", "ë"): -40,
                    ("K", "ò"): -40,
                    ("K", "ó"): -40,
                    ("K", "ô"): -40,
                    ("K", "õ"): -40,
                    ("K", "ö"): -40,
                    ("K", "ø"): -40,
                    ("K", "ù"): -30,
                    ("K", "ú"): -30,
                    ("K", "û"): -30,
                    ("K", "ü"): -30,
                    ("K", "ý"): -50,
                    ("K", "ÿ"): -50,
                    ("L", "T"): -110,
                    ("L", "V"): -110,
                    ("L", "W"): -70,
                    ("L", "Y"): -140,
                    ("L", "y"): -30,
                    ("L", "Ý"): -140,
                    ("L", "ý"): -30,
                    ("L", "ÿ"): -30,
                    ("L", "Ÿ"): -140,
                    ("L", "’"): -160,
                    ("L", "”"): -140,
                    ("O", ","): -40,
                    ("O", "."): -40,
                    ("O", "A"): -20,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -30,
                    ("O", "X"): -60,
                    ("O", "Y"): -70,
                    ("O", "À"): -20,
                    ("O", "Á"): -20,
                    ("O", "Â"): -20,
                    ("O", "Ã"): -20,
                    ("O", "Ä"): -20,
                    ("O", "Å"): -20,
                    ("O", "Ý"): -70,
                    ("O", "Ÿ"): -70,
                    ("P", ","): -180,
                    ("P", "."): -180,
                    ("P", "A"): -120,
                    ("P", "a"): -40,
                    ("P", "e"): -50,
                    ("P", "o"): -50,
                    ("P", "À"): -120,
                    ("P", "Á"): -120,
                    ("P", "Â"): -120,
                    ("P", "Ã"): -120,
                    ("P", "Ä"): -120,
                    ("P", "Å"): -120,
                    ("P", "à"): -40,
                    ("P", "á"): -40,
                    ("P", "â"): -40,
                    ("P", "ã"): -40,
                    ("P", "ä"): -40,
                    ("P", "å"): -40,
                    ("P", "è"): -50,
                    ("P", "é"): -50,
                    ("P", "ê"): -50,
                    ("P", "ë"): -50,
                    ("P", "ò"): -50,
                    ("P", "ó"): -50,
                    ("P", "ô"): -50,
                    ("P", "õ"): -50,
                    ("P", "ö"): -50,
                    ("P", "ø"): -50,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -20,
                    ("R", "T"): -30,
                    ("R", "U"): -40,
                    ("R", "V"): -50,
                    ("R", "W"): -30,
                    ("R", "Y"): -50,
                    ("R", "Ò"): -20,
                    ("R", "Ó"): -20,
                    ("R", "Ô"): -20,
                    ("R", "Õ"): -20,
                    ("R", "Ö"): -20,
                    ("R", "Ø"): -20,
                    ("R", "Ù"): -40,
                    ("R", "Ú"): -40,
                    ("R", "Û"): -40,
                    ("R", "Ü"): -40,
                    ("R", "Ý"): -50,
                    ("R", "Ÿ"): -50,
                    ("S", ","): -20,
                    ("S", "."): -20,
                    ("T", ","): -120,
                    ("T", "-"): -140,
                    ("T", "."): -120,
                    ("T", ":"): -20,
                    ("T", ";"): -20,
                    ("T", "A"): -120,
                    ("T", "O"): -40,
                    ("T", "a"): -120,
                    ("T", "e"): -120,
                    ("T", "o"): -120,
                    ("T", "r"): -120,
                    ("T", "u"): -120,
                    ("T", "w"): -120,
                    ("T", "y"): -120,
                    ("T", "À"): -120,
                    ("T", "Á"): -120,
                    ("T", "Â"): -120,
                    ("T", "Ã"): -120,
                    ("T", "Ä"): -120,
                    ("T", "Å"): -120,
                    ("T", "Ò"): -40,
                    ("T", "Ó"): -40,
                    ("T", "Ô"): -40,
                    ("T", "Õ"): -40,
                    ("T", "Ö"): -40,
                    ("T", "Ø"): -40,
                    ("T", "à"): -120,
                    ("T", "á"): -120,
                    ("T", "â"): -120,
                    ("T", "ã"): -60,
                    ("T", "ä"): -120,
                    ("T", "å"): -120,
                    ("T", "è"): -60,
                    ("T", "é"): -120,
                    ("T", "ê"): -120,
                    ("T", "ë"): -120,
                    ("T", "ò"): -120,
                    ("T", "ó"): -120,
                    ("T", "ô"): -120,
                    ("T", "õ"): -60,
                    ("T", "ö"): -120,
                    ("T", "ø"): -120,
                    ("T", "ù"): -120,
                    ("T", "ú"): -120,
                    ("T", "û"): -120,
                    ("T", "ü"): -120,
                    ("T", "ý"): -120,
                    ("T", "ÿ"): -60,
                    ("U", ","): -40,
                    ("U", "."): -40,
                    ("U", "A"): -40,
                    ("U", "À"): -40,
                    ("U", "Á"): -40,
                    ("U", "Â"): -40,
                    ("U", "Ã"): -40,
                    ("U", "Ä"): -40,
                    ("U", "Å"): -40,
                    ("V", ","): -125,
                    ("V", "-"): -80,
                    ("V", "."): -125,
                    ("V", ":"): -40,
                    ("V", ";"): -40,
                    ("V", "A"): -80,
                    ("V", "G"): -40,
                    ("V", "O"): -40,
                    ("V", "a"): -70,
                    ("V", "e"): -80,
                    ("V", "o"): -80,
                    ("V", "u"): -70,
                    ("V", "À"): -80,
                    ("V", "Á"): -80,
                    ("V", "Â"): -80,
                    ("V", "Ã"): -80,
                    ("V", "Ä"): -80,
                    ("V", "Å"): -80,
                    ("V", "Ò"): -40,
                    ("V", "Ó"): -40,
                    ("V", "Ô"): -40,
                    ("V", "Õ"): -40,
                    ("V", "Ö"): -40,
                    ("V", "Ø"): -40,
                    ("V", "à"): -70,
                    ("V", "á"): -70,
                    ("V", "â"): -70,
                    ("V", "ã"): -70,
                    ("V", "ä"): -70,
                    ("V", "å"): -70,
                    ("V", "è"): -80,
                    ("V", "é"): -80,
                    ("V", "ê"): -80,
                    ("V", "ë"): -80,
                    ("V", "ò"): -80,
                    ("V", "ó"): -80,
                    ("V", "ô"): -80,
                    ("V", "õ"): -80,
                    ("V", "ö"): -80,
                    ("V", "ø"): -80,
                    ("V", "ù"): -70,
                    ("V", "ú"): -70,
                    ("V", "û"): -70,
                    ("V", "ü"): -70,
                    ("W", ","): -80,
                    ("W", "-"): -40,
                    ("W", "."): -80,
                    ("W", "A"): -50,
                    ("W", "O"): -20,
                    ("W", "a"): -40,
                    ("W", "e"): -30,
                    ("W", "o"): -30,
                    ("W", "u"): -30,
                    ("W", "y"): -20,
                    ("W", "À"): -50,
                    ("W", "Á"): -50,
                    ("W", "Â"): -50,
                    ("W", "Ã"): -50,
                    ("W", "Ä"): -50,
                    ("W", "Å"): -50,
                    ("W", "Ò"): -20,
                    ("W", "Ó"): -20,
                    ("W", "Ô"): -20,
                    ("W", "Õ"): -20,
                    ("W", "Ö"): -20,
                    ("W", "Ø"): -20,
                    ("W", "à"): -40,
                    ("W", "á"): -40,
                    ("W", "â"): -40,
                    ("W", "ã"): -40,
                    ("W", "ä"): -40,
                    ("W", "å"): -40,
                    ("W", "è"): -30,
                    ("W", "é"): -30,
                    ("W", "ê"): -30,
                    ("W", "ë"): -30,
                    ("W", "ò"): -30,
                    ("W", "ó"): -30,
                    ("W", "ô"): -30,
                    ("W", "õ"): -30,
                    ("W", "ö"): -30,
                    ("W", "ø"): -30,
                    ("W", "ù"): -30,
                    ("W", "ú"): -30,
                    ("W", "û"): -30,
                    ("W", "ü"): -30,
                    ("W", "ý"): -20,
                    ("W", "ÿ"): -20,
                    ("Y", ","): -140,
                    ("Y", "-"): -140,
                    ("Y", "."): -140,
                    ("Y", ":"): -60,
                    ("Y", ";"): -60,
                    ("Y", "A"): -110,
                    ("Y", "O"): -85,
                    ("Y", "a"): -140,
                    ("Y", "e"): -140,
                    ("Y", "i"): -20,
                    ("Y", "o"): -140,
                    ("Y", "u"): -110,
                    ("Y", "À"): -110,
                    ("Y", "Á"): -110,
                    ("Y", "Â"): -110,
                    ("Y", "Ã"): -110,
                    ("Y", "Ä"): -110,
                    ("Y", "Å"): -110,
                    ("Y", "Ò"): -85,
                    ("Y", "Ó"): -85,
                    ("Y", "Ô"): -85,
                    ("Y", "Õ"): -85,
                    ("Y", "Ö"): -85,
                    ("Y", "Ø"): -85,
                    ("Y", "à"): -140,
                    ("Y", "á"): -140,
                    ("Y", "â"): -140,
                    ("Y", "ã"): -140,
                    ("Y", "ä"): -140,
                    ("Y", "å"): -140,
                    ("Y", "è"): -140,
                    ("Y", "é"): -140,
                    ("Y", "ê"): -140,
                    ("Y", "ë"): -140,
                    ("Y", "í"): -20,
                    ("Y", "ò"): -140,
                    ("Y", "ó"): -140,
                    ("Y", "ô"): -140,
                    ("Y", "õ"): -140,
                    ("Y", "ö"): -140,
                    ("Y", "ø"): -140,
                    ("Y", "ù"): -110,
                    ("Y", "ú"): -110,
                    ("Y", "û"): -110,
                    ("Y", "ü"): -110,
                    ("a", "v"): -20,
                    ("a", "w"): -20,
                    ("a", "y"): -30,
                    ("a", "ý"): -30,
                    ("a", "ÿ"): -30,
                    ("b", ","): -40,
                    ("b", "."): -40,
                    ("b", "b"): -10,
                    ("b", "l"): -20,
                    ("b", "u"): -20,
                    ("b", "v"): -20,
                    ("b", "y"): -20,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("b", "ý"): -20,
                    ("b", "ÿ"): -20,
                    ("b", "ł"): -20,
                    ("c", ","): -15,
                    ("c", "k"): -20,
                    ("e", ","): -15,
                    ("e", "."): -15,
                    ("e", "v"): -30,
                    ("e", "w"): -20,
                    ("e", "x"): -30,
                    ("e", "y"): -20,
                    ("e", "ý"): -20,
                    ("e", "ÿ"): -20,
                    ("f", ","): -30,
                    ("f", "."): -30,
                    ("f", "a"): -30,
                    ("f", "e"): -30,
                    ("f", "o"): -30,
                    ("f", "à"): -30,
                    ("f", "á"): -30,
                    ("f", "â"): -30,
                    ("f", "ã"): -30,
                    ("f", "ä"): -30,
                    ("f", "å"): -30,
                    ("f", "è"): -30,
                    ("f", "é"): -30,
                    ("f", "ê"): -30,
                    ("f", "ë"): -30,
                    ("f", "ò"): -30,
                    ("f", "ó"): -30,
                    ("f", "ô"): -30,
                    ("f", "õ"): -30,
                    ("f", "ö"): -30,
                    ("f", "ø"): -30,
                    ("f", "ı"): -28,
                    ("f", "’"): 50,
                    ("f", "”"): 60,
                    ("g", "r"): -10,
                    ("h", "y"): -30,
                    ("h", "ý"): -30,
                    ("h", "ÿ"): -30,
                    ("k", "e"): -20,
                    ("k", "o"): -20,
                    ("k", "è"): -20,
                    ("k", "é"): -20,
                    ("k", "ê"): -20,
                    ("k", "ë"): -20,
                    ("k", "ò"): -20,
                    ("k", "ó"): -20,
                    ("k", "ô"): -20,
                    ("k", "õ"): -20,
                    ("k", "ö"): -20,
                    ("k", "ø"): -20,
                    ("m", "u"): -10,
                    ("m", "y"): -15,
                    ("m", "ù"): -10,
                    ("m", "ú"): -10,
                    ("m", "û"): -10,
                    ("m", "ü"): -10,
                    ("m", "ý"): -15,
                    ("m", "ÿ"): -15,
                    ("n", "u"): -10,
                    ("n", "v"): -20,
                    ("n", "y"): -15,
                    ("n", "ù"): -10,
                    ("n", "ú"): -10,
                    ("n", "û"): -10,
                    ("n", "ü"): -10,
                    ("n", "ý"): -15,
                    ("n", "ÿ"): -15,
                    ("o", ","): -40,
                    ("o", "."): -40,
                    ("o", "v"): -15,
                    ("o", "w"): -15,
                    ("o", "x"): -30,
                    ("o", "y"): -30,
                    ("o", "ý"): -30,
                    ("o", "ÿ"): -30,
                    ("p", ","): -35,
                    ("p", "."): -35,
                    ("p", "y"): -30,
                    ("p", "ý"): -30,
                    ("p", "ÿ"): -30,
                    ("r", ","): -50,
                    ("r", "."): -50,
                    ("r", ":"): 30,
                    ("r", ";"): 30,
                    ("r", "a"): -10,
                    ("r", "i"): 15,
                    ("r", "k"): 15,
                    ("r", "l"): 15,
                    ("r", "m"): 25,
                    ("r", "n"): 25,
                    ("r", "p"): 30,
                    ("r", "t"): 40,
                    ("r", "u"): 15,
                    ("r", "v"): 30,
                    ("r", "y"): 30,
                    ("r", "à"): -10,
                    ("r", "á"): -10,
                    ("r", "â"): -10,
                    ("r", "ã"): -10,
                    ("r", "ä"): -10,
                    ("r", "å"): -10,
                    ("r", "ì"): 15,
                    ("r", "í"): 15,
                    ("r", "î"): 15,
                    ("r", "ï"): 15,
                    ("r", "ñ"): 25,
                    ("r", "ù"): 15,
                    ("r", "ú"): 15,
                    ("r", "û"): 15,
                    ("r", "ü"): 15,
                    ("r", "ý"): 30,
                    ("r", "ÿ"): 30,
                    ("r", "ł"): 15,
                    ("s", ","): -15,
                    ("s", "."): -15,
                    ("s", "w"): -30,
                    ("v", ","): -80,
                    ("v", "."): -80,
                    ("v", "a"): -25,
                    ("v", "e"): -25,
                    ("v", "o"): -25,
                    ("v", "à"): -25,
                    ("v", "á"): -25,
                    ("v", "â"): -25,
                    ("v", "ã"): -25,
                    ("v", "ä"): -25,
                    ("v", "å"): -25,
                    ("v", "è"): -25,
                    ("v", "é"): -25,
                    ("v", "ê"): -25,
                    ("v", "ë"): -25,
                    ("v", "ò"): -25,
                    ("v", "ó"): -25,
                    ("v", "ô"): -25,
                    ("v", "õ"): -25,
                    ("v", "ö"): -25,
                    ("v", "ø"): -25,
                    ("w", ","): -60,
                    ("w", "."): -60,
                    ("w", "a"): -15,
                    ("w", "e"): -10,
                    ("w", "o"): -10,
                    ("w", "à"): -15,
                    ("w", "á"): -15,
                    ("w", "â"): -15,
                    ("w", "ã"): -15,
                    ("w", "ä"): -15,
                    ("w", "å"): -15,
                    ("w", "è"): -10,
                    ("w", "é"): -10,
                    ("w", "ê"): -10,
                    ("w", "ë"): -10,
                    ("w", "ò"): -10,
                    ("w", "ó"): -10,
                    ("w", "ô"): -10,
                    ("w", "õ"): -10,
                    ("w", "ö"): -10,
                    ("w", "ø"): -10,
                    ("x", "e"): -30,
                    ("x", "è"): -30,
                    ("x", "é"): -30,
                    ("x", "ê"): -30,
                    ("x", "ë"): -30,
                    ("y", ","): -100,
                    ("y", "."): -100,
                    ("y", "a"): -20,
                    ("y", "e"): -20,
                    ("y", "o"): -20,
                    ("y", "à"): -20,
                    ("y", "á"): -20,
                    ("y", "â"): -20,
                    ("y", "ã"): -20,
                    ("y", "ä"): -20,
                    ("y", "å"): -20,
                    ("y", "è"): -20,
                    ("y", "é"): -20,
                    ("y", "ê"): -20,
                    ("y", "ë"): -20,
                    ("y", "ò"): -20,
                    ("y", "ó"): -20,
                    ("y", "ô"): -20,
                    ("y", "õ"): -20,
                    ("y", "ö"): -20,
                    ("y", "ø"): -20,
                    ("z", "e"): -15,
                    ("z", "o"): -15,
                    ("z", "è"): -15,
                    ("z", "é"): -15,
                    ("z", "ê"): -15,
                    ("z", "ë"): -15,
                    ("z", "ò"): -15,
                    ("z", "ó"): -15,
                    ("z", "ô"): -15,
                    ("z", "õ"): -15,
                    ("z", "ö"): -15,
                    ("z", "ø"): -15,
                    ("À", "C"): -30,
                    ("À", "G"): -30,
                    ("À", "O"): -30,
                    ("À", "Q"): -30,
                    ("À", "T"): -120,
                    ("À", "U"): -50,
                    ("À", "V"): -70,
                    ("À", "W"): -50,
                    ("À", "Y"): -100,
                    ("À", "u"): -30,
                    ("À", "v"): -40,
                    ("À", "w"): -40,
                    ("À", "y"): -40,
                    ("À", "Ç"): -30,
                    ("À", "Ò"): -30,
                    ("À", "Ó"): -30,
                    ("À", "Ô"): -30,
                    ("À", "Õ"): -30,
                    ("À", "Ö"): -30,
                    ("À", "Ø"): -30,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -100,
                    ("À", "ù"): -30,
                    ("À", "ú"): -30,
                    ("À", "û"): -30,
                    ("À", "ü"): -30,
                    ("À", "ý"): -40,
                    ("À", "ÿ"): -40,
                    ("À", "Ÿ"): -100,
                    ("Á", "C"): -30,
                    ("Á", "G"): -30,
                    ("Á", "O"): -30,
                    ("Á", "Q"): -30,
                    ("Á", "T"): -120,
                    ("Á", "U"): -50,
                    ("Á", "V"): -70,
                    ("Á", "W"): -50,
                    ("Á", "Y"): -100,
                    ("Á", "u"): -30,
                    ("Á", "v"): -40,
                    ("Á", "w"): -40,
                    ("Á", "y"): -40,
                    ("Á", "Ç"): -30,
                    ("Á", "Ò"): -30,
                    ("Á", "Ó"): -30,
                    ("Á", "Ô"): -30,
                    ("Á", "Õ"): -30,
                    ("Á", "Ö"): -30,
                    ("Á", "Ø"): -30,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -100,
                    ("Á", "ù"): -30,
                    ("Á", "ú"): -30,
                    ("Á", "û"): -30,
                    ("Á", "ü"): -30,
                    ("Á", "ý"): -40,
                    ("Á", "ÿ"): -40,
                    ("Á", "Ÿ"): -100,
                    ("Â", "C"): -30,
                    ("Â", "G"): -30,
                    ("Â", "O"): -30,
                    ("Â", "Q"): -30,
                    ("Â", "T"): -120,
                    ("Â", "U"): -50,
                    ("Â", "V"): -70,
                    ("Â", "W"): -50,
                    ("Â", "Y"): -100,
                    ("Â", "u"): -30,
                    ("Â", "v"): -40,
                    ("Â", "w"): -40,
                    ("Â", "y"): -40,
                    ("Â", "Ç"): -30,
                    ("Â", "Ò"): -30,
                    ("Â", "Ó"): -30,
                    ("Â", "Ô"): -30,
                    ("Â", "Õ"): -30,
                    ("Â", "Ö"): -30,
                    ("Â", "Ø"): -30,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -100,
                    ("Â", "ù"): -30,
                    ("Â", "ú"): -30,
                    ("Â", "û"): -30,
                    ("Â", "ü"): -30,
                    ("Â", "ý"): -40,
                    ("Â", "ÿ"): -40,
                    ("Â", "Ÿ"): -100,
                    ("Ã", "C"): -30,
                    ("Ã", "G"): -30,
                    ("Ã", "O"): -30,
                    ("Ã", "Q"): -30,
                    ("Ã", "T"): -120,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -70,
                    ("Ã", "W"): -50,
                    ("Ã", "Y"): -100,
                    ("Ã", "u"): -30,
                    ("Ã", "v"): -40,
                    ("Ã", "w"): -40,
                    ("Ã", "y"): -40,
                    ("Ã", "Ç"): -30,
                    ("Ã", "Ò"): -30,
                    ("Ã", "Ó"): -30,
                    ("Ã", "Ô"): -30,
                    ("Ã", "Õ"): -30,
                    ("Ã", "Ö"): -30,
                    ("Ã", "Ø"): -30,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -100,
                    ("Ã", "ù"): -30,
                    ("Ã", "ú"): -30,
                    ("Ã", "û"): -30,
                    ("Ã", "ü"): -30,
                    ("Ã", "ý"): -40,
                    ("Ã", "ÿ"): -40,
                    ("Ã", "Ÿ"): -100,
                    ("Ä", "C"): -30,
                    ("Ä", "G"): -30,
                    ("Ä", "O"): -30,
                    ("Ä", "Q"): -30,
                    ("Ä", "T"): -120,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -70,
                    ("Ä", "W"): -50,
                    ("Ä", "Y"): -100,
                    ("Ä", "u"): -30,
                    ("Ä", "v"): -40,
                    ("Ä", "w"): -40,
                    ("Ä", "y"): -40,
                    ("Ä", "Ç"): -30,
                    ("Ä", "Ò"): -30,
                    ("Ä", "Ó"): -30,
                    ("Ä", "Ô"): -30,
                    ("Ä", "Õ"): -30,
                    ("Ä", "Ö"): -30,
                    ("Ä", "Ø"): -30,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -100,
                    ("Ä", "ù"): -30,
                    ("Ä", "ú"): -30,
                    ("Ä", "û"): -30,
                    ("Ä", "ü"): -30,
                    ("Ä", "ý"): -40,
                    ("Ä", "ÿ"): -40,
                    ("Ä", "Ÿ"): -100,
                    ("Å", "C"): -30,
                    ("Å", "G"): -30,
                    ("Å", "O"): -30,
                    ("Å", "Q"): -30,
                    ("Å", "T"): -120,
                    ("Å", "U"): -50,
                    ("Å", "V"): -70,
                    ("Å", "W"): -50,
                    ("Å", "Y"): -100,
                    ("Å", "u"): -30,
                    ("Å", "v"): -40,
                    ("Å", "w"): -40,
                    ("Å", "y"): -40,
                    ("Å", "Ç"): -30,
                    ("Å", "Ò"): -30,
                    ("Å", "Ó"): -30,
                    ("Å", "Ô"): -30,
                    ("Å", "Õ"): -30,
                    ("Å", "Ö"): -30,
                    ("Å", "Ø"): -30,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -100,
                    ("Å", "ù"): -30,
                    ("Å", "ú"): -30,
                    ("Å", "û"): -30,
                    ("Å", "ü"): -30,
                    ("Å", "ý"): -40,
                    ("Å", "ÿ"): -40,
                    ("Å", "Ÿ"): -100,
                    ("Ç", ","): -30,
                    ("Ç", "."): -30,
                    ("Ò", ","): -40,
                    ("Ò", "."): -40,
                    ("Ò", "A"): -20,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -30,
                    ("Ò", "X"): -60,
                    ("Ò", "Y"): -70,
                    ("Ò", "À"): -20,
                    ("Ò", "Á"): -20,
                    ("Ò", "Â"): -20,
                    ("Ò", "Ã"): -20,
                    ("Ò", "Ä"): -20,
                    ("Ò", "Å"): -20,
                    ("Ò", "Ý"): -70,
                    ("Ò", "Ÿ"): -70,
                    ("Ó", ","): -40,
                    ("Ó", "."): -40,
                    ("Ó", "A"): -20,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -30,
                    ("Ó", "X"): -60,
                    ("Ó", "Y"): -70,
                    ("Ó", "À"): -20,
                    ("Ó", "Á"): -20,
                    ("Ó", "Â"): -20,
                    ("Ó", "Ã"): -20,
                    ("Ó", "Ä"): -20,
                    ("Ó", "Å"): -20,
                    ("Ó", "Ý"): -70,
                    ("Ó", "Ÿ"): -70,
                    ("Ô", ","): -40,
                    ("Ô", "."): -40,
                    ("Ô", "A"): -20,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -30,
                    ("Ô", "X"): -60,
                    ("Ô", "Y"): -70,
                    ("Ô", "À"): -20,
                    ("Ô", "Á"): -20,
                    ("Ô", "Â"): -20,
                    ("Ô", "Ã"): -20,
                    ("Ô", "Ä"): -20,
                    ("Ô", "Å"): -20,
                    ("Ô", "Ý"): -70,
                    ("Ô", "Ÿ"): -70,
                    ("Õ", ","): -40,
                    ("Õ", "."): -40,
                    ("Õ", "A"): -20,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -30,
                    ("Õ", "X"): -60,
                    ("Õ", "Y"): -70,
                    ("Õ", "À"): -20,
                    ("Õ", "Á"): -20,
                    ("Õ", "Â"): -20,
                    ("Õ", "Ã"): -20,
                    ("Õ", "Ä"): -20,
                    ("Õ", "Å"): -20,
                    ("Õ", "Ý"): -70,
                    ("Õ", "Ÿ"): -70,
                    ("Ö", ","): -40,
                    ("Ö", "."): -40,
                    ("Ö", "A"): -20,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -30,
                    ("Ö", "X"): -60,
                    ("Ö", "Y"): -70,
                    ("Ö", "À"): -20,
                    ("Ö", "Á"): -20,
                    ("Ö", "Â"): -20,
                    ("Ö", "Ã"): -20,
                    ("Ö", "Ä"): -20,
                    ("Ö", "Å"): -20,
                    ("Ö", "Ý"): -70,
                    ("Ö", "Ÿ"): -70,
                    ("Ø", ","): -40,
                    ("Ø", "."): -40,
                    ("Ø", "A"): -20,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -30,
                    ("Ø", "X"): -60,
                    ("Ø", "Y"): -70,
                    ("Ø", "À"): -20,
                    ("Ø", "Á"): -20,
                    ("Ø", "Â"): -20,
                    ("Ø", "Ã"): -20,
                    ("Ø", "Ä"): -20,
                    ("Ø", "Å"): -20,
                    ("Ø", "Ý"): -70,
                    ("Ø", "Ÿ"): -70,
                    ("Ù", ","): -40,
                    ("Ù", "."): -40,
                    ("Ù", "A"): -40,
                    ("Ù", "À"): -40,
                    ("Ù", "Á"): -40,
                    ("Ù", "Â"): -40,
                    ("Ù", "Ã"): -40,
                    ("Ù", "Ä"): -40,
                    ("Ù", "Å"): -40,
                    ("Ú", ","): -40,
                    ("Ú", "."): -40,
                    ("Ú", "A"): -40,
                    ("Ú", "À"): -40,
                    ("Ú", "Á"): -40,
                    ("Ú", "Â"): -40,
                    ("Ú", "Ã"): -40,
                    ("Ú", "Ä"): -40,
                    ("Ú", "Å"): -40,
                    ("Û", ","): -40,
                    ("Û", "."): -40,
                    ("Û", "A"): -40,
                    ("Û", "À"): -40,
                    ("Û", "Á"): -40,
                    ("Û", "Â"): -40,
                    ("Û", "Ã"): -40,
                    ("Û", "Ä"): -40,
                    ("Û", "Å"): -40,
                    ("Ü", ","): -40,
                    ("Ü", "."): -40,
                    ("Ü", "A"): -40,
                    ("Ü", "À"): -40,
                    ("Ü", "Á"): -40,
                    ("Ü", "Â"): -40,
                    ("Ü", "Ã"): -40,
                    ("Ü", "Ä"): -40,
                    ("Ü", "Å"): -40,
                    ("Ý", ","): -140,
                    ("Ý", "-"): -140,
                    ("Ý", "."): -140,
                    ("Ý", ":"): -60,
                    ("Ý", ";"): -60,
                    ("Ý", "A"): -110,
                    ("Ý", "O"): -85,
                    ("Ý", "a"): -140,
                    ("Ý", "e"): -140,
                    ("Ý", "i"): -20,
                    ("Ý", "o"): -140,
                    ("Ý", "u"): -110,
                    ("Ý", "À"): -110,
                    ("Ý", "Á"): -110,
                    ("Ý", "Â"): -110,
                    ("Ý", "Ã"): -110,
                    ("Ý", "Ä"): -110,
                    ("Ý", "Å"): -110,
                    ("Ý", "Ò"): -85,
                    ("Ý", "Ó"): -85,
                    ("Ý", "Ô"): -85,
                    ("Ý", "Õ"): -85,
                    ("Ý", "Ö"): -85,
                    ("Ý", "Ø"): -85,
                    ("Ý", "à"): -140,
                    ("Ý", "á"): -140,
                    ("Ý", "â"): -140,
                    ("Ý", "ã"): -70,
                    ("Ý", "ä"): -140,
                    ("Ý", "å"): -140,
                    ("Ý", "è"): -140,
                    ("Ý", "é"): -140,
                    ("Ý", "ê"): -140,
                    ("Ý", "ë"): -140,
                    ("Ý", "í"): -20,
                    ("Ý", "ò"): -140,
                    ("Ý", "ó"): -140,
                    ("Ý", "ô"): -140,
                    ("Ý", "õ"): -140,
                    ("Ý", "ö"): -140,
                    ("Ý", "ø"): -140,
                    ("Ý", "ù"): -110,
                    ("Ý", "ú"): -110,
                    ("Ý", "û"): -110,
                    ("Ý", "ü"): -110,
                    ("à", "v"): -20,
                    ("à", "w"): -20,
                    ("à", "y"): -30,
                    ("à", "ý"): -30,
                    ("à", "ÿ"): -30,
                    ("á", "v"): -20,
                    ("á", "w"): -20,
                    ("á", "y"): -30,
                    ("á", "ý"): -30,
                    ("á", "ÿ"): -30,
                    ("â", "v"): -20,
                    ("â", "w"): -20,
                    ("â", "y"): -30,
                    ("â", "ý"): -30,
                    ("â", "ÿ"): -30,
                    ("ã", "v"): -20,
                    ("ã", "w"): -20,
                    ("ã", "y"): -30,
                    ("ã", "ý"): -30,
                    ("ã", "ÿ"): -30,
                    ("ä", "v"): -20,
                    ("ä", "w"): -20,
                    ("ä", "y"): -30,
                    ("ä", "ý"): -30,
                    ("ä", "ÿ"): -30,
                    ("å", "v"): -20,
                    ("å", "w"): -20,
                    ("å", "y"): -30,
                    ("å", "ý"): -30,
                    ("å", "ÿ"): -30,
                    ("ç", ","): -15,
                    ("ç", "k"): -20,
                    ("è", ","): -15,
                    ("è", "."): -15,
                    ("è", "v"): -30,
                    ("è", "w"): -20,
                    ("è", "x"): -30,
                    ("è", "y"): -20,
                    ("è", "ý"): -20,
                    ("è", "ÿ"): -20,
                    ("é", ","): -15,
                    ("é", "."): -15,
                    ("é", "v"): -30,
                    ("é", "w"): -20,
                    ("é", "x"): -30,
                    ("é", "y"): -20,
                    ("é", "ý"): -20,
                    ("é", "ÿ"): -20,
                    ("ê", ","): -15,
                    ("ê", "."): -15,
                    ("ê", "v"): -30,
                    ("ê", "w"): -20,
                    ("ê", "x"): -30,
                    ("ê", "y"): -20,
                    ("ê", "ý"): -20,
                    ("ê", "ÿ"): -20,
                    ("ë", ","): -15,
                    ("ë", "."): -15,
                    ("ë", "v"): -30,
                    ("ë", "w"): -20,
                    ("ë", "x"): -30,
                    ("ë", "y"): -20,
                    ("ë", "ý"): -20,
                    ("ë", "ÿ"): -20,
                    ("ñ", "u"): -10,
                    ("ñ", "v"): -20,
                    ("ñ", "y"): -15,
                    ("ñ", "ù"): -10,
                    ("ñ", "ú"): -10,
                    ("ñ", "û"): -10,
                    ("ñ", "ü"): -10,
                    ("ñ", "ý"): -15,
                    ("ñ", "ÿ"): -15,
                    ("ò", ","): -40,
                    ("ò", "."): -40,
                    ("ò", "v"): -15,
                    ("ò", "w"): -15,
                    ("ò", "x"): -30,
                    ("ò", "y"): -30,
                    ("ò", "ý"): -30,
                    ("ò", "ÿ"): -30,
                    ("ó", ","): -40,
                    ("ó", "."): -40,
                    ("ó", "v"): -15,
                    ("ó", "w"): -15,
                    ("ó", "x"): -30,
                    ("ó", "y"): -30,
                    ("ó", "ý"): -30,
                    ("ó", "ÿ"): -30,
                    ("ô", ","): -40,
                    ("ô", "."): -40,
                    ("ô", "v"): -15,
                    ("ô", "w"): -15,
                    ("ô", "x"): -30,
                    ("ô", "y"): -30,
                    ("ô", "ý"): -30,
                    ("ô", "ÿ"): -30,
                    ("õ", ","): -40,
                    ("õ", "."): -40,
                    ("õ", "v"): -15,
                    ("õ", "w"): -15,
                    ("õ", "x"): -30,
                    ("õ", "y"): -30,
                    ("õ", "ý"): -30,
                    ("õ", "ÿ"): -30,
                    ("ö", ","): -40,
                    ("ö", "."): -40,
                    ("ö", "v"): -15,
                    ("ö", "w"): -15,
                    ("ö", "x"): -30,
                    ("ö", "y"): -30,
                    ("ö", "ý"): -30,
                    ("ö", "ÿ"): -30,
                    ("ø", ","): -95,
                    ("ø", "."): -95,
                    ("ø", "a"): -55,
                    ("ø", "b"): -55,
                    ("ø", "c"): -55,
                    ("ø", "d"): -55,
                    ("ø", "e"): -55,
                    ("ø", "f"): -55,
                    ("ø", "g"): -55,
                    ("ø", "h"): -55,
                    ("ø", "i"): -55,
                    ("ø", "j"): -55,
                    ("ø", "k"): -55,
                    ("ø", "l"): -55,
                    ("ø", "m"): -55,
                    ("ø", "n"): -55,
                    ("ø", "o"): -55,
                    ("ø", "p"): -55,
                    ("ø", "q"): -55,
                    ("ø", "r"): -55,
                    ("ø", "s"): -55,
                    ("ø", "t"): -55,
                    ("ø", "u"): -55,
                    ("ø", "v"): -70,
                    ("ø", "w"): -70,
                    ("ø", "x"): -85,
                    ("ø", "y"): -70,
                    ("ø", "z"): -55,
                    ("ø", "à"): -55,
                    ("ø", "á"): -55,
                    ("ø", "â"): -55,
                    ("ø", "ã"): -55,
                    ("ø", "ä"): -55,
                    ("ø", "å"): -55,
                    ("ø", "ç"): -55,
                    ("ø", "è"): -55,
                    ("ø", "é"): -55,
                    ("ø", "ê"): -55,
                    ("ø", "ë"): -55,
                    ("ø", "ì"): -55,
                    ("ø", "í"): -55,
                    ("ø", "î"): -55,
                    ("ø", "ï"): -55,
                    ("ø", "ñ"): -55,
                    ("ø", "ò"): -55,
                    ("ø", "ó"): -55,
                    ("ø", "ô"): -55,
                    ("ø", "õ"): -55,
                    ("ø", "ö"): -55,
                    ("ø", "ø"): -55,
                    ("ø", "ù"): -55,
                    ("ø", "ú"): -55,
                    ("ø", "û"): -55,
                    ("ø", "ü"): -55,
                    ("ø", "ý"): -70,
                    ("ø", "ÿ"): -70,
                    ("ø", "ł"): -55,
                    ("ø", "š"): -55,
                    ("ø", "ž"): -55,
                    ("ý", ","): -100,
                    ("ý", "."): -100,
                    ("ý", "a"): -20,
                    ("ý", "e"): -20,
                    ("ý", "o"): -20,
                    ("ý", "à"): -20,
                    ("ý", "á"): -20,
                    ("ý", "â"): -20,
                    ("ý", "ã"): -20,
                    ("ý", "ä"): -20,
                    ("ý", "å"): -20,
                    ("ý", "è"): -20,
                    ("ý", "é"): -20,
                    ("ý", "ê"): -20,
                    ("ý", "ë"): -20,
                    ("ý", "ò"): -20,
                    ("ý", "ó"): -20,
                    ("ý", "ô"): -20,
                    ("ý", "õ"): -20,
                    ("ý", "ö"): -20,
                    ("ý", "ø"): -20,
                    ("ÿ", ","): -100,
                    ("ÿ", "."): -100,
                    ("ÿ", "a"): -20,
                    ("ÿ", "e"): -20,
                    ("ÿ", "o"): -20,
                    ("ÿ", "à"): -20,
                    ("ÿ", "á"): -20,
                    ("ÿ", "â"): -20,
                    ("ÿ", "ã"): -20,
                    ("ÿ", "ä"): -20,
                    ("ÿ", "å"): -20,
                    ("ÿ", "è"): -20,
                    ("ÿ", "é"): -20,
                    ("ÿ", "ê"): -20,
                    ("ÿ", "ë"): -20,
                    ("ÿ", "ò"): -20,
                    ("ÿ", "ó"): -20,
                    ("ÿ", "ô"): -20,
                    ("ÿ", "õ"): -20,
                    ("ÿ", "ö"): -20,
                    ("ÿ", "ø"): -20,
                    ("Ł", "T"): -110,
                    ("Ł", "V"): -110,
                    ("Ł", "W"): -70,
                    ("Ł", "Y"): -140,
                    ("Ł", "y"): -30,
                    ("Ł", "Ý"): -140,
                    ("Ł", "ý"): -30,
                    ("Ł", "ÿ"): -30,
                    ("Ł", "Ÿ"): -140,
                    ("Ł", "’"): -160,
                    ("Ł", "”"): -140,
                    ("Š", ","): -20,
                    ("Š", "."): -20,
                    ("š", ","): -15,
                    ("š", "."): -15,
                    ("š", "w"): -30,
                    ("Ÿ", ","): -140,
                    ("Ÿ", "-"): -140,
                    ("Ÿ", "."): -140,
                    ("Ÿ", ":"): -60,
                    ("Ÿ", ";"): -60,
                    ("Ÿ", "A"): -110,
                    ("Ÿ", "O"): -85,
                    ("Ÿ", "a"): -140,
                    ("Ÿ", "e"): -140,
                    ("Ÿ", "i"): -20,
                    ("Ÿ", "o"): -140,
                    ("Ÿ", "u"): -110,
                    ("Ÿ", "À"): -110,
                    ("Ÿ", "Á"): -110,
                    ("Ÿ", "Â"): -110,
                    ("Ÿ", "Ã"): -110,
                    ("Ÿ", "Ä"): -110,
                    ("Ÿ", "Å"): -110,
                    ("Ÿ", "Ò"): -85,
                    ("Ÿ", "Ó"): -85,
                    ("Ÿ", "Ô"): -85,
                    ("Ÿ", "Õ"): -85,
                    ("Ÿ", "Ö"): -85,
                    ("Ÿ", "Ø"): -85,
                    ("Ÿ", "à"): -140,
                    ("Ÿ", "á"): -140,
                    ("Ÿ", "â"): -140,
                    ("Ÿ", "ã"): -70,
                    ("Ÿ", "ä"): -140,
                    ("Ÿ", "å"): -140,
                    ("Ÿ", "è"): -140,
                    ("Ÿ", "é"): -140,
                    ("Ÿ", "ê"): -140,
                    ("Ÿ", "ë"): -140,
                    ("Ÿ", "í"): -20,
                    ("Ÿ", "ò"): -140,
                    ("Ÿ", "ó"): -140,
                    ("Ÿ", "ô"): -140,
                    ("Ÿ", "õ"): -140,
                    ("Ÿ", "ö"): -140,
                    ("Ÿ", "ø"): -140,
                    ("Ÿ", "ù"): -110,
                    ("Ÿ", "ú"): -110,
                    ("Ÿ", "û"): -110,
                    ("Ÿ", "ü"): -110,
                    ("ž", "e"): -15,
                    ("ž", "o"): -15,
                    ("ž", "è"): -15,
                    ("ž", "é"): -15,
                    ("ž", "ê"): -15,
                    ("ž", "ë"): -15,
                    ("ž", "ò"): -15,
                    ("ž", "ó"): -15,
                    ("ž", "ô"): -15,
                    ("ž", "õ"): -15,
                    ("ž", "ö"): -15,
                    ("ž", "ø"): -15,
                    ("‘", "‘"): -57,
                    ("’", " "): -70,
                    ("’", "d"): -50,
                    ("’", "r"): -50,
                    ("’", "s"): -50,
                    ("’", "š"): -50,
                    ("’", "’"): -57,
                    ("”", " "): -40,
                },
                0,
            ),
        ),
        BuiltinFont(
            b"Helvetica-Bold",
            b"f1",
            dictget(
                {
                    " ": 278,
                    "!": 333,
                    '"': 474,
                    "#": 556,
                    "$": 556,
                    "%": 889,
                    "&": 722,
                    "'": 238,
                    "(": 333,
                    ")": 333,
                    "*": 389,
                    "+": 584,
                    ",": 278,
                    "-": 333,
                    ".": 278,
                    "/": 278,
                    "0": 556,
                    "1": 556,
                    "2": 556,
                    "3": 556,
                    "4": 556,
                    "5": 556,
                    "6": 556,
                    "7": 556,
                    "8": 556,
                    "9": 556,
                    ":": 333,
                    ";": 333,
                    "<": 584,
                    "=": 584,
                    ">": 584,
                    "?": 611,
                    "@": 975,
                    "A": 722,
                    "B": 722,
                    "C": 722,
                    "D": 722,
                    "E": 667,
                    "F": 611,
                    "G": 778,
                    "H": 722,
                    "I": 278,
                    "J": 556,
                    "K": 722,
                    "L": 611,
                    "M": 833,
                    "N": 722,
                    "O": 778,
                    "P": 667,
                    "Q": 778,
                    "R": 722,
                    "S": 667,
                    "T": 611,
                    "U": 722,
                    "V": 667,
                    "W": 944,
                    "X": 667,
                    "Y": 667,
                    "Z": 611,
                    "[": 333,
                    "\\": 278,
                    "]": 333,
                    "^": 584,
                    "_": 556,
                    "`": 333,
                    "a": 556,
                    "b": 611,
                    "c": 556,
                    "d": 611,
                    "e": 556,
                    "f": 333,
                    "g": 611,
                    "h": 611,
                    "i": 278,
                    "j": 278,
                    "k": 556,
                    "l": 278,
                    "m": 889,
                    "n": 611,
                    "o": 611,
                    "p": 611,
                    "q": 611,
                    "r": 389,
                    "s": 556,
                    "t": 333,
                    "u": 611,
                    "v": 556,
                    "w": 778,
                    "x": 556,
                    "y": 556,
                    "z": 500,
                    "{": 389,
                    "|": 280,
                    "}": 389,
                    "~": 584,
                    "¡": 333,
                    "¢": 556,
                    "£": 556,
                    "¤": 556,
                    "¥": 556,
                    "¦": 280,
                    "§": 556,
                    "©": 737,
                    "ª": 370,
                    "«": 556,
                    "¬": 584,
                    "®": 737,
                    "°": 400,
                    "±": 584,
                    "²": 333,
                    "³": 333,
                    "¶": 556,
                    "·": 278,
                    "¹": 333,
                    "º": 365,
                    "»": 556,
                    "¼": 834,
                    "½": 834,
                    "¾": 834,
                    "¿": 611,
                    "À": 722,
                    "Á": 722,
                    "Â": 722,
                    "Ã": 722,
                    "Ä": 722,
                    "Å": 722,
                    "Æ": 1000,
                    "Ç": 722,
                    "È": 667,
                    "É": 667,
                    "Ê": 667,
                    "Ë": 667,
                    "Ì": 278,
                    "Í": 278,
                    "Î": 278,
                    "Ï": 278,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 778,
                    "Ó": 778,
                    "Ô": 778,
                    "Õ": 778,
                    "Ö": 778,
                    "×": 584,
                    "Ø": 778,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 667,
                    "Þ": 667,
                    "ß": 611,
                    "à": 556,
                    "á": 556,
                    "â": 556,
                    "ã": 556,
                    "ä": 556,
                    "å": 556,
                    "æ": 889,
                    "ç": 556,
                    "è": 556,
                    "é": 556,
                    "ê": 556,
                    "ë": 556,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 611,
                    "ñ": 611,
                    "ò": 611,
                    "ó": 611,
                    "ô": 611,
                    "õ": 611,
                    "ö": 611,
                    "÷": 584,
                    "ø": 611,
                    "ù": 611,
                    "ú": 611,
                    "û": 611,
                    "ü": 611,
                    "ý": 556,
                    "þ": 611,
                    "ÿ": 556,
                    "ı": 278,
                    "Ł": 611,
                    "ł": 278,
                    "Œ": 1000,
                    "œ": 944,
                    "Š": 667,
                    "š": 556,
                    "Ÿ": 667,
                    "Ž": 611,
                    "ž": 500,
                    "ƒ": 556,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 611,
                    "–": 556,
                    "—": 1000,
                    "‘": 278,
                    "’": 278,
                    "‚": 278,
                    "“": 500,
                    "”": 500,
                    "„": 500,
                    "†": 556,
                    "‡": 556,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 556,
                    "™": 1000,
                    "−": 584,
                    "ﬁ": 611,
                    "ﬂ": 611,
                },
                611,
            ),
            dictget(
                {
                    (" ", "T"): -100,
                    (" ", "V"): -80,
                    (" ", "W"): -80,
                    (" ", "Y"): -120,
                    (" ", "Ý"): -120,
                    (" ", "Ÿ"): -120,
                    (" ", "‘"): -60,
                    (" ", "“"): -80,
                    (",", " "): -40,
                    (",", "’"): -120,
                    (",", "”"): -120,
                    (".", " "): -40,
                    (".", "’"): -120,
                    (".", "”"): -120,
                    (":", " "): -40,
                    (";", " "): -40,
                    ("A", "C"): -40,
                    ("A", "G"): -50,
                    ("A", "O"): -40,
                    ("A", "Q"): -40,
                    ("A", "T"): -90,
                    ("A", "U"): -50,
                    ("A", "V"): -80,
                    ("A", "W"): -60,
                    ("A", "Y"): -110,
                    ("A", "u"): -30,
                    ("A", "v"): -40,
                    ("A", "w"): -30,
                    ("A", "y"): -30,
                    ("A", "Ç"): -40,
                    ("A", "Ò"): -40,
                    ("A", "Ó"): -40,
                    ("A", "Ô"): -40,
                    ("A", "Õ"): -40,
                    ("A", "Ö"): -40,
                    ("A", "Ø"): -40,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -110,
                    ("A", "ù"): -30,
                    ("A", "ú"): -30,
                    ("A", "û"): -30,
                    ("A", "ü"): -30,
                    ("A", "ý"): -30,
                    ("A", "ÿ"): -30,
                    ("A", "Ÿ"): -110,
                    ("B", "A"): -30,
                    ("B", "U"): -10,
                    ("B", "À"): -30,
                    ("B", "Á"): -30,
                    ("B", "Â"): -30,
                    ("B", "Ã"): -30,
                    ("B", "Ä"): -30,
                    ("B", "Å"): -30,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("D", ","): -30,
                    ("D", "."): -30,
                    ("D", "A"): -40,
                    ("D", "V"): -40,
                    ("D", "W"): -40,
                    ("D", "Y"): -70,
                    ("D", "À"): -40,
                    ("D", "Á"): -40,
                    ("D", "Â"): -40,
                    ("D", "Ã"): -40,
                    ("D", "Ä"): -40,
                    ("D", "Å"): -40,
                    ("D", "Ý"): -70,
                    ("D", "Ÿ"): -70,
                    ("F", ","): -100,
                    ("F", "."): -100,
                    ("F", "A"): -80,
                    ("F", "a"): -20,
                    ("F", "À"): -80,
                    ("F", "Á"): -80,
                    ("F", "Â"): -80,
                    ("F", "Ã"): -80,
                    ("F", "Ä"): -80,
                    ("F", "Å"): -80,
                    ("F", "à"): -20,
                    ("F", "á"): -20,
                    ("F", "â"): -20,
                    ("F", "ã"): -20,
                    ("F", "ä"): -20,
                    ("F", "å"): -20,
                    ("J", ","): -20,
                    ("J", "."): -20,
                    ("J", "A"): -20,
                    ("J", "u"): -20,
                    ("J", "À"): -20,
                    ("J", "Á"): -20,
                    ("J", "Â"): -20,
                    ("J", "Ã"): -20,
                    ("J", "Ä"): -20,
                    ("J", "Å"): -20,
                    ("J", "ù"): -20,
                    ("J", "ú"): -20,
                    ("J", "û"): -20,
                    ("J", "ü"): -20,
                    ("K", "O"): -30,
                    ("K", "e"): -15,
                    ("K", "o"): -35,
                    ("K", "u"): -30,
                    ("K", "y"): -40,
                    ("K", "Ò"): -30,
                    ("K", "Ó"): -30,
                    ("K", "Ô"): -30,
                    ("K", "Õ"): -30,
                    ("K", "Ö"): -30,
                    ("K", "Ø"): -30,
                    ("K", "è"): -15,
                    ("K", "é"): -15,
                    ("K", "ê"): -15,
                    ("K", "ë"): -15,
                    ("K", "ò"): -35,
                    ("K", "ó"): -35,
                    ("K", "ô"): -35,
                    ("K", "õ"): -35,
                    ("K", "ö"): -35,
                    ("K", "ø"): -35,
                    ("K", "ù"): -30,
                    ("K", "ú"): -30,
                    ("K", "û"): -30,
                    ("K", "ü"): -30,
                    ("K", "ý"): -40,
                    ("K", "ÿ"): -40,
                    ("L", "T"): -90,
                    ("L", "V"): -110,
                    ("L", "W"): -80,
                    ("L", "Y"): -120,
                    ("L", "y"): -30,
                    ("L", "Ý"): -120,
                    ("L", "ý"): -30,
                    ("L", "ÿ"): -30,
                    ("L", "Ÿ"): -120,
                    ("L", "’"): -140,
                    ("L", "”"): -140,
                    ("O", ","): -40,
                    ("O", "."): -40,
                    ("O", "A"): -50,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -50,
                    ("O", "X"): -50,
                    ("O", "Y"): -70,
                    ("O", "À"): -50,
                    ("O", "Á"): -50,
                    ("O", "Â"): -50,
                    ("O", "Ã"): -50,
                    ("O", "Ä"): -50,
                    ("O", "Å"): -50,
                    ("O", "Ý"): -70,
                    ("O", "Ÿ"): -70,
                    ("P", ","): -120,
                    ("P", "."): -120,
                    ("P", "A"): -100,
                    ("P", "a"): -30,
                    ("P", "e"): -30,
                    ("P", "o"): -40,
                    ("P", "À"): -100,
                    ("P", "Á"): -100,
                    ("P", "Â"): -100,
                    ("P", "Ã"): -100,
                    ("P", "Ä"): -100,
                    ("P", "Å"): -100,
                    ("P", "à"): -30,
                    ("P", "á"): -30,
                    ("P", "â"): -30,
                    ("P", "ã"): -30,
                    ("P", "ä"): -30,
                    ("P", "å"): -30,
                    ("P", "è"): -30,
                    ("P", "é"): -30,
                    ("P", "ê"): -30,
                    ("P", "ë"): -30,
                    ("P", "ò"): -40,
                    ("P", "ó"): -40,
                    ("P", "ô"): -40,
                    ("P", "õ"): -40,
                    ("P", "ö"): -40,
                    ("P", "ø"): -40,
                    ("Q", ","): 20,
                    ("Q", "."): 20,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -20,
                    ("R", "T"): -20,
                    ("R", "U"): -20,
                    ("R", "V"): -50,
                    ("R", "W"): -40,
                    ("R", "Y"): -50,
                    ("R", "Ò"): -20,
                    ("R", "Ó"): -20,
                    ("R", "Ô"): -20,
                    ("R", "Õ"): -20,
                    ("R", "Ö"): -20,
                    ("R", "Ø"): -20,
                    ("R", "Ù"): -20,
                    ("R", "Ú"): -20,
                    ("R", "Û"): -20,
                    ("R", "Ü"): -20,
                    ("R", "Ý"): -50,
                    ("R", "Ÿ"): -50,
                    ("T", ","): -80,
                    ("T", "-"): -120,
                    ("T", "."): -80,
                    ("T", ":"): -40,
                    ("T", ";"): -40,
                    ("T", "A"): -90,
                    ("T", "O"): -40,
                    ("T", "a"): -80,
                    ("T", "e"): -60,
                    ("T", "o"): -80,
                    ("T", "r"): -80,
                    ("T", "u"): -90,
                    ("T", "w"): -60,
                    ("T", "y"): -60,
                    ("T", "À"): -90,
                    ("T", "Á"): -90,
                    ("T", "Â"): -90,
                    ("T", "Ã"): -90,
                    ("T", "Ä"): -90,
                    ("T", "Å"): -90,
                    ("T", "Ò"): -40,
                    ("T", "Ó"): -40,
                    ("T", "Ô"): -40,
                    ("T", "Õ"): -40,
                    ("T", "Ö"): -40,
                    ("T", "Ø"): -40,
                    ("T", "à"): -80,
                    ("T", "á"): -80,
                    ("T", "â"): -80,
                    ("T", "ã"): -80,
                    ("T", "ä"): -80,
                    ("T", "å"): -80,
                    ("T", "è"): -60,
                    ("T", "é"): -60,
                    ("T", "ê"): -60,
                    ("T", "ë"): -60,
                    ("T", "ò"): -80,
                    ("T", "ó"): -80,
                    ("T", "ô"): -80,
                    ("T", "õ"): -80,
                    ("T", "ö"): -80,
                    ("T", "ø"): -80,
                    ("T", "ù"): -90,
                    ("T", "ú"): -90,
                    ("T", "û"): -90,
                    ("T", "ü"): -90,
                    ("T", "ý"): -60,
                    ("T", "ÿ"): -60,
                    ("U", ","): -30,
                    ("U", "."): -30,
                    ("U", "A"): -50,
                    ("U", "À"): -50,
                    ("U", "Á"): -50,
                    ("U", "Â"): -50,
                    ("U", "Ã"): -50,
                    ("U", "Ä"): -50,
                    ("U", "Å"): -50,
                    ("V", ","): -120,
                    ("V", "-"): -80,
                    ("V", "."): -120,
                    ("V", ":"): -40,
                    ("V", ";"): -40,
                    ("V", "A"): -80,
                    ("V", "G"): -50,
                    ("V", "O"): -50,
                    ("V", "a"): -60,
                    ("V", "e"): -50,
                    ("V", "o"): -90,
                    ("V", "u"): -60,
                    ("V", "À"): -80,
                    ("V", "Á"): -80,
                    ("V", "Â"): -80,
                    ("V", "Ã"): -80,
                    ("V", "Ä"): -80,
                    ("V", "Å"): -80,
                    ("V", "Ò"): -50,
                    ("V", "Ó"): -50,
                    ("V", "Ô"): -50,
                    ("V", "Õ"): -50,
                    ("V", "Ö"): -50,
                    ("V", "Ø"): -50,
                    ("V", "à"): -60,
                    ("V", "á"): -60,
                    ("V", "â"): -60,
                    ("V", "ã"): -60,
                    ("V", "ä"): -60,
                    ("V", "å"): -60,
                    ("V", "è"): -50,
                    ("V", "é"): -50,
                    ("V", "ê"): -50,
                    ("V", "ë"): -50,
                    ("V", "ò"): -90,
                    ("V", "ó"): -90,
                    ("V", "ô"): -90,
                    ("V", "õ"): -90,
                    ("V", "ö"): -90,
                    ("V", "ø"): -90,
                    ("V", "ù"): -60,
                    ("V", "ú"): -60,
                    ("V", "û"): -60,
                    ("V", "ü"): -60,
                    ("W", ","): -80,
                    ("W", "-"): -40,
                    ("W", "."): -80,
                    ("W", ":"): -10,
                    ("W", ";"): -10,
                    ("W", "A"): -60,
                    ("W", "O"): -20,
                    ("W", "a"): -40,
                    ("W", "e"): -35,
                    ("W", "o"): -60,
                    ("W", "u"): -45,
                    ("W", "y"): -20,
                    ("W", "À"): -60,
                    ("W", "Á"): -60,
                    ("W", "Â"): -60,
                    ("W", "Ã"): -60,
                    ("W", "Ä"): -60,
                    ("W", "Å"): -60,
                    ("W", "Ò"): -20,
                    ("W", "Ó"): -20,
                    ("W", "Ô"): -20,
                    ("W", "Õ"): -20,
                    ("W", "Ö"): -20,
                    ("W", "Ø"): -20,
                    ("W", "à"): -40,
                    ("W", "á"): -40,
                    ("W", "â"): -40,
                    ("W", "ã"): -40,
                    ("W", "ä"): -40,
                    ("W", "å"): -40,
                    ("W", "è"): -35,
                    ("W", "é"): -35,
                    ("W", "ê"): -35,
                    ("W", "ë"): -35,
                    ("W", "ò"): -60,
                    ("W", "ó"): -60,
                    ("W", "ô"): -60,
                    ("W", "õ"): -60,
                    ("W", "ö"): -60,
                    ("W", "ø"): -60,
                    ("W", "ù"): -45,
                    ("W", "ú"): -45,
                    ("W", "û"): -45,
                    ("W", "ü"): -45,
                    ("W", "ý"): -20,
                    ("W", "ÿ"): -20,
                    ("Y", ","): -100,
                    ("Y", "."): -100,
                    ("Y", ":"): -50,
                    ("Y", ";"): -50,
                    ("Y", "A"): -110,
                    ("Y", "O"): -70,
                    ("Y", "a"): -90,
                    ("Y", "e"): -80,
                    ("Y", "o"): -100,
                    ("Y", "u"): -100,
                    ("Y", "À"): -110,
                    ("Y", "Á"): -110,
                    ("Y", "Â"): -110,
                    ("Y", "Ã"): -110,
                    ("Y", "Ä"): -110,
                    ("Y", "Å"): -110,
                    ("Y", "Ò"): -70,
                    ("Y", "Ó"): -70,
                    ("Y", "Ô"): -70,
                    ("Y", "Õ"): -70,
                    ("Y", "Ö"): -70,
                    ("Y", "Ø"): -70,
                    ("Y", "à"): -90,
                    ("Y", "á"): -90,
                    ("Y", "â"): -90,
                    ("Y", "ã"): -90,
                    ("Y", "ä"): -90,
                    ("Y", "å"): -90,
                    ("Y", "è"): -80,
                    ("Y", "é"): -80,
                    ("Y", "ê"): -80,
                    ("Y", "ë"): -80,
                    ("Y", "ò"): -100,
                    ("Y", "ó"): -100,
                    ("Y", "ô"): -100,
                    ("Y", "õ"): -100,
                    ("Y", "ö"): -100,
                    ("Y", "ø"): -100,
                    ("Y", "ù"): -100,
                    ("Y", "ú"): -100,
                    ("Y", "û"): -100,
                    ("Y", "ü"): -100,
                    ("a", "g"): -10,
                    ("a", "v"): -15,
                    ("a", "w"): -15,
                    ("a", "y"): -20,
                    ("a", "ý"): -20,
                    ("a", "ÿ"): -20,
                    ("b", "l"): -10,
                    ("b", "u"): -20,
                    ("b", "v"): -20,
                    ("b", "y"): -20,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("b", "ý"): -20,
                    ("b", "ÿ"): -20,
                    ("b", "ł"): -10,
                    ("c", "h"): -10,
                    ("c", "k"): -20,
                    ("c", "l"): -20,
                    ("c", "y"): -10,
                    ("c", "ý"): -10,
                    ("c", "ÿ"): -10,
                    ("c", "ł"): -20,
                    ("d", "d"): -10,
                    ("d", "v"): -15,
                    ("d", "w"): -15,
                    ("d", "y"): -15,
                    ("d", "ý"): -15,
                    ("d", "ÿ"): -15,
                    ("e", ","): 10,
                    ("e", "."): 20,
                    ("e", "v"): -15,
                    ("e", "w"): -15,
                    ("e", "x"): -15,
                    ("e", "y"): -15,
                    ("e", "ý"): -15,
                    ("e", "ÿ"): -15,
                    ("f", ","): -10,
                    ("f", "."): -10,
                    ("f", "e"): -10,
                    ("f", "o"): -20,
                    ("f", "è"): -10,
                    ("f", "é"): -10,
                    ("f", "ê"): -10,
                    ("f", "ë"): -10,
                    ("f", "ò"): -20,
                    ("f", "ó"): -20,
                    ("f", "ô"): -20,
                    ("f", "õ"): -20,
                    ("f", "ö"): -20,
                    ("f", "ø"): -20,
                    ("f", "’"): 30,
                    ("f", "”"): 30,
                    ("g", "e"): 10,
                    ("g", "g"): -10,
                    ("g", "è"): 10,
                    ("g", "é"): 10,
                    ("g", "ê"): 10,
                    ("g", "ë"): 10,
                    ("h", "y"): -20,
                    ("h", "ý"): -20,
                    ("h", "ÿ"): -20,
                    ("k", "o"): -15,
                    ("k", "ò"): -15,
                    ("k", "ó"): -15,
                    ("k", "ô"): -15,
                    ("k", "õ"): -15,
                    ("k", "ö"): -15,
                    ("k", "ø"): -15,
                    ("l", "w"): -15,
                    ("l", "y"): -15,
                    ("l", "ý"): -15,
                    ("l", "ÿ"): -15,
                    ("m", "u"): -20,
                    ("m", "y"): -30,
                    ("m", "ù"): -20,
                    ("m", "ú"): -20,
                    ("m", "û"): -20,
                    ("m", "ü"): -20,
                    ("m", "ý"): -30,
                    ("m", "ÿ"): -30,
                    ("n", "u"): -10,
                    ("n", "v"): -40,
                    ("n", "y"): -20,
                    ("n", "ù"): -10,
                    ("n", "ú"): -10,
                    ("n", "û"): -10,
                    ("n", "ü"): -10,
                    ("n", "ý"): -20,
                    ("n", "ÿ"): -20,
                    ("o", "v"): -20,
                    ("o", "w"): -15,
                    ("o", "x"): -30,
                    ("o", "y"): -20,
                    ("o", "ý"): -20,
                    ("o", "ÿ"): -20,
                    ("p", "y"): -15,
                    ("p", "ý"): -15,
                    ("p", "ÿ"): -15,
                    ("r", ","): -60,
                    ("r", "-"): -20,
                    ("r", "."): -60,
                    ("r", "c"): -20,
                    ("r", "d"): -20,
                    ("r", "g"): -15,
                    ("r", "o"): -20,
                    ("r", "q"): -20,
                    ("r", "s"): -15,
                    ("r", "t"): 20,
                    ("r", "v"): 10,
                    ("r", "y"): 10,
                    ("r", "ç"): -20,
                    ("r", "ò"): -20,
                    ("r", "ó"): -20,
                    ("r", "ô"): -20,
                    ("r", "õ"): -20,
                    ("r", "ö"): -20,
                    ("r", "ø"): -20,
                    ("r", "ý"): 10,
                    ("r", "ÿ"): 10,
                    ("r", "š"): -15,
                    ("s", "w"): -15,
                    ("v", ","): -80,
                    ("v", "."): -80,
                    ("v", "a"): -20,
                    ("v", "o"): -30,
                    ("v", "à"): -20,
                    ("v", "á"): -20,
                    ("v", "â"): -20,
                    ("v", "ã"): -20,
                    ("v", "ä"): -20,
                    ("v", "å"): -20,
                    ("v", "ò"): -30,
                    ("v", "ó"): -30,
                    ("v", "ô"): -30,
                    ("v", "õ"): -30,
                    ("v", "ö"): -30,
                    ("v", "ø"): -30,
                    ("w", ","): -40,
                    ("w", "."): -40,
                    ("w", "o"): -20,
                    ("w", "ò"): -20,
                    ("w", "ó"): -20,
                    ("w", "ô"): -20,
                    ("w", "õ"): -20,
                    ("w", "ö"): -20,
                    ("w", "ø"): -20,
                    ("x", "e"): -10,
                    ("x", "è"): -10,
                    ("x", "é"): -10,
                    ("x", "ê"): -10,
                    ("x", "ë"): -10,
                    ("y", ","): -80,
                    ("y", "."): -80,
                    ("y", "a"): -30,
                    ("y", "e"): -10,
                    ("y", "o"): -25,
                    ("y", "à"): -30,
                    ("y", "á"): -30,
                    ("y", "â"): -30,
                    ("y", "ã"): -30,
                    ("y", "ä"): -30,
                    ("y", "å"): -30,
                    ("y", "è"): -10,
                    ("y", "é"): -10,
                    ("y", "ê"): -10,
                    ("y", "ë"): -10,
                    ("y", "ò"): -25,
                    ("y", "ó"): -25,
                    ("y", "ô"): -25,
                    ("y", "õ"): -25,
                    ("y", "ö"): -25,
                    ("y", "ø"): -25,
                    ("z", "e"): 10,
                    ("z", "è"): 10,
                    ("z", "é"): 10,
                    ("z", "ê"): 10,
                    ("z", "ë"): 10,
                    ("À", "C"): -40,
                    ("À", "G"): -50,
                    ("À", "O"): -40,
                    ("À", "Q"): -40,
                    ("À", "T"): -90,
                    ("À", "U"): -50,
                    ("À", "V"): -80,
                    ("À", "W"): -60,
                    ("À", "Y"): -110,
                    ("À", "u"): -30,
                    ("À", "v"): -40,
                    ("À", "w"): -30,
                    ("À", "y"): -30,
                    ("À", "Ç"): -40,
                    ("À", "Ò"): -40,
                    ("À", "Ó"): -40,
                    ("À", "Ô"): -40,
                    ("À", "Õ"): -40,
                    ("À", "Ö"): -40,
                    ("À", "Ø"): -40,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -110,
                    ("À", "ù"): -30,
                    ("À", "ú"): -30,
                    ("À", "û"): -30,
                    ("À", "ü"): -30,
                    ("À", "ý"): -30,
                    ("À", "ÿ"): -30,
                    ("À", "Ÿ"): -110,
                    ("Á", "C"): -40,
                    ("Á", "G"): -50,
                    ("Á", "O"): -40,
                    ("Á", "Q"): -40,
                    ("Á", "T"): -90,
                    ("Á", "U"): -50,
                    ("Á", "V"): -80,
                    ("Á", "W"): -60,
                    ("Á", "Y"): -110,
                    ("Á", "u"): -30,
                    ("Á", "v"): -40,
                    ("Á", "w"): -30,
                    ("Á", "y"): -30,
                    ("Á", "Ç"): -40,
                    ("Á", "Ò"): -40,
                    ("Á", "Ó"): -40,
                    ("Á", "Ô"): -40,
                    ("Á", "Õ"): -40,
                    ("Á", "Ö"): -40,
                    ("Á", "Ø"): -40,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -110,
                    ("Á", "ù"): -30,
                    ("Á", "ú"): -30,
                    ("Á", "û"): -30,
                    ("Á", "ü"): -30,
                    ("Á", "ý"): -30,
                    ("Á", "ÿ"): -30,
                    ("Á", "Ÿ"): -110,
                    ("Â", "C"): -40,
                    ("Â", "G"): -50,
                    ("Â", "O"): -40,
                    ("Â", "Q"): -40,
                    ("Â", "T"): -90,
                    ("Â", "U"): -50,
                    ("Â", "V"): -80,
                    ("Â", "W"): -60,
                    ("Â", "Y"): -110,
                    ("Â", "u"): -30,
                    ("Â", "v"): -40,
                    ("Â", "w"): -30,
                    ("Â", "y"): -30,
                    ("Â", "Ç"): -40,
                    ("Â", "Ò"): -40,
                    ("Â", "Ó"): -40,
                    ("Â", "Ô"): -40,
                    ("Â", "Õ"): -40,
                    ("Â", "Ö"): -40,
                    ("Â", "Ø"): -40,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -110,
                    ("Â", "ù"): -30,
                    ("Â", "ú"): -30,
                    ("Â", "û"): -30,
                    ("Â", "ü"): -30,
                    ("Â", "ý"): -30,
                    ("Â", "ÿ"): -30,
                    ("Â", "Ÿ"): -110,
                    ("Ã", "C"): -40,
                    ("Ã", "G"): -50,
                    ("Ã", "O"): -40,
                    ("Ã", "Q"): -40,
                    ("Ã", "T"): -90,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -80,
                    ("Ã", "W"): -60,
                    ("Ã", "Y"): -110,
                    ("Ã", "u"): -30,
                    ("Ã", "v"): -40,
                    ("Ã", "w"): -30,
                    ("Ã", "y"): -30,
                    ("Ã", "Ç"): -40,
                    ("Ã", "Ò"): -40,
                    ("Ã", "Ó"): -40,
                    ("Ã", "Ô"): -40,
                    ("Ã", "Õ"): -40,
                    ("Ã", "Ö"): -40,
                    ("Ã", "Ø"): -40,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -110,
                    ("Ã", "ù"): -30,
                    ("Ã", "ú"): -30,
                    ("Ã", "û"): -30,
                    ("Ã", "ü"): -30,
                    ("Ã", "ý"): -30,
                    ("Ã", "ÿ"): -30,
                    ("Ã", "Ÿ"): -110,
                    ("Ä", "C"): -40,
                    ("Ä", "G"): -50,
                    ("Ä", "O"): -40,
                    ("Ä", "Q"): -40,
                    ("Ä", "T"): -90,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -80,
                    ("Ä", "W"): -60,
                    ("Ä", "Y"): -110,
                    ("Ä", "u"): -30,
                    ("Ä", "v"): -40,
                    ("Ä", "w"): -30,
                    ("Ä", "y"): -30,
                    ("Ä", "Ç"): -40,
                    ("Ä", "Ò"): -40,
                    ("Ä", "Ó"): -40,
                    ("Ä", "Ô"): -40,
                    ("Ä", "Õ"): -40,
                    ("Ä", "Ö"): -40,
                    ("Ä", "Ø"): -40,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -110,
                    ("Ä", "ù"): -30,
                    ("Ä", "ú"): -30,
                    ("Ä", "û"): -30,
                    ("Ä", "ü"): -30,
                    ("Ä", "ý"): -30,
                    ("Ä", "ÿ"): -30,
                    ("Ä", "Ÿ"): -110,
                    ("Å", "C"): -40,
                    ("Å", "G"): -50,
                    ("Å", "O"): -40,
                    ("Å", "Q"): -40,
                    ("Å", "T"): -90,
                    ("Å", "U"): -50,
                    ("Å", "V"): -80,
                    ("Å", "W"): -60,
                    ("Å", "Y"): -110,
                    ("Å", "u"): -30,
                    ("Å", "v"): -40,
                    ("Å", "w"): -30,
                    ("Å", "y"): -30,
                    ("Å", "Ç"): -40,
                    ("Å", "Ò"): -40,
                    ("Å", "Ó"): -40,
                    ("Å", "Ô"): -40,
                    ("Å", "Õ"): -40,
                    ("Å", "Ö"): -40,
                    ("Å", "Ø"): -40,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -110,
                    ("Å", "ù"): -30,
                    ("Å", "ú"): -30,
                    ("Å", "û"): -30,
                    ("Å", "ü"): -30,
                    ("Å", "ý"): -30,
                    ("Å", "ÿ"): -30,
                    ("Å", "Ÿ"): -110,
                    ("Ò", ","): -40,
                    ("Ò", "."): -40,
                    ("Ò", "A"): -50,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -50,
                    ("Ò", "X"): -50,
                    ("Ò", "Y"): -70,
                    ("Ò", "À"): -50,
                    ("Ò", "Á"): -50,
                    ("Ò", "Â"): -50,
                    ("Ò", "Ã"): -50,
                    ("Ò", "Ä"): -50,
                    ("Ò", "Å"): -50,
                    ("Ò", "Ý"): -70,
                    ("Ò", "Ÿ"): -70,
                    ("Ó", ","): -40,
                    ("Ó", "."): -40,
                    ("Ó", "A"): -50,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -50,
                    ("Ó", "X"): -50,
                    ("Ó", "Y"): -70,
                    ("Ó", "À"): -50,
                    ("Ó", "Á"): -50,
                    ("Ó", "Â"): -50,
                    ("Ó", "Ã"): -50,
                    ("Ó", "Ä"): -50,
                    ("Ó", "Å"): -50,
                    ("Ó", "Ý"): -70,
                    ("Ó", "Ÿ"): -70,
                    ("Ô", ","): -40,
                    ("Ô", "."): -40,
                    ("Ô", "A"): -50,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -50,
                    ("Ô", "X"): -50,
                    ("Ô", "Y"): -70,
                    ("Ô", "À"): -50,
                    ("Ô", "Á"): -50,
                    ("Ô", "Â"): -50,
                    ("Ô", "Ã"): -50,
                    ("Ô", "Ä"): -50,
                    ("Ô", "Å"): -50,
                    ("Ô", "Ý"): -70,
                    ("Ô", "Ÿ"): -70,
                    ("Õ", ","): -40,
                    ("Õ", "."): -40,
                    ("Õ", "A"): -50,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -50,
                    ("Õ", "X"): -50,
                    ("Õ", "Y"): -70,
                    ("Õ", "À"): -50,
                    ("Õ", "Á"): -50,
                    ("Õ", "Â"): -50,
                    ("Õ", "Ã"): -50,
                    ("Õ", "Ä"): -50,
                    ("Õ", "Å"): -50,
                    ("Õ", "Ý"): -70,
                    ("Õ", "Ÿ"): -70,
                    ("Ö", ","): -40,
                    ("Ö", "."): -40,
                    ("Ö", "A"): -50,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -50,
                    ("Ö", "X"): -50,
                    ("Ö", "Y"): -70,
                    ("Ö", "À"): -50,
                    ("Ö", "Á"): -50,
                    ("Ö", "Â"): -50,
                    ("Ö", "Ã"): -50,
                    ("Ö", "Ä"): -50,
                    ("Ö", "Å"): -50,
                    ("Ö", "Ý"): -70,
                    ("Ö", "Ÿ"): -70,
                    ("Ø", ","): -40,
                    ("Ø", "."): -40,
                    ("Ø", "A"): -50,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -50,
                    ("Ø", "X"): -50,
                    ("Ø", "Y"): -70,
                    ("Ø", "À"): -50,
                    ("Ø", "Á"): -50,
                    ("Ø", "Â"): -50,
                    ("Ø", "Ã"): -50,
                    ("Ø", "Ä"): -50,
                    ("Ø", "Å"): -50,
                    ("Ø", "Ý"): -70,
                    ("Ø", "Ÿ"): -70,
                    ("Ù", ","): -30,
                    ("Ù", "."): -30,
                    ("Ù", "A"): -50,
                    ("Ù", "À"): -50,
                    ("Ù", "Á"): -50,
                    ("Ù", "Â"): -50,
                    ("Ù", "Ã"): -50,
                    ("Ù", "Ä"): -50,
                    ("Ù", "Å"): -50,
                    ("Ú", ","): -30,
                    ("Ú", "."): -30,
                    ("Ú", "A"): -50,
                    ("Ú", "À"): -50,
                    ("Ú", "Á"): -50,
                    ("Ú", "Â"): -50,
                    ("Ú", "Ã"): -50,
                    ("Ú", "Ä"): -50,
                    ("Ú", "Å"): -50,
                    ("Û", ","): -30,
                    ("Û", "."): -30,
                    ("Û", "A"): -50,
                    ("Û", "À"): -50,
                    ("Û", "Á"): -50,
                    ("Û", "Â"): -50,
                    ("Û", "Ã"): -50,
                    ("Û", "Ä"): -50,
                    ("Û", "Å"): -50,
                    ("Ü", ","): -30,
                    ("Ü", "."): -30,
                    ("Ü", "A"): -50,
                    ("Ü", "À"): -50,
                    ("Ü", "Á"): -50,
                    ("Ü", "Â"): -50,
                    ("Ü", "Ã"): -50,
                    ("Ü", "Ä"): -50,
                    ("Ü", "Å"): -50,
                    ("Ý", ","): -100,
                    ("Ý", "."): -100,
                    ("Ý", ":"): -50,
                    ("Ý", ";"): -50,
                    ("Ý", "A"): -110,
                    ("Ý", "O"): -70,
                    ("Ý", "a"): -90,
                    ("Ý", "e"): -80,
                    ("Ý", "o"): -100,
                    ("Ý", "u"): -100,
                    ("Ý", "À"): -110,
                    ("Ý", "Á"): -110,
                    ("Ý", "Â"): -110,
                    ("Ý", "Ã"): -110,
                    ("Ý", "Ä"): -110,
                    ("Ý", "Å"): -110,
                    ("Ý", "Ò"): -70,
                    ("Ý", "Ó"): -70,
                    ("Ý", "Ô"): -70,
                    ("Ý", "Õ"): -70,
                    ("Ý", "Ö"): -70,
                    ("Ý", "Ø"): -70,
                    ("Ý", "à"): -90,
                    ("Ý", "á"): -90,
                    ("Ý", "â"): -90,
                    ("Ý", "ã"): -90,
                    ("Ý", "ä"): -90,
                    ("Ý", "å"): -90,
                    ("Ý", "è"): -80,
                    ("Ý", "é"): -80,
                    ("Ý", "ê"): -80,
                    ("Ý", "ë"): -80,
                    ("Ý", "ò"): -100,
                    ("Ý", "ó"): -100,
                    ("Ý", "ô"): -100,
                    ("Ý", "õ"): -100,
                    ("Ý", "ö"): -100,
                    ("Ý", "ø"): -100,
                    ("Ý", "ù"): -100,
                    ("Ý", "ú"): -100,
                    ("Ý", "û"): -100,
                    ("Ý", "ü"): -100,
                    ("à", "g"): -10,
                    ("à", "v"): -15,
                    ("à", "w"): -15,
                    ("à", "y"): -20,
                    ("à", "ý"): -20,
                    ("à", "ÿ"): -20,
                    ("á", "g"): -10,
                    ("á", "v"): -15,
                    ("á", "w"): -15,
                    ("á", "y"): -20,
                    ("á", "ý"): -20,
                    ("á", "ÿ"): -20,
                    ("â", "g"): -10,
                    ("â", "v"): -15,
                    ("â", "w"): -15,
                    ("â", "y"): -20,
                    ("â", "ý"): -20,
                    ("â", "ÿ"): -20,
                    ("ã", "g"): -10,
                    ("ã", "v"): -15,
                    ("ã", "w"): -15,
                    ("ã", "y"): -20,
                    ("ã", "ý"): -20,
                    ("ã", "ÿ"): -20,
                    ("ä", "g"): -10,
                    ("ä", "v"): -15,
                    ("ä", "w"): -15,
                    ("ä", "y"): -20,
                    ("ä", "ý"): -20,
                    ("ä", "ÿ"): -20,
                    ("å", "g"): -10,
                    ("å", "v"): -15,
                    ("å", "w"): -15,
                    ("å", "y"): -20,
                    ("å", "ý"): -20,
                    ("å", "ÿ"): -20,
                    ("ç", "h"): -10,
                    ("ç", "k"): -20,
                    ("ç", "l"): -20,
                    ("ç", "y"): -10,
                    ("ç", "ý"): -10,
                    ("ç", "ÿ"): -10,
                    ("ç", "ł"): -20,
                    ("è", ","): 10,
                    ("è", "."): 20,
                    ("è", "v"): -15,
                    ("è", "w"): -15,
                    ("è", "x"): -15,
                    ("è", "y"): -15,
                    ("è", "ý"): -15,
                    ("è", "ÿ"): -15,
                    ("é", ","): 10,
                    ("é", "."): 20,
                    ("é", "v"): -15,
                    ("é", "w"): -15,
                    ("é", "x"): -15,
                    ("é", "y"): -15,
                    ("é", "ý"): -15,
                    ("é", "ÿ"): -15,
                    ("ê", ","): 10,
                    ("ê", "."): 20,
                    ("ê", "v"): -15,
                    ("ê", "w"): -15,
                    ("ê", "x"): -15,
                    ("ê", "y"): -15,
                    ("ê", "ý"): -15,
                    ("ê", "ÿ"): -15,
                    ("ë", ","): 10,
                    ("ë", "."): 20,
                    ("ë", "v"): -15,
                    ("ë", "w"): -15,
                    ("ë", "x"): -15,
                    ("ë", "y"): -15,
                    ("ë", "ý"): -15,
                    ("ë", "ÿ"): -15,
                    ("ñ", "u"): -10,
                    ("ñ", "v"): -40,
                    ("ñ", "y"): -20,
                    ("ñ", "ù"): -10,
                    ("ñ", "ú"): -10,
                    ("ñ", "û"): -10,
                    ("ñ", "ü"): -10,
                    ("ñ", "ý"): -20,
                    ("ñ", "ÿ"): -20,
                    ("ò", "v"): -20,
                    ("ò", "w"): -15,
                    ("ò", "x"): -30,
                    ("ò", "y"): -20,
                    ("ò", "ý"): -20,
                    ("ò", "ÿ"): -20,
                    ("ó", "v"): -20,
                    ("ó", "w"): -15,
                    ("ó", "x"): -30,
                    ("ó", "y"): -20,
                    ("ó", "ý"): -20,
                    ("ó", "ÿ"): -20,
                    ("ô", "v"): -20,
                    ("ô", "w"): -15,
                    ("ô", "x"): -30,
                    ("ô", "y"): -20,
                    ("ô", "ý"): -20,
                    ("ô", "ÿ"): -20,
                    ("õ", "v"): -20,
                    ("õ", "w"): -15,
                    ("õ", "x"): -30,
                    ("õ", "y"): -20,
                    ("õ", "ý"): -20,
                    ("õ", "ÿ"): -20,
                    ("ö", "v"): -20,
                    ("ö", "w"): -15,
                    ("ö", "x"): -30,
                    ("ö", "y"): -20,
                    ("ö", "ý"): -20,
                    ("ö", "ÿ"): -20,
                    ("ø", "v"): -20,
                    ("ø", "w"): -15,
                    ("ø", "x"): -30,
                    ("ø", "y"): -20,
                    ("ø", "ý"): -20,
                    ("ø", "ÿ"): -20,
                    ("ý", ","): -80,
                    ("ý", "."): -80,
                    ("ý", "a"): -30,
                    ("ý", "e"): -10,
                    ("ý", "o"): -25,
                    ("ý", "à"): -30,
                    ("ý", "á"): -30,
                    ("ý", "â"): -30,
                    ("ý", "ã"): -30,
                    ("ý", "ä"): -30,
                    ("ý", "å"): -30,
                    ("ý", "è"): -10,
                    ("ý", "é"): -10,
                    ("ý", "ê"): -10,
                    ("ý", "ë"): -10,
                    ("ý", "ò"): -25,
                    ("ý", "ó"): -25,
                    ("ý", "ô"): -25,
                    ("ý", "õ"): -25,
                    ("ý", "ö"): -25,
                    ("ý", "ø"): -25,
                    ("ÿ", ","): -80,
                    ("ÿ", "."): -80,
                    ("ÿ", "a"): -30,
                    ("ÿ", "e"): -10,
                    ("ÿ", "o"): -25,
                    ("ÿ", "à"): -30,
                    ("ÿ", "á"): -30,
                    ("ÿ", "â"): -30,
                    ("ÿ", "ã"): -30,
                    ("ÿ", "ä"): -30,
                    ("ÿ", "å"): -30,
                    ("ÿ", "è"): -10,
                    ("ÿ", "é"): -10,
                    ("ÿ", "ê"): -10,
                    ("ÿ", "ë"): -10,
                    ("ÿ", "ò"): -25,
                    ("ÿ", "ó"): -25,
                    ("ÿ", "ô"): -25,
                    ("ÿ", "õ"): -25,
                    ("ÿ", "ö"): -25,
                    ("ÿ", "ø"): -25,
                    ("Ł", "T"): -90,
                    ("Ł", "V"): -110,
                    ("Ł", "W"): -80,
                    ("Ł", "Y"): -120,
                    ("Ł", "y"): -30,
                    ("Ł", "Ý"): -120,
                    ("Ł", "ý"): -30,
                    ("Ł", "ÿ"): -30,
                    ("Ł", "Ÿ"): -120,
                    ("Ł", "’"): -140,
                    ("Ł", "”"): -140,
                    ("ł", "w"): -15,
                    ("ł", "y"): -15,
                    ("ł", "ý"): -15,
                    ("ł", "ÿ"): -15,
                    ("š", "w"): -15,
                    ("Ÿ", ","): -100,
                    ("Ÿ", "."): -100,
                    ("Ÿ", ":"): -50,
                    ("Ÿ", ";"): -50,
                    ("Ÿ", "A"): -110,
                    ("Ÿ", "O"): -70,
                    ("Ÿ", "a"): -90,
                    ("Ÿ", "e"): -80,
                    ("Ÿ", "o"): -100,
                    ("Ÿ", "u"): -100,
                    ("Ÿ", "À"): -110,
                    ("Ÿ", "Á"): -110,
                    ("Ÿ", "Â"): -110,
                    ("Ÿ", "Ã"): -110,
                    ("Ÿ", "Ä"): -110,
                    ("Ÿ", "Å"): -110,
                    ("Ÿ", "Ò"): -70,
                    ("Ÿ", "Ó"): -70,
                    ("Ÿ", "Ô"): -70,
                    ("Ÿ", "Õ"): -70,
                    ("Ÿ", "Ö"): -70,
                    ("Ÿ", "Ø"): -70,
                    ("Ÿ", "à"): -90,
                    ("Ÿ", "á"): -90,
                    ("Ÿ", "â"): -90,
                    ("Ÿ", "ã"): -90,
                    ("Ÿ", "ä"): -90,
                    ("Ÿ", "å"): -90,
                    ("Ÿ", "è"): -80,
                    ("Ÿ", "é"): -80,
                    ("Ÿ", "ê"): -80,
                    ("Ÿ", "ë"): -80,
                    ("Ÿ", "ò"): -100,
                    ("Ÿ", "ó"): -100,
                    ("Ÿ", "ô"): -100,
                    ("Ÿ", "õ"): -100,
                    ("Ÿ", "ö"): -100,
                    ("Ÿ", "ø"): -100,
                    ("Ÿ", "ù"): -100,
                    ("Ÿ", "ú"): -100,
                    ("Ÿ", "û"): -100,
                    ("Ÿ", "ü"): -100,
                    ("ž", "e"): 10,
                    ("ž", "è"): 10,
                    ("ž", "é"): 10,
                    ("ž", "ê"): 10,
                    ("ž", "ë"): 10,
                    ("‘", "‘"): -46,
                    ("’", " "): -80,
                    ("’", "d"): -80,
                    ("’", "l"): -20,
                    ("’", "r"): -40,
                    ("’", "s"): -60,
                    ("’", "v"): -20,
                    ("’", "ł"): -20,
                    ("’", "š"): -60,
                    ("’", "’"): -46,
                    ("”", " "): -80,
                },
                0,
            ),
        ),
        BuiltinFont(
            b"Helvetica-Oblique",
            b"f2",
            dictget(
                {
                    " ": 278,
                    "!": 278,
                    '"': 355,
                    "#": 556,
                    "$": 556,
                    "%": 889,
                    "&": 667,
                    "'": 191,
                    "(": 333,
                    ")": 333,
                    "*": 389,
                    "+": 584,
                    ",": 278,
                    "-": 333,
                    ".": 278,
                    "/": 278,
                    "0": 556,
                    "1": 556,
                    "2": 556,
                    "3": 556,
                    "4": 556,
                    "5": 556,
                    "6": 556,
                    "7": 556,
                    "8": 556,
                    "9": 556,
                    ":": 278,
                    ";": 278,
                    "<": 584,
                    "=": 584,
                    ">": 584,
                    "?": 556,
                    "@": 1015,
                    "A": 667,
                    "B": 667,
                    "C": 722,
                    "D": 722,
                    "E": 667,
                    "F": 611,
                    "G": 778,
                    "H": 722,
                    "I": 278,
                    "J": 500,
                    "K": 667,
                    "L": 556,
                    "M": 833,
                    "N": 722,
                    "O": 778,
                    "P": 667,
                    "Q": 778,
                    "R": 722,
                    "S": 667,
                    "T": 611,
                    "U": 722,
                    "V": 667,
                    "W": 944,
                    "X": 667,
                    "Y": 667,
                    "Z": 611,
                    "[": 278,
                    "\\": 278,
                    "]": 278,
                    "^": 469,
                    "_": 556,
                    "`": 333,
                    "a": 556,
                    "b": 556,
                    "c": 500,
                    "d": 556,
                    "e": 556,
                    "f": 278,
                    "g": 556,
                    "h": 556,
                    "i": 222,
                    "j": 222,
                    "k": 500,
                    "l": 222,
                    "m": 833,
                    "n": 556,
                    "o": 556,
                    "p": 556,
                    "q": 556,
                    "r": 333,
                    "s": 500,
                    "t": 278,
                    "u": 556,
                    "v": 500,
                    "w": 722,
                    "x": 500,
                    "y": 500,
                    "z": 500,
                    "{": 334,
                    "|": 260,
                    "}": 334,
                    "~": 584,
                    "¡": 333,
                    "¢": 556,
                    "£": 556,
                    "¤": 556,
                    "¥": 556,
                    "¦": 260,
                    "§": 556,
                    "©": 737,
                    "ª": 370,
                    "«": 556,
                    "¬": 584,
                    "®": 737,
                    "°": 400,
                    "±": 584,
                    "²": 333,
                    "³": 333,
                    "¶": 537,
                    "·": 278,
                    "¹": 333,
                    "º": 365,
                    "»": 556,
                    "¼": 834,
                    "½": 834,
                    "¾": 834,
                    "¿": 611,
                    "À": 667,
                    "Á": 667,
                    "Â": 667,
                    "Ã": 667,
                    "Ä": 667,
                    "Å": 667,
                    "Æ": 1000,
                    "Ç": 722,
                    "È": 667,
                    "É": 667,
                    "Ê": 667,
                    "Ë": 667,
                    "Ì": 278,
                    "Í": 278,
                    "Î": 278,
                    "Ï": 278,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 778,
                    "Ó": 778,
                    "Ô": 778,
                    "Õ": 778,
                    "Ö": 778,
                    "×": 584,
                    "Ø": 778,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 667,
                    "Þ": 667,
                    "ß": 611,
                    "à": 556,
                    "á": 556,
                    "â": 556,
                    "ã": 556,
                    "ä": 556,
                    "å": 556,
                    "æ": 889,
                    "ç": 500,
                    "è": 556,
                    "é": 556,
                    "ê": 556,
                    "ë": 556,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 556,
                    "ñ": 556,
                    "ò": 556,
                    "ó": 556,
                    "ô": 556,
                    "õ": 556,
                    "ö": 556,
                    "÷": 584,
                    "ø": 611,
                    "ù": 556,
                    "ú": 556,
                    "û": 556,
                    "ü": 556,
                    "ý": 500,
                    "þ": 556,
                    "ÿ": 500,
                    "ı": 278,
                    "Ł": 556,
                    "ł": 222,
                    "Œ": 1000,
                    "œ": 944,
                    "Š": 667,
                    "š": 500,
                    "Ÿ": 667,
                    "Ž": 611,
                    "ž": 500,
                    "ƒ": 556,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 556,
                    "–": 556,
                    "—": 1000,
                    "‘": 222,
                    "’": 222,
                    "‚": 222,
                    "“": 333,
                    "”": 333,
                    "„": 333,
                    "†": 556,
                    "‡": 556,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 556,
                    "™": 1000,
                    "−": 584,
                    "ﬁ": 500,
                    "ﬂ": 500,
                },
                556,
            ),
            dictget(
                {
                    (" ", "T"): -50,
                    (" ", "V"): -50,
                    (" ", "W"): -40,
                    (" ", "Y"): -90,
                    (" ", "Ý"): -90,
                    (" ", "Ÿ"): -90,
                    (" ", "‘"): -60,
                    (" ", "“"): -30,
                    (",", "’"): -100,
                    (",", "”"): -100,
                    (".", " "): -60,
                    (".", "’"): -100,
                    (".", "”"): -100,
                    (":", " "): -50,
                    (";", " "): -50,
                    ("A", "C"): -30,
                    ("A", "G"): -30,
                    ("A", "O"): -30,
                    ("A", "Q"): -30,
                    ("A", "T"): -120,
                    ("A", "U"): -50,
                    ("A", "V"): -70,
                    ("A", "W"): -50,
                    ("A", "Y"): -100,
                    ("A", "u"): -30,
                    ("A", "v"): -40,
                    ("A", "w"): -40,
                    ("A", "y"): -40,
                    ("A", "Ç"): -30,
                    ("A", "Ò"): -30,
                    ("A", "Ó"): -30,
                    ("A", "Ô"): -30,
                    ("A", "Õ"): -30,
                    ("A", "Ö"): -30,
                    ("A", "Ø"): -30,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -100,
                    ("A", "ù"): -30,
                    ("A", "ú"): -30,
                    ("A", "û"): -30,
                    ("A", "ü"): -30,
                    ("A", "ý"): -40,
                    ("A", "ÿ"): -40,
                    ("A", "Ÿ"): -100,
                    ("B", ","): -20,
                    ("B", "."): -20,
                    ("B", "U"): -10,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("C", ","): -30,
                    ("C", "."): -30,
                    ("D", ","): -70,
                    ("D", "."): -70,
                    ("D", "A"): -40,
                    ("D", "V"): -70,
                    ("D", "W"): -40,
                    ("D", "Y"): -90,
                    ("D", "À"): -40,
                    ("D", "Á"): -40,
                    ("D", "Â"): -40,
                    ("D", "Ã"): -40,
                    ("D", "Ä"): -40,
                    ("D", "Å"): -40,
                    ("D", "Ý"): -90,
                    ("D", "Ÿ"): -90,
                    ("F", ","): -150,
                    ("F", "."): -150,
                    ("F", "A"): -80,
                    ("F", "a"): -50,
                    ("F", "e"): -30,
                    ("F", "o"): -30,
                    ("F", "r"): -45,
                    ("F", "À"): -80,
                    ("F", "Á"): -80,
                    ("F", "Â"): -80,
                    ("F", "Ã"): -80,
                    ("F", "Ä"): -80,
                    ("F", "Å"): -80,
                    ("F", "à"): -50,
                    ("F", "á"): -50,
                    ("F", "â"): -50,
                    ("F", "ã"): -50,
                    ("F", "ä"): -50,
                    ("F", "å"): -50,
                    ("F", "è"): -30,
                    ("F", "é"): -30,
                    ("F", "ê"): -30,
                    ("F", "ë"): -30,
                    ("F", "ò"): -30,
                    ("F", "ó"): -30,
                    ("F", "ô"): -30,
                    ("F", "õ"): -30,
                    ("F", "ö"): -30,
                    ("F", "ø"): -30,
                    ("J", ","): -30,
                    ("J", "."): -30,
                    ("J", "A"): -20,
                    ("J", "a"): -20,
                    ("J", "u"): -20,
                    ("J", "À"): -20,
                    ("J", "Á"): -20,
                    ("J", "Â"): -20,
                    ("J", "Ã"): -20,
                    ("J", "Ä"): -20,
                    ("J", "Å"): -20,
                    ("J", "à"): -20,
                    ("J", "á"): -20,
                    ("J", "â"): -20,
                    ("J", "ã"): -20,
                    ("J", "ä"): -20,
                    ("J", "å"): -20,
                    ("J", "ù"): -20,
                    ("J", "ú"): -20,
                    ("J", "û"): -20,
                    ("J", "ü"): -20,
                    ("K", "O"): -50,
                    ("K", "e"): -40,
                    ("K", "o"): -40,
                    ("K", "u"): -30,
                    ("K", "y"): -50,
                    ("K", "Ò"): -50,
                    ("K", "Ó"): -50,
                    ("K", "Ô"): -50,
                    ("K", "Õ"): -50,
                    ("K", "Ö"): -50,
                    ("K", "Ø"): -50,
                    ("K", "è"): -40,
                    ("K", "é"): -40,
                    ("K", "ê"): -40,
                    ("K", "ë"): -40,
                    ("K", "ò"): -40,
                    ("K", "ó"): -40,
                    ("K", "ô"): -40,
                    ("K", "õ"): -40,
                    ("K", "ö"): -40,
                    ("K", "ø"): -40,
                    ("K", "ù"): -30,
                    ("K", "ú"): -30,
                    ("K", "û"): -30,
                    ("K", "ü"): -30,
                    ("K", "ý"): -50,
                    ("K", "ÿ"): -50,
                    ("L", "T"): -110,
                    ("L", "V"): -110,
                    ("L", "W"): -70,
                    ("L", "Y"): -140,
                    ("L", "y"): -30,
                    ("L", "Ý"): -140,
                    ("L", "ý"): -30,
                    ("L", "ÿ"): -30,
                    ("L", "Ÿ"): -140,
                    ("L", "’"): -160,
                    ("L", "”"): -140,
                    ("O", ","): -40,
                    ("O", "."): -40,
                    ("O", "A"): -20,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -30,
                    ("O", "X"): -60,
                    ("O", "Y"): -70,
                    ("O", "À"): -20,
                    ("O", "Á"): -20,
                    ("O", "Â"): -20,
                    ("O", "Ã"): -20,
                    ("O", "Ä"): -20,
                    ("O", "Å"): -20,
                    ("O", "Ý"): -70,
                    ("O", "Ÿ"): -70,
                    ("P", ","): -180,
                    ("P", "."): -180,
                    ("P", "A"): -120,
                    ("P", "a"): -40,
                    ("P", "e"): -50,
                    ("P", "o"): -50,
                    ("P", "À"): -120,
                    ("P", "Á"): -120,
                    ("P", "Â"): -120,
                    ("P", "Ã"): -120,
                    ("P", "Ä"): -120,
                    ("P", "Å"): -120,
                    ("P", "à"): -40,
                    ("P", "á"): -40,
                    ("P", "â"): -40,
                    ("P", "ã"): -40,
                    ("P", "ä"): -40,
                    ("P", "å"): -40,
                    ("P", "è"): -50,
                    ("P", "é"): -50,
                    ("P", "ê"): -50,
                    ("P", "ë"): -50,
                    ("P", "ò"): -50,
                    ("P", "ó"): -50,
                    ("P", "ô"): -50,
                    ("P", "õ"): -50,
                    ("P", "ö"): -50,
                    ("P", "ø"): -50,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -20,
                    ("R", "T"): -30,
                    ("R", "U"): -40,
                    ("R", "V"): -50,
                    ("R", "W"): -30,
                    ("R", "Y"): -50,
                    ("R", "Ò"): -20,
                    ("R", "Ó"): -20,
                    ("R", "Ô"): -20,
                    ("R", "Õ"): -20,
                    ("R", "Ö"): -20,
                    ("R", "Ø"): -20,
                    ("R", "Ù"): -40,
                    ("R", "Ú"): -40,
                    ("R", "Û"): -40,
                    ("R", "Ü"): -40,
                    ("R", "Ý"): -50,
                    ("R", "Ÿ"): -50,
                    ("S", ","): -20,
                    ("S", "."): -20,
                    ("T", ","): -120,
                    ("T", "-"): -140,
                    ("T", "."): -120,
                    ("T", ":"): -20,
                    ("T", ";"): -20,
                    ("T", "A"): -120,
                    ("T", "O"): -40,
                    ("T", "a"): -120,
                    ("T", "e"): -120,
                    ("T", "o"): -120,
                    ("T", "r"): -120,
                    ("T", "u"): -120,
                    ("T", "w"): -120,
                    ("T", "y"): -120,
                    ("T", "À"): -120,
                    ("T", "Á"): -120,
                    ("T", "Â"): -120,
                    ("T", "Ã"): -120,
                    ("T", "Ä"): -120,
                    ("T", "Å"): -120,
                    ("T", "Ò"): -40,
                    ("T", "Ó"): -40,
                    ("T", "Ô"): -40,
                    ("T", "Õ"): -40,
                    ("T", "Ö"): -40,
                    ("T", "Ø"): -40,
                    ("T", "à"): -120,
                    ("T", "á"): -120,
                    ("T", "â"): -120,
                    ("T", "ã"): -60,
                    ("T", "ä"): -120,
                    ("T", "å"): -120,
                    ("T", "è"): -60,
                    ("T", "é"): -120,
                    ("T", "ê"): -120,
                    ("T", "ë"): -120,
                    ("T", "ò"): -120,
                    ("T", "ó"): -120,
                    ("T", "ô"): -120,
                    ("T", "õ"): -60,
                    ("T", "ö"): -120,
                    ("T", "ø"): -120,
                    ("T", "ù"): -120,
                    ("T", "ú"): -120,
                    ("T", "û"): -120,
                    ("T", "ü"): -120,
                    ("T", "ý"): -120,
                    ("T", "ÿ"): -60,
                    ("U", ","): -40,
                    ("U", "."): -40,
                    ("U", "A"): -40,
                    ("U", "À"): -40,
                    ("U", "Á"): -40,
                    ("U", "Â"): -40,
                    ("U", "Ã"): -40,
                    ("U", "Ä"): -40,
                    ("U", "Å"): -40,
                    ("V", ","): -125,
                    ("V", "-"): -80,
                    ("V", "."): -125,
                    ("V", ":"): -40,
                    ("V", ";"): -40,
                    ("V", "A"): -80,
                    ("V", "G"): -40,
                    ("V", "O"): -40,
                    ("V", "a"): -70,
                    ("V", "e"): -80,
                    ("V", "o"): -80,
                    ("V", "u"): -70,
                    ("V", "À"): -80,
                    ("V", "Á"): -80,
                    ("V", "Â"): -80,
                    ("V", "Ã"): -80,
                    ("V", "Ä"): -80,
                    ("V", "Å"): -80,
                    ("V", "Ò"): -40,
                    ("V", "Ó"): -40,
                    ("V", "Ô"): -40,
                    ("V", "Õ"): -40,
                    ("V", "Ö"): -40,
                    ("V", "Ø"): -40,
                    ("V", "à"): -70,
                    ("V", "á"): -70,
                    ("V", "â"): -70,
                    ("V", "ã"): -70,
                    ("V", "ä"): -70,
                    ("V", "å"): -70,
                    ("V", "è"): -80,
                    ("V", "é"): -80,
                    ("V", "ê"): -80,
                    ("V", "ë"): -80,
                    ("V", "ò"): -80,
                    ("V", "ó"): -80,
                    ("V", "ô"): -80,
                    ("V", "õ"): -80,
                    ("V", "ö"): -80,
                    ("V", "ø"): -80,
                    ("V", "ù"): -70,
                    ("V", "ú"): -70,
                    ("V", "û"): -70,
                    ("V", "ü"): -70,
                    ("W", ","): -80,
                    ("W", "-"): -40,
                    ("W", "."): -80,
                    ("W", "A"): -50,
                    ("W", "O"): -20,
                    ("W", "a"): -40,
                    ("W", "e"): -30,
                    ("W", "o"): -30,
                    ("W", "u"): -30,
                    ("W", "y"): -20,
                    ("W", "À"): -50,
                    ("W", "Á"): -50,
                    ("W", "Â"): -50,
                    ("W", "Ã"): -50,
                    ("W", "Ä"): -50,
                    ("W", "Å"): -50,
                    ("W", "Ò"): -20,
                    ("W", "Ó"): -20,
                    ("W", "Ô"): -20,
                    ("W", "Õ"): -20,
                    ("W", "Ö"): -20,
                    ("W", "Ø"): -20,
                    ("W", "à"): -40,
                    ("W", "á"): -40,
                    ("W", "â"): -40,
                    ("W", "ã"): -40,
                    ("W", "ä"): -40,
                    ("W", "å"): -40,
                    ("W", "è"): -30,
                    ("W", "é"): -30,
                    ("W", "ê"): -30,
                    ("W", "ë"): -30,
                    ("W", "ò"): -30,
                    ("W", "ó"): -30,
                    ("W", "ô"): -30,
                    ("W", "õ"): -30,
                    ("W", "ö"): -30,
                    ("W", "ø"): -30,
                    ("W", "ù"): -30,
                    ("W", "ú"): -30,
                    ("W", "û"): -30,
                    ("W", "ü"): -30,
                    ("W", "ý"): -20,
                    ("W", "ÿ"): -20,
                    ("Y", ","): -140,
                    ("Y", "-"): -140,
                    ("Y", "."): -140,
                    ("Y", ":"): -60,
                    ("Y", ";"): -60,
                    ("Y", "A"): -110,
                    ("Y", "O"): -85,
                    ("Y", "a"): -140,
                    ("Y", "e"): -140,
                    ("Y", "i"): -20,
                    ("Y", "o"): -140,
                    ("Y", "u"): -110,
                    ("Y", "À"): -110,
                    ("Y", "Á"): -110,
                    ("Y", "Â"): -110,
                    ("Y", "Ã"): -110,
                    ("Y", "Ä"): -110,
                    ("Y", "Å"): -110,
                    ("Y", "Ò"): -85,
                    ("Y", "Ó"): -85,
                    ("Y", "Ô"): -85,
                    ("Y", "Õ"): -85,
                    ("Y", "Ö"): -85,
                    ("Y", "Ø"): -85,
                    ("Y", "à"): -140,
                    ("Y", "á"): -140,
                    ("Y", "â"): -140,
                    ("Y", "ã"): -140,
                    ("Y", "ä"): -140,
                    ("Y", "å"): -140,
                    ("Y", "è"): -140,
                    ("Y", "é"): -140,
                    ("Y", "ê"): -140,
                    ("Y", "ë"): -140,
                    ("Y", "í"): -20,
                    ("Y", "ò"): -140,
                    ("Y", "ó"): -140,
                    ("Y", "ô"): -140,
                    ("Y", "õ"): -140,
                    ("Y", "ö"): -140,
                    ("Y", "ø"): -140,
                    ("Y", "ù"): -110,
                    ("Y", "ú"): -110,
                    ("Y", "û"): -110,
                    ("Y", "ü"): -110,
                    ("a", "v"): -20,
                    ("a", "w"): -20,
                    ("a", "y"): -30,
                    ("a", "ý"): -30,
                    ("a", "ÿ"): -30,
                    ("b", ","): -40,
                    ("b", "."): -40,
                    ("b", "b"): -10,
                    ("b", "l"): -20,
                    ("b", "u"): -20,
                    ("b", "v"): -20,
                    ("b", "y"): -20,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("b", "ý"): -20,
                    ("b", "ÿ"): -20,
                    ("b", "ł"): -20,
                    ("c", ","): -15,
                    ("c", "k"): -20,
                    ("e", ","): -15,
                    ("e", "."): -15,
                    ("e", "v"): -30,
                    ("e", "w"): -20,
                    ("e", "x"): -30,
                    ("e", "y"): -20,
                    ("e", "ý"): -20,
                    ("e", "ÿ"): -20,
                    ("f", ","): -30,
                    ("f", "."): -30,
                    ("f", "a"): -30,
                    ("f", "e"): -30,
                    ("f", "o"): -30,
                    ("f", "à"): -30,
                    ("f", "á"): -30,
                    ("f", "â"): -30,
                    ("f", "ã"): -30,
                    ("f", "ä"): -30,
                    ("f", "å"): -30,
                    ("f", "è"): -30,
                    ("f", "é"): -30,
                    ("f", "ê"): -30,
                    ("f", "ë"): -30,
                    ("f", "ò"): -30,
                    ("f", "ó"): -30,
                    ("f", "ô"): -30,
                    ("f", "õ"): -30,
                    ("f", "ö"): -30,
                    ("f", "ø"): -30,
                    ("f", "ı"): -28,
                    ("f", "’"): 50,
                    ("f", "”"): 60,
                    ("g", "r"): -10,
                    ("h", "y"): -30,
                    ("h", "ý"): -30,
                    ("h", "ÿ"): -30,
                    ("k", "e"): -20,
                    ("k", "o"): -20,
                    ("k", "è"): -20,
                    ("k", "é"): -20,
                    ("k", "ê"): -20,
                    ("k", "ë"): -20,
                    ("k", "ò"): -20,
                    ("k", "ó"): -20,
                    ("k", "ô"): -20,
                    ("k", "õ"): -20,
                    ("k", "ö"): -20,
                    ("k", "ø"): -20,
                    ("m", "u"): -10,
                    ("m", "y"): -15,
                    ("m", "ù"): -10,
                    ("m", "ú"): -10,
                    ("m", "û"): -10,
                    ("m", "ü"): -10,
                    ("m", "ý"): -15,
                    ("m", "ÿ"): -15,
                    ("n", "u"): -10,
                    ("n", "v"): -20,
                    ("n", "y"): -15,
                    ("n", "ù"): -10,
                    ("n", "ú"): -10,
                    ("n", "û"): -10,
                    ("n", "ü"): -10,
                    ("n", "ý"): -15,
                    ("n", "ÿ"): -15,
                    ("o", ","): -40,
                    ("o", "."): -40,
                    ("o", "v"): -15,
                    ("o", "w"): -15,
                    ("o", "x"): -30,
                    ("o", "y"): -30,
                    ("o", "ý"): -30,
                    ("o", "ÿ"): -30,
                    ("p", ","): -35,
                    ("p", "."): -35,
                    ("p", "y"): -30,
                    ("p", "ý"): -30,
                    ("p", "ÿ"): -30,
                    ("r", ","): -50,
                    ("r", "."): -50,
                    ("r", ":"): 30,
                    ("r", ";"): 30,
                    ("r", "a"): -10,
                    ("r", "i"): 15,
                    ("r", "k"): 15,
                    ("r", "l"): 15,
                    ("r", "m"): 25,
                    ("r", "n"): 25,
                    ("r", "p"): 30,
                    ("r", "t"): 40,
                    ("r", "u"): 15,
                    ("r", "v"): 30,
                    ("r", "y"): 30,
                    ("r", "à"): -10,
                    ("r", "á"): -10,
                    ("r", "â"): -10,
                    ("r", "ã"): -10,
                    ("r", "ä"): -10,
                    ("r", "å"): -10,
                    ("r", "ì"): 15,
                    ("r", "í"): 15,
                    ("r", "î"): 15,
                    ("r", "ï"): 15,
                    ("r", "ñ"): 25,
                    ("r", "ù"): 15,
                    ("r", "ú"): 15,
                    ("r", "û"): 15,
                    ("r", "ü"): 15,
                    ("r", "ý"): 30,
                    ("r", "ÿ"): 30,
                    ("r", "ł"): 15,
                    ("s", ","): -15,
                    ("s", "."): -15,
                    ("s", "w"): -30,
                    ("v", ","): -80,
                    ("v", "."): -80,
                    ("v", "a"): -25,
                    ("v", "e"): -25,
                    ("v", "o"): -25,
                    ("v", "à"): -25,
                    ("v", "á"): -25,
                    ("v", "â"): -25,
                    ("v", "ã"): -25,
                    ("v", "ä"): -25,
                    ("v", "å"): -25,
                    ("v", "è"): -25,
                    ("v", "é"): -25,
                    ("v", "ê"): -25,
                    ("v", "ë"): -25,
                    ("v", "ò"): -25,
                    ("v", "ó"): -25,
                    ("v", "ô"): -25,
                    ("v", "õ"): -25,
                    ("v", "ö"): -25,
                    ("v", "ø"): -25,
                    ("w", ","): -60,
                    ("w", "."): -60,
                    ("w", "a"): -15,
                    ("w", "e"): -10,
                    ("w", "o"): -10,
                    ("w", "à"): -15,
                    ("w", "á"): -15,
                    ("w", "â"): -15,
                    ("w", "ã"): -15,
                    ("w", "ä"): -15,
                    ("w", "å"): -15,
                    ("w", "è"): -10,
                    ("w", "é"): -10,
                    ("w", "ê"): -10,
                    ("w", "ë"): -10,
                    ("w", "ò"): -10,
                    ("w", "ó"): -10,
                    ("w", "ô"): -10,
                    ("w", "õ"): -10,
                    ("w", "ö"): -10,
                    ("w", "ø"): -10,
                    ("x", "e"): -30,
                    ("x", "è"): -30,
                    ("x", "é"): -30,
                    ("x", "ê"): -30,
                    ("x", "ë"): -30,
                    ("y", ","): -100,
                    ("y", "."): -100,
                    ("y", "a"): -20,
                    ("y", "e"): -20,
                    ("y", "o"): -20,
                    ("y", "à"): -20,
                    ("y", "á"): -20,
                    ("y", "â"): -20,
                    ("y", "ã"): -20,
                    ("y", "ä"): -20,
                    ("y", "å"): -20,
                    ("y", "è"): -20,
                    ("y", "é"): -20,
                    ("y", "ê"): -20,
                    ("y", "ë"): -20,
                    ("y", "ò"): -20,
                    ("y", "ó"): -20,
                    ("y", "ô"): -20,
                    ("y", "õ"): -20,
                    ("y", "ö"): -20,
                    ("y", "ø"): -20,
                    ("z", "e"): -15,
                    ("z", "o"): -15,
                    ("z", "è"): -15,
                    ("z", "é"): -15,
                    ("z", "ê"): -15,
                    ("z", "ë"): -15,
                    ("z", "ò"): -15,
                    ("z", "ó"): -15,
                    ("z", "ô"): -15,
                    ("z", "õ"): -15,
                    ("z", "ö"): -15,
                    ("z", "ø"): -15,
                    ("À", "C"): -30,
                    ("À", "G"): -30,
                    ("À", "O"): -30,
                    ("À", "Q"): -30,
                    ("À", "T"): -120,
                    ("À", "U"): -50,
                    ("À", "V"): -70,
                    ("À", "W"): -50,
                    ("À", "Y"): -100,
                    ("À", "u"): -30,
                    ("À", "v"): -40,
                    ("À", "w"): -40,
                    ("À", "y"): -40,
                    ("À", "Ç"): -30,
                    ("À", "Ò"): -30,
                    ("À", "Ó"): -30,
                    ("À", "Ô"): -30,
                    ("À", "Õ"): -30,
                    ("À", "Ö"): -30,
                    ("À", "Ø"): -30,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -100,
                    ("À", "ù"): -30,
                    ("À", "ú"): -30,
                    ("À", "û"): -30,
                    ("À", "ü"): -30,
                    ("À", "ý"): -40,
                    ("À", "ÿ"): -40,
                    ("À", "Ÿ"): -100,
                    ("Á", "C"): -30,
                    ("Á", "G"): -30,
                    ("Á", "O"): -30,
                    ("Á", "Q"): -30,
                    ("Á", "T"): -120,
                    ("Á", "U"): -50,
                    ("Á", "V"): -70,
                    ("Á", "W"): -50,
                    ("Á", "Y"): -100,
                    ("Á", "u"): -30,
                    ("Á", "v"): -40,
                    ("Á", "w"): -40,
                    ("Á", "y"): -40,
                    ("Á", "Ç"): -30,
                    ("Á", "Ò"): -30,
                    ("Á", "Ó"): -30,
                    ("Á", "Ô"): -30,
                    ("Á", "Õ"): -30,
                    ("Á", "Ö"): -30,
                    ("Á", "Ø"): -30,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -100,
                    ("Á", "ù"): -30,
                    ("Á", "ú"): -30,
                    ("Á", "û"): -30,
                    ("Á", "ü"): -30,
                    ("Á", "ý"): -40,
                    ("Á", "ÿ"): -40,
                    ("Á", "Ÿ"): -100,
                    ("Â", "C"): -30,
                    ("Â", "G"): -30,
                    ("Â", "O"): -30,
                    ("Â", "Q"): -30,
                    ("Â", "T"): -120,
                    ("Â", "U"): -50,
                    ("Â", "V"): -70,
                    ("Â", "W"): -50,
                    ("Â", "Y"): -100,
                    ("Â", "u"): -30,
                    ("Â", "v"): -40,
                    ("Â", "w"): -40,
                    ("Â", "y"): -40,
                    ("Â", "Ç"): -30,
                    ("Â", "Ò"): -30,
                    ("Â", "Ó"): -30,
                    ("Â", "Ô"): -30,
                    ("Â", "Õ"): -30,
                    ("Â", "Ö"): -30,
                    ("Â", "Ø"): -30,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -100,
                    ("Â", "ù"): -30,
                    ("Â", "ú"): -30,
                    ("Â", "û"): -30,
                    ("Â", "ü"): -30,
                    ("Â", "ý"): -40,
                    ("Â", "ÿ"): -40,
                    ("Â", "Ÿ"): -100,
                    ("Ã", "C"): -30,
                    ("Ã", "G"): -30,
                    ("Ã", "O"): -30,
                    ("Ã", "Q"): -30,
                    ("Ã", "T"): -120,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -70,
                    ("Ã", "W"): -50,
                    ("Ã", "Y"): -100,
                    ("Ã", "u"): -30,
                    ("Ã", "v"): -40,
                    ("Ã", "w"): -40,
                    ("Ã", "y"): -40,
                    ("Ã", "Ç"): -30,
                    ("Ã", "Ò"): -30,
                    ("Ã", "Ó"): -30,
                    ("Ã", "Ô"): -30,
                    ("Ã", "Õ"): -30,
                    ("Ã", "Ö"): -30,
                    ("Ã", "Ø"): -30,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -100,
                    ("Ã", "ù"): -30,
                    ("Ã", "ú"): -30,
                    ("Ã", "û"): -30,
                    ("Ã", "ü"): -30,
                    ("Ã", "ý"): -40,
                    ("Ã", "ÿ"): -40,
                    ("Ã", "Ÿ"): -100,
                    ("Ä", "C"): -30,
                    ("Ä", "G"): -30,
                    ("Ä", "O"): -30,
                    ("Ä", "Q"): -30,
                    ("Ä", "T"): -120,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -70,
                    ("Ä", "W"): -50,
                    ("Ä", "Y"): -100,
                    ("Ä", "u"): -30,
                    ("Ä", "v"): -40,
                    ("Ä", "w"): -40,
                    ("Ä", "y"): -40,
                    ("Ä", "Ç"): -30,
                    ("Ä", "Ò"): -30,
                    ("Ä", "Ó"): -30,
                    ("Ä", "Ô"): -30,
                    ("Ä", "Õ"): -30,
                    ("Ä", "Ö"): -30,
                    ("Ä", "Ø"): -30,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -100,
                    ("Ä", "ù"): -30,
                    ("Ä", "ú"): -30,
                    ("Ä", "û"): -30,
                    ("Ä", "ü"): -30,
                    ("Ä", "ý"): -40,
                    ("Ä", "ÿ"): -40,
                    ("Ä", "Ÿ"): -100,
                    ("Å", "C"): -30,
                    ("Å", "G"): -30,
                    ("Å", "O"): -30,
                    ("Å", "Q"): -30,
                    ("Å", "T"): -120,
                    ("Å", "U"): -50,
                    ("Å", "V"): -70,
                    ("Å", "W"): -50,
                    ("Å", "Y"): -100,
                    ("Å", "u"): -30,
                    ("Å", "v"): -40,
                    ("Å", "w"): -40,
                    ("Å", "y"): -40,
                    ("Å", "Ç"): -30,
                    ("Å", "Ò"): -30,
                    ("Å", "Ó"): -30,
                    ("Å", "Ô"): -30,
                    ("Å", "Õ"): -30,
                    ("Å", "Ö"): -30,
                    ("Å", "Ø"): -30,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -100,
                    ("Å", "ù"): -30,
                    ("Å", "ú"): -30,
                    ("Å", "û"): -30,
                    ("Å", "ü"): -30,
                    ("Å", "ý"): -40,
                    ("Å", "ÿ"): -40,
                    ("Å", "Ÿ"): -100,
                    ("Ç", ","): -30,
                    ("Ç", "."): -30,
                    ("Ò", ","): -40,
                    ("Ò", "."): -40,
                    ("Ò", "A"): -20,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -30,
                    ("Ò", "X"): -60,
                    ("Ò", "Y"): -70,
                    ("Ò", "À"): -20,
                    ("Ò", "Á"): -20,
                    ("Ò", "Â"): -20,
                    ("Ò", "Ã"): -20,
                    ("Ò", "Ä"): -20,
                    ("Ò", "Å"): -20,
                    ("Ò", "Ý"): -70,
                    ("Ò", "Ÿ"): -70,
                    ("Ó", ","): -40,
                    ("Ó", "."): -40,
                    ("Ó", "A"): -20,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -30,
                    ("Ó", "X"): -60,
                    ("Ó", "Y"): -70,
                    ("Ó", "À"): -20,
                    ("Ó", "Á"): -20,
                    ("Ó", "Â"): -20,
                    ("Ó", "Ã"): -20,
                    ("Ó", "Ä"): -20,
                    ("Ó", "Å"): -20,
                    ("Ó", "Ý"): -70,
                    ("Ó", "Ÿ"): -70,
                    ("Ô", ","): -40,
                    ("Ô", "."): -40,
                    ("Ô", "A"): -20,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -30,
                    ("Ô", "X"): -60,
                    ("Ô", "Y"): -70,
                    ("Ô", "À"): -20,
                    ("Ô", "Á"): -20,
                    ("Ô", "Â"): -20,
                    ("Ô", "Ã"): -20,
                    ("Ô", "Ä"): -20,
                    ("Ô", "Å"): -20,
                    ("Ô", "Ý"): -70,
                    ("Ô", "Ÿ"): -70,
                    ("Õ", ","): -40,
                    ("Õ", "."): -40,
                    ("Õ", "A"): -20,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -30,
                    ("Õ", "X"): -60,
                    ("Õ", "Y"): -70,
                    ("Õ", "À"): -20,
                    ("Õ", "Á"): -20,
                    ("Õ", "Â"): -20,
                    ("Õ", "Ã"): -20,
                    ("Õ", "Ä"): -20,
                    ("Õ", "Å"): -20,
                    ("Õ", "Ý"): -70,
                    ("Õ", "Ÿ"): -70,
                    ("Ö", ","): -40,
                    ("Ö", "."): -40,
                    ("Ö", "A"): -20,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -30,
                    ("Ö", "X"): -60,
                    ("Ö", "Y"): -70,
                    ("Ö", "À"): -20,
                    ("Ö", "Á"): -20,
                    ("Ö", "Â"): -20,
                    ("Ö", "Ã"): -20,
                    ("Ö", "Ä"): -20,
                    ("Ö", "Å"): -20,
                    ("Ö", "Ý"): -70,
                    ("Ö", "Ÿ"): -70,
                    ("Ø", ","): -40,
                    ("Ø", "."): -40,
                    ("Ø", "A"): -20,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -30,
                    ("Ø", "X"): -60,
                    ("Ø", "Y"): -70,
                    ("Ø", "À"): -20,
                    ("Ø", "Á"): -20,
                    ("Ø", "Â"): -20,
                    ("Ø", "Ã"): -20,
                    ("Ø", "Ä"): -20,
                    ("Ø", "Å"): -20,
                    ("Ø", "Ý"): -70,
                    ("Ø", "Ÿ"): -70,
                    ("Ù", ","): -40,
                    ("Ù", "."): -40,
                    ("Ù", "A"): -40,
                    ("Ù", "À"): -40,
                    ("Ù", "Á"): -40,
                    ("Ù", "Â"): -40,
                    ("Ù", "Ã"): -40,
                    ("Ù", "Ä"): -40,
                    ("Ù", "Å"): -40,
                    ("Ú", ","): -40,
                    ("Ú", "."): -40,
                    ("Ú", "A"): -40,
                    ("Ú", "À"): -40,
                    ("Ú", "Á"): -40,
                    ("Ú", "Â"): -40,
                    ("Ú", "Ã"): -40,
                    ("Ú", "Ä"): -40,
                    ("Ú", "Å"): -40,
                    ("Û", ","): -40,
                    ("Û", "."): -40,
                    ("Û", "A"): -40,
                    ("Û", "À"): -40,
                    ("Û", "Á"): -40,
                    ("Û", "Â"): -40,
                    ("Û", "Ã"): -40,
                    ("Û", "Ä"): -40,
                    ("Û", "Å"): -40,
                    ("Ü", ","): -40,
                    ("Ü", "."): -40,
                    ("Ü", "A"): -40,
                    ("Ü", "À"): -40,
                    ("Ü", "Á"): -40,
                    ("Ü", "Â"): -40,
                    ("Ü", "Ã"): -40,
                    ("Ü", "Ä"): -40,
                    ("Ü", "Å"): -40,
                    ("Ý", ","): -140,
                    ("Ý", "-"): -140,
                    ("Ý", "."): -140,
                    ("Ý", ":"): -60,
                    ("Ý", ";"): -60,
                    ("Ý", "A"): -110,
                    ("Ý", "O"): -85,
                    ("Ý", "a"): -140,
                    ("Ý", "e"): -140,
                    ("Ý", "i"): -20,
                    ("Ý", "o"): -140,
                    ("Ý", "u"): -110,
                    ("Ý", "À"): -110,
                    ("Ý", "Á"): -110,
                    ("Ý", "Â"): -110,
                    ("Ý", "Ã"): -110,
                    ("Ý", "Ä"): -110,
                    ("Ý", "Å"): -110,
                    ("Ý", "Ò"): -85,
                    ("Ý", "Ó"): -85,
                    ("Ý", "Ô"): -85,
                    ("Ý", "Õ"): -85,
                    ("Ý", "Ö"): -85,
                    ("Ý", "Ø"): -85,
                    ("Ý", "à"): -140,
                    ("Ý", "á"): -140,
                    ("Ý", "â"): -140,
                    ("Ý", "ã"): -70,
                    ("Ý", "ä"): -140,
                    ("Ý", "å"): -140,
                    ("Ý", "è"): -140,
                    ("Ý", "é"): -140,
                    ("Ý", "ê"): -140,
                    ("Ý", "ë"): -140,
                    ("Ý", "í"): -20,
                    ("Ý", "ò"): -140,
                    ("Ý", "ó"): -140,
                    ("Ý", "ô"): -140,
                    ("Ý", "õ"): -140,
                    ("Ý", "ö"): -140,
                    ("Ý", "ø"): -140,
                    ("Ý", "ù"): -110,
                    ("Ý", "ú"): -110,
                    ("Ý", "û"): -110,
                    ("Ý", "ü"): -110,
                    ("à", "v"): -20,
                    ("à", "w"): -20,
                    ("à", "y"): -30,
                    ("à", "ý"): -30,
                    ("à", "ÿ"): -30,
                    ("á", "v"): -20,
                    ("á", "w"): -20,
                    ("á", "y"): -30,
                    ("á", "ý"): -30,
                    ("á", "ÿ"): -30,
                    ("â", "v"): -20,
                    ("â", "w"): -20,
                    ("â", "y"): -30,
                    ("â", "ý"): -30,
                    ("â", "ÿ"): -30,
                    ("ã", "v"): -20,
                    ("ã", "w"): -20,
                    ("ã", "y"): -30,
                    ("ã", "ý"): -30,
                    ("ã", "ÿ"): -30,
                    ("ä", "v"): -20,
                    ("ä", "w"): -20,
                    ("ä", "y"): -30,
                    ("ä", "ý"): -30,
                    ("ä", "ÿ"): -30,
                    ("å", "v"): -20,
                    ("å", "w"): -20,
                    ("å", "y"): -30,
                    ("å", "ý"): -30,
                    ("å", "ÿ"): -30,
                    ("ç", ","): -15,
                    ("ç", "k"): -20,
                    ("è", ","): -15,
                    ("è", "."): -15,
                    ("è", "v"): -30,
                    ("è", "w"): -20,
                    ("è", "x"): -30,
                    ("è", "y"): -20,
                    ("è", "ý"): -20,
                    ("è", "ÿ"): -20,
                    ("é", ","): -15,
                    ("é", "."): -15,
                    ("é", "v"): -30,
                    ("é", "w"): -20,
                    ("é", "x"): -30,
                    ("é", "y"): -20,
                    ("é", "ý"): -20,
                    ("é", "ÿ"): -20,
                    ("ê", ","): -15,
                    ("ê", "."): -15,
                    ("ê", "v"): -30,
                    ("ê", "w"): -20,
                    ("ê", "x"): -30,
                    ("ê", "y"): -20,
                    ("ê", "ý"): -20,
                    ("ê", "ÿ"): -20,
                    ("ë", ","): -15,
                    ("ë", "."): -15,
                    ("ë", "v"): -30,
                    ("ë", "w"): -20,
                    ("ë", "x"): -30,
                    ("ë", "y"): -20,
                    ("ë", "ý"): -20,
                    ("ë", "ÿ"): -20,
                    ("ñ", "u"): -10,
                    ("ñ", "v"): -20,
                    ("ñ", "y"): -15,
                    ("ñ", "ù"): -10,
                    ("ñ", "ú"): -10,
                    ("ñ", "û"): -10,
                    ("ñ", "ü"): -10,
                    ("ñ", "ý"): -15,
                    ("ñ", "ÿ"): -15,
                    ("ò", ","): -40,
                    ("ò", "."): -40,
                    ("ò", "v"): -15,
                    ("ò", "w"): -15,
                    ("ò", "x"): -30,
                    ("ò", "y"): -30,
                    ("ò", "ý"): -30,
                    ("ò", "ÿ"): -30,
                    ("ó", ","): -40,
                    ("ó", "."): -40,
                    ("ó", "v"): -15,
                    ("ó", "w"): -15,
                    ("ó", "x"): -30,
                    ("ó", "y"): -30,
                    ("ó", "ý"): -30,
                    ("ó", "ÿ"): -30,
                    ("ô", ","): -40,
                    ("ô", "."): -40,
                    ("ô", "v"): -15,
                    ("ô", "w"): -15,
                    ("ô", "x"): -30,
                    ("ô", "y"): -30,
                    ("ô", "ý"): -30,
                    ("ô", "ÿ"): -30,
                    ("õ", ","): -40,
                    ("õ", "."): -40,
                    ("õ", "v"): -15,
                    ("õ", "w"): -15,
                    ("õ", "x"): -30,
                    ("õ", "y"): -30,
                    ("õ", "ý"): -30,
                    ("õ", "ÿ"): -30,
                    ("ö", ","): -40,
                    ("ö", "."): -40,
                    ("ö", "v"): -15,
                    ("ö", "w"): -15,
                    ("ö", "x"): -30,
                    ("ö", "y"): -30,
                    ("ö", "ý"): -30,
                    ("ö", "ÿ"): -30,
                    ("ø", ","): -95,
                    ("ø", "."): -95,
                    ("ø", "a"): -55,
                    ("ø", "b"): -55,
                    ("ø", "c"): -55,
                    ("ø", "d"): -55,
                    ("ø", "e"): -55,
                    ("ø", "f"): -55,
                    ("ø", "g"): -55,
                    ("ø", "h"): -55,
                    ("ø", "i"): -55,
                    ("ø", "j"): -55,
                    ("ø", "k"): -55,
                    ("ø", "l"): -55,
                    ("ø", "m"): -55,
                    ("ø", "n"): -55,
                    ("ø", "o"): -55,
                    ("ø", "p"): -55,
                    ("ø", "q"): -55,
                    ("ø", "r"): -55,
                    ("ø", "s"): -55,
                    ("ø", "t"): -55,
                    ("ø", "u"): -55,
                    ("ø", "v"): -70,
                    ("ø", "w"): -70,
                    ("ø", "x"): -85,
                    ("ø", "y"): -70,
                    ("ø", "z"): -55,
                    ("ø", "à"): -55,
                    ("ø", "á"): -55,
                    ("ø", "â"): -55,
                    ("ø", "ã"): -55,
                    ("ø", "ä"): -55,
                    ("ø", "å"): -55,
                    ("ø", "ç"): -55,
                    ("ø", "è"): -55,
                    ("ø", "é"): -55,
                    ("ø", "ê"): -55,
                    ("ø", "ë"): -55,
                    ("ø", "ì"): -55,
                    ("ø", "í"): -55,
                    ("ø", "î"): -55,
                    ("ø", "ï"): -55,
                    ("ø", "ñ"): -55,
                    ("ø", "ò"): -55,
                    ("ø", "ó"): -55,
                    ("ø", "ô"): -55,
                    ("ø", "õ"): -55,
                    ("ø", "ö"): -55,
                    ("ø", "ø"): -55,
                    ("ø", "ù"): -55,
                    ("ø", "ú"): -55,
                    ("ø", "û"): -55,
                    ("ø", "ü"): -55,
                    ("ø", "ý"): -70,
                    ("ø", "ÿ"): -70,
                    ("ø", "ł"): -55,
                    ("ø", "š"): -55,
                    ("ø", "ž"): -55,
                    ("ý", ","): -100,
                    ("ý", "."): -100,
                    ("ý", "a"): -20,
                    ("ý", "e"): -20,
                    ("ý", "o"): -20,
                    ("ý", "à"): -20,
                    ("ý", "á"): -20,
                    ("ý", "â"): -20,
                    ("ý", "ã"): -20,
                    ("ý", "ä"): -20,
                    ("ý", "å"): -20,
                    ("ý", "è"): -20,
                    ("ý", "é"): -20,
                    ("ý", "ê"): -20,
                    ("ý", "ë"): -20,
                    ("ý", "ò"): -20,
                    ("ý", "ó"): -20,
                    ("ý", "ô"): -20,
                    ("ý", "õ"): -20,
                    ("ý", "ö"): -20,
                    ("ý", "ø"): -20,
                    ("ÿ", ","): -100,
                    ("ÿ", "."): -100,
                    ("ÿ", "a"): -20,
                    ("ÿ", "e"): -20,
                    ("ÿ", "o"): -20,
                    ("ÿ", "à"): -20,
                    ("ÿ", "á"): -20,
                    ("ÿ", "â"): -20,
                    ("ÿ", "ã"): -20,
                    ("ÿ", "ä"): -20,
                    ("ÿ", "å"): -20,
                    ("ÿ", "è"): -20,
                    ("ÿ", "é"): -20,
                    ("ÿ", "ê"): -20,
                    ("ÿ", "ë"): -20,
                    ("ÿ", "ò"): -20,
                    ("ÿ", "ó"): -20,
                    ("ÿ", "ô"): -20,
                    ("ÿ", "õ"): -20,
                    ("ÿ", "ö"): -20,
                    ("ÿ", "ø"): -20,
                    ("Ł", "T"): -110,
                    ("Ł", "V"): -110,
                    ("Ł", "W"): -70,
                    ("Ł", "Y"): -140,
                    ("Ł", "y"): -30,
                    ("Ł", "Ý"): -140,
                    ("Ł", "ý"): -30,
                    ("Ł", "ÿ"): -30,
                    ("Ł", "Ÿ"): -140,
                    ("Ł", "’"): -160,
                    ("Ł", "”"): -140,
                    ("Š", ","): -20,
                    ("Š", "."): -20,
                    ("š", ","): -15,
                    ("š", "."): -15,
                    ("š", "w"): -30,
                    ("Ÿ", ","): -140,
                    ("Ÿ", "-"): -140,
                    ("Ÿ", "."): -140,
                    ("Ÿ", ":"): -60,
                    ("Ÿ", ";"): -60,
                    ("Ÿ", "A"): -110,
                    ("Ÿ", "O"): -85,
                    ("Ÿ", "a"): -140,
                    ("Ÿ", "e"): -140,
                    ("Ÿ", "i"): -20,
                    ("Ÿ", "o"): -140,
                    ("Ÿ", "u"): -110,
                    ("Ÿ", "À"): -110,
                    ("Ÿ", "Á"): -110,
                    ("Ÿ", "Â"): -110,
                    ("Ÿ", "Ã"): -110,
                    ("Ÿ", "Ä"): -110,
                    ("Ÿ", "Å"): -110,
                    ("Ÿ", "Ò"): -85,
                    ("Ÿ", "Ó"): -85,
                    ("Ÿ", "Ô"): -85,
                    ("Ÿ", "Õ"): -85,
                    ("Ÿ", "Ö"): -85,
                    ("Ÿ", "Ø"): -85,
                    ("Ÿ", "à"): -140,
                    ("Ÿ", "á"): -140,
                    ("Ÿ", "â"): -140,
                    ("Ÿ", "ã"): -70,
                    ("Ÿ", "ä"): -140,
                    ("Ÿ", "å"): -140,
                    ("Ÿ", "è"): -140,
                    ("Ÿ", "é"): -140,
                    ("Ÿ", "ê"): -140,
                    ("Ÿ", "ë"): -140,
                    ("Ÿ", "í"): -20,
                    ("Ÿ", "ò"): -140,
                    ("Ÿ", "ó"): -140,
                    ("Ÿ", "ô"): -140,
                    ("Ÿ", "õ"): -140,
                    ("Ÿ", "ö"): -140,
                    ("Ÿ", "ø"): -140,
                    ("Ÿ", "ù"): -110,
                    ("Ÿ", "ú"): -110,
                    ("Ÿ", "û"): -110,
                    ("Ÿ", "ü"): -110,
                    ("ž", "e"): -15,
                    ("ž", "o"): -15,
                    ("ž", "è"): -15,
                    ("ž", "é"): -15,
                    ("ž", "ê"): -15,
                    ("ž", "ë"): -15,
                    ("ž", "ò"): -15,
                    ("ž", "ó"): -15,
                    ("ž", "ô"): -15,
                    ("ž", "õ"): -15,
                    ("ž", "ö"): -15,
                    ("ž", "ø"): -15,
                    ("‘", "‘"): -57,
                    ("’", " "): -70,
                    ("’", "d"): -50,
                    ("’", "r"): -50,
                    ("’", "s"): -50,
                    ("’", "š"): -50,
                    ("’", "’"): -57,
                    ("”", " "): -40,
                },
                0,
            ),
        ),
        BuiltinFont(
            b"Helvetica-BoldOblique",
            b"f3",
            dictget(
                {
                    " ": 278,
                    "!": 333,
                    '"': 474,
                    "#": 556,
                    "$": 556,
                    "%": 889,
                    "&": 722,
                    "'": 238,
                    "(": 333,
                    ")": 333,
                    "*": 389,
                    "+": 584,
                    ",": 278,
                    "-": 333,
                    ".": 278,
                    "/": 278,
                    "0": 556,
                    "1": 556,
                    "2": 556,
                    "3": 556,
                    "4": 556,
                    "5": 556,
                    "6": 556,
                    "7": 556,
                    "8": 556,
                    "9": 556,
                    ":": 333,
                    ";": 333,
                    "<": 584,
                    "=": 584,
                    ">": 584,
                    "?": 611,
                    "@": 975,
                    "A": 722,
                    "B": 722,
                    "C": 722,
                    "D": 722,
                    "E": 667,
                    "F": 611,
                    "G": 778,
                    "H": 722,
                    "I": 278,
                    "J": 556,
                    "K": 722,
                    "L": 611,
                    "M": 833,
                    "N": 722,
                    "O": 778,
                    "P": 667,
                    "Q": 778,
                    "R": 722,
                    "S": 667,
                    "T": 611,
                    "U": 722,
                    "V": 667,
                    "W": 944,
                    "X": 667,
                    "Y": 667,
                    "Z": 611,
                    "[": 333,
                    "\\": 278,
                    "]": 333,
                    "^": 584,
                    "_": 556,
                    "`": 333,
                    "a": 556,
                    "b": 611,
                    "c": 556,
                    "d": 611,
                    "e": 556,
                    "f": 333,
                    "g": 611,
                    "h": 611,
                    "i": 278,
                    "j": 278,
                    "k": 556,
                    "l": 278,
                    "m": 889,
                    "n": 611,
                    "o": 611,
                    "p": 611,
                    "q": 611,
                    "r": 389,
                    "s": 556,
                    "t": 333,
                    "u": 611,
                    "v": 556,
                    "w": 778,
                    "x": 556,
                    "y": 556,
                    "z": 500,
                    "{": 389,
                    "|": 280,
                    "}": 389,
                    "~": 584,
                    "¡": 333,
                    "¢": 556,
                    "£": 556,
                    "¤": 556,
                    "¥": 556,
                    "¦": 280,
                    "§": 556,
                    "©": 737,
                    "ª": 370,
                    "«": 556,
                    "¬": 584,
                    "®": 737,
                    "°": 400,
                    "±": 584,
                    "²": 333,
                    "³": 333,
                    "¶": 556,
                    "·": 278,
                    "¹": 333,
                    "º": 365,
                    "»": 556,
                    "¼": 834,
                    "½": 834,
                    "¾": 834,
                    "¿": 611,
                    "À": 722,
                    "Á": 722,
                    "Â": 722,
                    "Ã": 722,
                    "Ä": 722,
                    "Å": 722,
                    "Æ": 1000,
                    "Ç": 722,
                    "È": 667,
                    "É": 667,
                    "Ê": 667,
                    "Ë": 667,
                    "Ì": 278,
                    "Í": 278,
                    "Î": 278,
                    "Ï": 278,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 778,
                    "Ó": 778,
                    "Ô": 778,
                    "Õ": 778,
                    "Ö": 778,
                    "×": 584,
                    "Ø": 778,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 667,
                    "Þ": 667,
                    "ß": 611,
                    "à": 556,
                    "á": 556,
                    "â": 556,
                    "ã": 556,
                    "ä": 556,
                    "å": 556,
                    "æ": 889,
                    "ç": 556,
                    "è": 556,
                    "é": 556,
                    "ê": 556,
                    "ë": 556,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 611,
                    "ñ": 611,
                    "ò": 611,
                    "ó": 611,
                    "ô": 611,
                    "õ": 611,
                    "ö": 611,
                    "÷": 584,
                    "ø": 611,
                    "ù": 611,
                    "ú": 611,
                    "û": 611,
                    "ü": 611,
                    "ý": 556,
                    "þ": 611,
                    "ÿ": 556,
                    "ı": 278,
                    "Ł": 611,
                    "ł": 278,
                    "Œ": 1000,
                    "œ": 944,
                    "Š": 667,
                    "š": 556,
                    "Ÿ": 667,
                    "Ž": 611,
                    "ž": 500,
                    "ƒ": 556,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 611,
                    "–": 556,
                    "—": 1000,
                    "‘": 278,
                    "’": 278,
                    "‚": 278,
                    "“": 500,
                    "”": 500,
                    "„": 500,
                    "†": 556,
                    "‡": 556,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 556,
                    "™": 1000,
                    "−": 584,
                    "ﬁ": 611,
                    "ﬂ": 611,
                },
                611,
            ),
            dictget(
                {
                    (" ", "T"): -100,
                    (" ", "V"): -80,
                    (" ", "W"): -80,
                    (" ", "Y"): -120,
                    (" ", "Ý"): -120,
                    (" ", "Ÿ"): -120,
                    (" ", "‘"): -60,
                    (" ", "“"): -80,
                    (",", " "): -40,
                    (",", "’"): -120,
                    (",", "”"): -120,
                    (".", " "): -40,
                    (".", "’"): -120,
                    (".", "”"): -120,
                    (":", " "): -40,
                    (";", " "): -40,
                    ("A", "C"): -40,
                    ("A", "G"): -50,
                    ("A", "O"): -40,
                    ("A", "Q"): -40,
                    ("A", "T"): -90,
                    ("A", "U"): -50,
                    ("A", "V"): -80,
                    ("A", "W"): -60,
                    ("A", "Y"): -110,
                    ("A", "u"): -30,
                    ("A", "v"): -40,
                    ("A", "w"): -30,
                    ("A", "y"): -30,
                    ("A", "Ç"): -40,
                    ("A", "Ò"): -40,
                    ("A", "Ó"): -40,
                    ("A", "Ô"): -40,
                    ("A", "Õ"): -40,
                    ("A", "Ö"): -40,
                    ("A", "Ø"): -40,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -110,
                    ("A", "ù"): -30,
                    ("A", "ú"): -30,
                    ("A", "û"): -30,
                    ("A", "ü"): -30,
                    ("A", "ý"): -30,
                    ("A", "ÿ"): -30,
                    ("A", "Ÿ"): -110,
                    ("B", "A"): -30,
                    ("B", "U"): -10,
                    ("B", "À"): -30,
                    ("B", "Á"): -30,
                    ("B", "Â"): -30,
                    ("B", "Ã"): -30,
                    ("B", "Ä"): -30,
                    ("B", "Å"): -30,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("D", ","): -30,
                    ("D", "."): -30,
                    ("D", "A"): -40,
                    ("D", "V"): -40,
                    ("D", "W"): -40,
                    ("D", "Y"): -70,
                    ("D", "À"): -40,
                    ("D", "Á"): -40,
                    ("D", "Â"): -40,
                    ("D", "Ã"): -40,
                    ("D", "Ä"): -40,
                    ("D", "Å"): -40,
                    ("D", "Ý"): -70,
                    ("D", "Ÿ"): -70,
                    ("F", ","): -100,
                    ("F", "."): -100,
                    ("F", "A"): -80,
                    ("F", "a"): -20,
                    ("F", "À"): -80,
                    ("F", "Á"): -80,
                    ("F", "Â"): -80,
                    ("F", "Ã"): -80,
                    ("F", "Ä"): -80,
                    ("F", "Å"): -80,
                    ("F", "à"): -20,
                    ("F", "á"): -20,
                    ("F", "â"): -20,
                    ("F", "ã"): -20,
                    ("F", "ä"): -20,
                    ("F", "å"): -20,
                    ("J", ","): -20,
                    ("J", "."): -20,
                    ("J", "A"): -20,
                    ("J", "u"): -20,
                    ("J", "À"): -20,
                    ("J", "Á"): -20,
                    ("J", "Â"): -20,
                    ("J", "Ã"): -20,
                    ("J", "Ä"): -20,
                    ("J", "Å"): -20,
                    ("J", "ù"): -20,
                    ("J", "ú"): -20,
                    ("J", "û"): -20,
                    ("J", "ü"): -20,
                    ("K", "O"): -30,
                    ("K", "e"): -15,
                    ("K", "o"): -35,
                    ("K", "u"): -30,
                    ("K", "y"): -40,
                    ("K", "Ò"): -30,
                    ("K", "Ó"): -30,
                    ("K", "Ô"): -30,
                    ("K", "Õ"): -30,
                    ("K", "Ö"): -30,
                    ("K", "Ø"): -30,
                    ("K", "è"): -15,
                    ("K", "é"): -15,
                    ("K", "ê"): -15,
                    ("K", "ë"): -15,
                    ("K", "ò"): -35,
                    ("K", "ó"): -35,
                    ("K", "ô"): -35,
                    ("K", "õ"): -35,
                    ("K", "ö"): -35,
                    ("K", "ø"): -35,
                    ("K", "ù"): -30,
                    ("K", "ú"): -30,
                    ("K", "û"): -30,
                    ("K", "ü"): -30,
                    ("K", "ý"): -40,
                    ("K", "ÿ"): -40,
                    ("L", "T"): -90,
                    ("L", "V"): -110,
                    ("L", "W"): -80,
                    ("L", "Y"): -120,
                    ("L", "y"): -30,
                    ("L", "Ý"): -120,
                    ("L", "ý"): -30,
                    ("L", "ÿ"): -30,
                    ("L", "Ÿ"): -120,
                    ("L", "’"): -140,
                    ("L", "”"): -140,
                    ("O", ","): -40,
                    ("O", "."): -40,
                    ("O", "A"): -50,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -50,
                    ("O", "X"): -50,
                    ("O", "Y"): -70,
                    ("O", "À"): -50,
                    ("O", "Á"): -50,
                    ("O", "Â"): -50,
                    ("O", "Ã"): -50,
                    ("O", "Ä"): -50,
                    ("O", "Å"): -50,
                    ("O", "Ý"): -70,
                    ("O", "Ÿ"): -70,
                    ("P", ","): -120,
                    ("P", "."): -120,
                    ("P", "A"): -100,
                    ("P", "a"): -30,
                    ("P", "e"): -30,
                    ("P", "o"): -40,
                    ("P", "À"): -100,
                    ("P", "Á"): -100,
                    ("P", "Â"): -100,
                    ("P", "Ã"): -100,
                    ("P", "Ä"): -100,
                    ("P", "Å"): -100,
                    ("P", "à"): -30,
                    ("P", "á"): -30,
                    ("P", "â"): -30,
                    ("P", "ã"): -30,
                    ("P", "ä"): -30,
                    ("P", "å"): -30,
                    ("P", "è"): -30,
                    ("P", "é"): -30,
                    ("P", "ê"): -30,
                    ("P", "ë"): -30,
                    ("P", "ò"): -40,
                    ("P", "ó"): -40,
                    ("P", "ô"): -40,
                    ("P", "õ"): -40,
                    ("P", "ö"): -40,
                    ("P", "ø"): -40,
                    ("Q", ","): 20,
                    ("Q", "."): 20,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -20,
                    ("R", "T"): -20,
                    ("R", "U"): -20,
                    ("R", "V"): -50,
                    ("R", "W"): -40,
                    ("R", "Y"): -50,
                    ("R", "Ò"): -20,
                    ("R", "Ó"): -20,
                    ("R", "Ô"): -20,
                    ("R", "Õ"): -20,
                    ("R", "Ö"): -20,
                    ("R", "Ø"): -20,
                    ("R", "Ù"): -20,
                    ("R", "Ú"): -20,
                    ("R", "Û"): -20,
                    ("R", "Ü"): -20,
                    ("R", "Ý"): -50,
                    ("R", "Ÿ"): -50,
                    ("T", ","): -80,
                    ("T", "-"): -120,
                    ("T", "."): -80,
                    ("T", ":"): -40,
                    ("T", ";"): -40,
                    ("T", "A"): -90,
                    ("T", "O"): -40,
                    ("T", "a"): -80,
                    ("T", "e"): -60,
                    ("T", "o"): -80,
                    ("T", "r"): -80,
                    ("T", "u"): -90,
                    ("T", "w"): -60,
                    ("T", "y"): -60,
                    ("T", "À"): -90,
                    ("T", "Á"): -90,
                    ("T", "Â"): -90,
                    ("T", "Ã"): -90,
                    ("T", "Ä"): -90,
                    ("T", "Å"): -90,
                    ("T", "Ò"): -40,
                    ("T", "Ó"): -40,
                    ("T", "Ô"): -40,
                    ("T", "Õ"): -40,
                    ("T", "Ö"): -40,
                    ("T", "Ø"): -40,
                    ("T", "à"): -80,
                    ("T", "á"): -80,
                    ("T", "â"): -80,
                    ("T", "ã"): -80,
                    ("T", "ä"): -80,
                    ("T", "å"): -80,
                    ("T", "è"): -60,
                    ("T", "é"): -60,
                    ("T", "ê"): -60,
                    ("T", "ë"): -60,
                    ("T", "ò"): -80,
                    ("T", "ó"): -80,
                    ("T", "ô"): -80,
                    ("T", "õ"): -80,
                    ("T", "ö"): -80,
                    ("T", "ø"): -80,
                    ("T", "ù"): -90,
                    ("T", "ú"): -90,
                    ("T", "û"): -90,
                    ("T", "ü"): -90,
                    ("T", "ý"): -60,
                    ("T", "ÿ"): -60,
                    ("U", ","): -30,
                    ("U", "."): -30,
                    ("U", "A"): -50,
                    ("U", "À"): -50,
                    ("U", "Á"): -50,
                    ("U", "Â"): -50,
                    ("U", "Ã"): -50,
                    ("U", "Ä"): -50,
                    ("U", "Å"): -50,
                    ("V", ","): -120,
                    ("V", "-"): -80,
                    ("V", "."): -120,
                    ("V", ":"): -40,
                    ("V", ";"): -40,
                    ("V", "A"): -80,
                    ("V", "G"): -50,
                    ("V", "O"): -50,
                    ("V", "a"): -60,
                    ("V", "e"): -50,
                    ("V", "o"): -90,
                    ("V", "u"): -60,
                    ("V", "À"): -80,
                    ("V", "Á"): -80,
                    ("V", "Â"): -80,
                    ("V", "Ã"): -80,
                    ("V", "Ä"): -80,
                    ("V", "Å"): -80,
                    ("V", "Ò"): -50,
                    ("V", "Ó"): -50,
                    ("V", "Ô"): -50,
                    ("V", "Õ"): -50,
                    ("V", "Ö"): -50,
                    ("V", "Ø"): -50,
                    ("V", "à"): -60,
                    ("V", "á"): -60,
                    ("V", "â"): -60,
                    ("V", "ã"): -60,
                    ("V", "ä"): -60,
                    ("V", "å"): -60,
                    ("V", "è"): -50,
                    ("V", "é"): -50,
                    ("V", "ê"): -50,
                    ("V", "ë"): -50,
                    ("V", "ò"): -90,
                    ("V", "ó"): -90,
                    ("V", "ô"): -90,
                    ("V", "õ"): -90,
                    ("V", "ö"): -90,
                    ("V", "ø"): -90,
                    ("V", "ù"): -60,
                    ("V", "ú"): -60,
                    ("V", "û"): -60,
                    ("V", "ü"): -60,
                    ("W", ","): -80,
                    ("W", "-"): -40,
                    ("W", "."): -80,
                    ("W", ":"): -10,
                    ("W", ";"): -10,
                    ("W", "A"): -60,
                    ("W", "O"): -20,
                    ("W", "a"): -40,
                    ("W", "e"): -35,
                    ("W", "o"): -60,
                    ("W", "u"): -45,
                    ("W", "y"): -20,
                    ("W", "À"): -60,
                    ("W", "Á"): -60,
                    ("W", "Â"): -60,
                    ("W", "Ã"): -60,
                    ("W", "Ä"): -60,
                    ("W", "Å"): -60,
                    ("W", "Ò"): -20,
                    ("W", "Ó"): -20,
                    ("W", "Ô"): -20,
                    ("W", "Õ"): -20,
                    ("W", "Ö"): -20,
                    ("W", "Ø"): -20,
                    ("W", "à"): -40,
                    ("W", "á"): -40,
                    ("W", "â"): -40,
                    ("W", "ã"): -40,
                    ("W", "ä"): -40,
                    ("W", "å"): -40,
                    ("W", "è"): -35,
                    ("W", "é"): -35,
                    ("W", "ê"): -35,
                    ("W", "ë"): -35,
                    ("W", "ò"): -60,
                    ("W", "ó"): -60,
                    ("W", "ô"): -60,
                    ("W", "õ"): -60,
                    ("W", "ö"): -60,
                    ("W", "ø"): -60,
                    ("W", "ù"): -45,
                    ("W", "ú"): -45,
                    ("W", "û"): -45,
                    ("W", "ü"): -45,
                    ("W", "ý"): -20,
                    ("W", "ÿ"): -20,
                    ("Y", ","): -100,
                    ("Y", "."): -100,
                    ("Y", ":"): -50,
                    ("Y", ";"): -50,
                    ("Y", "A"): -110,
                    ("Y", "O"): -70,
                    ("Y", "a"): -90,
                    ("Y", "e"): -80,
                    ("Y", "o"): -100,
                    ("Y", "u"): -100,
                    ("Y", "À"): -110,
                    ("Y", "Á"): -110,
                    ("Y", "Â"): -110,
                    ("Y", "Ã"): -110,
                    ("Y", "Ä"): -110,
                    ("Y", "Å"): -110,
                    ("Y", "Ò"): -70,
                    ("Y", "Ó"): -70,
                    ("Y", "Ô"): -70,
                    ("Y", "Õ"): -70,
                    ("Y", "Ö"): -70,
                    ("Y", "Ø"): -70,
                    ("Y", "à"): -90,
                    ("Y", "á"): -90,
                    ("Y", "â"): -90,
                    ("Y", "ã"): -90,
                    ("Y", "ä"): -90,
                    ("Y", "å"): -90,
                    ("Y", "è"): -80,
                    ("Y", "é"): -80,
                    ("Y", "ê"): -80,
                    ("Y", "ë"): -80,
                    ("Y", "ò"): -100,
                    ("Y", "ó"): -100,
                    ("Y", "ô"): -100,
                    ("Y", "õ"): -100,
                    ("Y", "ö"): -100,
                    ("Y", "ø"): -100,
                    ("Y", "ù"): -100,
                    ("Y", "ú"): -100,
                    ("Y", "û"): -100,
                    ("Y", "ü"): -100,
                    ("a", "g"): -10,
                    ("a", "v"): -15,
                    ("a", "w"): -15,
                    ("a", "y"): -20,
                    ("a", "ý"): -20,
                    ("a", "ÿ"): -20,
                    ("b", "l"): -10,
                    ("b", "u"): -20,
                    ("b", "v"): -20,
                    ("b", "y"): -20,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("b", "ý"): -20,
                    ("b", "ÿ"): -20,
                    ("b", "ł"): -10,
                    ("c", "h"): -10,
                    ("c", "k"): -20,
                    ("c", "l"): -20,
                    ("c", "y"): -10,
                    ("c", "ý"): -10,
                    ("c", "ÿ"): -10,
                    ("c", "ł"): -20,
                    ("d", "d"): -10,
                    ("d", "v"): -15,
                    ("d", "w"): -15,
                    ("d", "y"): -15,
                    ("d", "ý"): -15,
                    ("d", "ÿ"): -15,
                    ("e", ","): 10,
                    ("e", "."): 20,
                    ("e", "v"): -15,
                    ("e", "w"): -15,
                    ("e", "x"): -15,
                    ("e", "y"): -15,
                    ("e", "ý"): -15,
                    ("e", "ÿ"): -15,
                    ("f", ","): -10,
                    ("f", "."): -10,
                    ("f", "e"): -10,
                    ("f", "o"): -20,
                    ("f", "è"): -10,
                    ("f", "é"): -10,
                    ("f", "ê"): -10,
                    ("f", "ë"): -10,
                    ("f", "ò"): -20,
                    ("f", "ó"): -20,
                    ("f", "ô"): -20,
                    ("f", "õ"): -20,
                    ("f", "ö"): -20,
                    ("f", "ø"): -20,
                    ("f", "’"): 30,
                    ("f", "”"): 30,
                    ("g", "e"): 10,
                    ("g", "g"): -10,
                    ("g", "è"): 10,
                    ("g", "é"): 10,
                    ("g", "ê"): 10,
                    ("g", "ë"): 10,
                    ("h", "y"): -20,
                    ("h", "ý"): -20,
                    ("h", "ÿ"): -20,
                    ("k", "o"): -15,
                    ("k", "ò"): -15,
                    ("k", "ó"): -15,
                    ("k", "ô"): -15,
                    ("k", "õ"): -15,
                    ("k", "ö"): -15,
                    ("k", "ø"): -15,
                    ("l", "w"): -15,
                    ("l", "y"): -15,
                    ("l", "ý"): -15,
                    ("l", "ÿ"): -15,
                    ("m", "u"): -20,
                    ("m", "y"): -30,
                    ("m", "ù"): -20,
                    ("m", "ú"): -20,
                    ("m", "û"): -20,
                    ("m", "ü"): -20,
                    ("m", "ý"): -30,
                    ("m", "ÿ"): -30,
                    ("n", "u"): -10,
                    ("n", "v"): -40,
                    ("n", "y"): -20,
                    ("n", "ù"): -10,
                    ("n", "ú"): -10,
                    ("n", "û"): -10,
                    ("n", "ü"): -10,
                    ("n", "ý"): -20,
                    ("n", "ÿ"): -20,
                    ("o", "v"): -20,
                    ("o", "w"): -15,
                    ("o", "x"): -30,
                    ("o", "y"): -20,
                    ("o", "ý"): -20,
                    ("o", "ÿ"): -20,
                    ("p", "y"): -15,
                    ("p", "ý"): -15,
                    ("p", "ÿ"): -15,
                    ("r", ","): -60,
                    ("r", "-"): -20,
                    ("r", "."): -60,
                    ("r", "c"): -20,
                    ("r", "d"): -20,
                    ("r", "g"): -15,
                    ("r", "o"): -20,
                    ("r", "q"): -20,
                    ("r", "s"): -15,
                    ("r", "t"): 20,
                    ("r", "v"): 10,
                    ("r", "y"): 10,
                    ("r", "ç"): -20,
                    ("r", "ò"): -20,
                    ("r", "ó"): -20,
                    ("r", "ô"): -20,
                    ("r", "õ"): -20,
                    ("r", "ö"): -20,
                    ("r", "ø"): -20,
                    ("r", "ý"): 10,
                    ("r", "ÿ"): 10,
                    ("r", "š"): -15,
                    ("s", "w"): -15,
                    ("v", ","): -80,
                    ("v", "."): -80,
                    ("v", "a"): -20,
                    ("v", "o"): -30,
                    ("v", "à"): -20,
                    ("v", "á"): -20,
                    ("v", "â"): -20,
                    ("v", "ã"): -20,
                    ("v", "ä"): -20,
                    ("v", "å"): -20,
                    ("v", "ò"): -30,
                    ("v", "ó"): -30,
                    ("v", "ô"): -30,
                    ("v", "õ"): -30,
                    ("v", "ö"): -30,
                    ("v", "ø"): -30,
                    ("w", ","): -40,
                    ("w", "."): -40,
                    ("w", "o"): -20,
                    ("w", "ò"): -20,
                    ("w", "ó"): -20,
                    ("w", "ô"): -20,
                    ("w", "õ"): -20,
                    ("w", "ö"): -20,
                    ("w", "ø"): -20,
                    ("x", "e"): -10,
                    ("x", "è"): -10,
                    ("x", "é"): -10,
                    ("x", "ê"): -10,
                    ("x", "ë"): -10,
                    ("y", ","): -80,
                    ("y", "."): -80,
                    ("y", "a"): -30,
                    ("y", "e"): -10,
                    ("y", "o"): -25,
                    ("y", "à"): -30,
                    ("y", "á"): -30,
                    ("y", "â"): -30,
                    ("y", "ã"): -30,
                    ("y", "ä"): -30,
                    ("y", "å"): -30,
                    ("y", "è"): -10,
                    ("y", "é"): -10,
                    ("y", "ê"): -10,
                    ("y", "ë"): -10,
                    ("y", "ò"): -25,
                    ("y", "ó"): -25,
                    ("y", "ô"): -25,
                    ("y", "õ"): -25,
                    ("y", "ö"): -25,
                    ("y", "ø"): -25,
                    ("z", "e"): 10,
                    ("z", "è"): 10,
                    ("z", "é"): 10,
                    ("z", "ê"): 10,
                    ("z", "ë"): 10,
                    ("À", "C"): -40,
                    ("À", "G"): -50,
                    ("À", "O"): -40,
                    ("À", "Q"): -40,
                    ("À", "T"): -90,
                    ("À", "U"): -50,
                    ("À", "V"): -80,
                    ("À", "W"): -60,
                    ("À", "Y"): -110,
                    ("À", "u"): -30,
                    ("À", "v"): -40,
                    ("À", "w"): -30,
                    ("À", "y"): -30,
                    ("À", "Ç"): -40,
                    ("À", "Ò"): -40,
                    ("À", "Ó"): -40,
                    ("À", "Ô"): -40,
                    ("À", "Õ"): -40,
                    ("À", "Ö"): -40,
                    ("À", "Ø"): -40,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -110,
                    ("À", "ù"): -30,
                    ("À", "ú"): -30,
                    ("À", "û"): -30,
                    ("À", "ü"): -30,
                    ("À", "ý"): -30,
                    ("À", "ÿ"): -30,
                    ("À", "Ÿ"): -110,
                    ("Á", "C"): -40,
                    ("Á", "G"): -50,
                    ("Á", "O"): -40,
                    ("Á", "Q"): -40,
                    ("Á", "T"): -90,
                    ("Á", "U"): -50,
                    ("Á", "V"): -80,
                    ("Á", "W"): -60,
                    ("Á", "Y"): -110,
                    ("Á", "u"): -30,
                    ("Á", "v"): -40,
                    ("Á", "w"): -30,
                    ("Á", "y"): -30,
                    ("Á", "Ç"): -40,
                    ("Á", "Ò"): -40,
                    ("Á", "Ó"): -40,
                    ("Á", "Ô"): -40,
                    ("Á", "Õ"): -40,
                    ("Á", "Ö"): -40,
                    ("Á", "Ø"): -40,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -110,
                    ("Á", "ù"): -30,
                    ("Á", "ú"): -30,
                    ("Á", "û"): -30,
                    ("Á", "ü"): -30,
                    ("Á", "ý"): -30,
                    ("Á", "ÿ"): -30,
                    ("Á", "Ÿ"): -110,
                    ("Â", "C"): -40,
                    ("Â", "G"): -50,
                    ("Â", "O"): -40,
                    ("Â", "Q"): -40,
                    ("Â", "T"): -90,
                    ("Â", "U"): -50,
                    ("Â", "V"): -80,
                    ("Â", "W"): -60,
                    ("Â", "Y"): -110,
                    ("Â", "u"): -30,
                    ("Â", "v"): -40,
                    ("Â", "w"): -30,
                    ("Â", "y"): -30,
                    ("Â", "Ç"): -40,
                    ("Â", "Ò"): -40,
                    ("Â", "Ó"): -40,
                    ("Â", "Ô"): -40,
                    ("Â", "Õ"): -40,
                    ("Â", "Ö"): -40,
                    ("Â", "Ø"): -40,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -110,
                    ("Â", "ù"): -30,
                    ("Â", "ú"): -30,
                    ("Â", "û"): -30,
                    ("Â", "ü"): -30,
                    ("Â", "ý"): -30,
                    ("Â", "ÿ"): -30,
                    ("Â", "Ÿ"): -110,
                    ("Ã", "C"): -40,
                    ("Ã", "G"): -50,
                    ("Ã", "O"): -40,
                    ("Ã", "Q"): -40,
                    ("Ã", "T"): -90,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -80,
                    ("Ã", "W"): -60,
                    ("Ã", "Y"): -110,
                    ("Ã", "u"): -30,
                    ("Ã", "v"): -40,
                    ("Ã", "w"): -30,
                    ("Ã", "y"): -30,
                    ("Ã", "Ç"): -40,
                    ("Ã", "Ò"): -40,
                    ("Ã", "Ó"): -40,
                    ("Ã", "Ô"): -40,
                    ("Ã", "Õ"): -40,
                    ("Ã", "Ö"): -40,
                    ("Ã", "Ø"): -40,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -110,
                    ("Ã", "ù"): -30,
                    ("Ã", "ú"): -30,
                    ("Ã", "û"): -30,
                    ("Ã", "ü"): -30,
                    ("Ã", "ý"): -30,
                    ("Ã", "ÿ"): -30,
                    ("Ã", "Ÿ"): -110,
                    ("Ä", "C"): -40,
                    ("Ä", "G"): -50,
                    ("Ä", "O"): -40,
                    ("Ä", "Q"): -40,
                    ("Ä", "T"): -90,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -80,
                    ("Ä", "W"): -60,
                    ("Ä", "Y"): -110,
                    ("Ä", "u"): -30,
                    ("Ä", "v"): -40,
                    ("Ä", "w"): -30,
                    ("Ä", "y"): -30,
                    ("Ä", "Ç"): -40,
                    ("Ä", "Ò"): -40,
                    ("Ä", "Ó"): -40,
                    ("Ä", "Ô"): -40,
                    ("Ä", "Õ"): -40,
                    ("Ä", "Ö"): -40,
                    ("Ä", "Ø"): -40,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -110,
                    ("Ä", "ù"): -30,
                    ("Ä", "ú"): -30,
                    ("Ä", "û"): -30,
                    ("Ä", "ü"): -30,
                    ("Ä", "ý"): -30,
                    ("Ä", "ÿ"): -30,
                    ("Ä", "Ÿ"): -110,
                    ("Å", "C"): -40,
                    ("Å", "G"): -50,
                    ("Å", "O"): -40,
                    ("Å", "Q"): -40,
                    ("Å", "T"): -90,
                    ("Å", "U"): -50,
                    ("Å", "V"): -80,
                    ("Å", "W"): -60,
                    ("Å", "Y"): -110,
                    ("Å", "u"): -30,
                    ("Å", "v"): -40,
                    ("Å", "w"): -30,
                    ("Å", "y"): -30,
                    ("Å", "Ç"): -40,
                    ("Å", "Ò"): -40,
                    ("Å", "Ó"): -40,
                    ("Å", "Ô"): -40,
                    ("Å", "Õ"): -40,
                    ("Å", "Ö"): -40,
                    ("Å", "Ø"): -40,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -110,
                    ("Å", "ù"): -30,
                    ("Å", "ú"): -30,
                    ("Å", "û"): -30,
                    ("Å", "ü"): -30,
                    ("Å", "ý"): -30,
                    ("Å", "ÿ"): -30,
                    ("Å", "Ÿ"): -110,
                    ("Ò", ","): -40,
                    ("Ò", "."): -40,
                    ("Ò", "A"): -50,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -50,
                    ("Ò", "X"): -50,
                    ("Ò", "Y"): -70,
                    ("Ò", "À"): -50,
                    ("Ò", "Á"): -50,
                    ("Ò", "Â"): -50,
                    ("Ò", "Ã"): -50,
                    ("Ò", "Ä"): -50,
                    ("Ò", "Å"): -50,
                    ("Ò", "Ý"): -70,
                    ("Ò", "Ÿ"): -70,
                    ("Ó", ","): -40,
                    ("Ó", "."): -40,
                    ("Ó", "A"): -50,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -50,
                    ("Ó", "X"): -50,
                    ("Ó", "Y"): -70,
                    ("Ó", "À"): -50,
                    ("Ó", "Á"): -50,
                    ("Ó", "Â"): -50,
                    ("Ó", "Ã"): -50,
                    ("Ó", "Ä"): -50,
                    ("Ó", "Å"): -50,
                    ("Ó", "Ý"): -70,
                    ("Ó", "Ÿ"): -70,
                    ("Ô", ","): -40,
                    ("Ô", "."): -40,
                    ("Ô", "A"): -50,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -50,
                    ("Ô", "X"): -50,
                    ("Ô", "Y"): -70,
                    ("Ô", "À"): -50,
                    ("Ô", "Á"): -50,
                    ("Ô", "Â"): -50,
                    ("Ô", "Ã"): -50,
                    ("Ô", "Ä"): -50,
                    ("Ô", "Å"): -50,
                    ("Ô", "Ý"): -70,
                    ("Ô", "Ÿ"): -70,
                    ("Õ", ","): -40,
                    ("Õ", "."): -40,
                    ("Õ", "A"): -50,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -50,
                    ("Õ", "X"): -50,
                    ("Õ", "Y"): -70,
                    ("Õ", "À"): -50,
                    ("Õ", "Á"): -50,
                    ("Õ", "Â"): -50,
                    ("Õ", "Ã"): -50,
                    ("Õ", "Ä"): -50,
                    ("Õ", "Å"): -50,
                    ("Õ", "Ý"): -70,
                    ("Õ", "Ÿ"): -70,
                    ("Ö", ","): -40,
                    ("Ö", "."): -40,
                    ("Ö", "A"): -50,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -50,
                    ("Ö", "X"): -50,
                    ("Ö", "Y"): -70,
                    ("Ö", "À"): -50,
                    ("Ö", "Á"): -50,
                    ("Ö", "Â"): -50,
                    ("Ö", "Ã"): -50,
                    ("Ö", "Ä"): -50,
                    ("Ö", "Å"): -50,
                    ("Ö", "Ý"): -70,
                    ("Ö", "Ÿ"): -70,
                    ("Ø", ","): -40,
                    ("Ø", "."): -40,
                    ("Ø", "A"): -50,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -50,
                    ("Ø", "X"): -50,
                    ("Ø", "Y"): -70,
                    ("Ø", "À"): -50,
                    ("Ø", "Á"): -50,
                    ("Ø", "Â"): -50,
                    ("Ø", "Ã"): -50,
                    ("Ø", "Ä"): -50,
                    ("Ø", "Å"): -50,
                    ("Ø", "Ý"): -70,
                    ("Ø", "Ÿ"): -70,
                    ("Ù", ","): -30,
                    ("Ù", "."): -30,
                    ("Ù", "A"): -50,
                    ("Ù", "À"): -50,
                    ("Ù", "Á"): -50,
                    ("Ù", "Â"): -50,
                    ("Ù", "Ã"): -50,
                    ("Ù", "Ä"): -50,
                    ("Ù", "Å"): -50,
                    ("Ú", ","): -30,
                    ("Ú", "."): -30,
                    ("Ú", "A"): -50,
                    ("Ú", "À"): -50,
                    ("Ú", "Á"): -50,
                    ("Ú", "Â"): -50,
                    ("Ú", "Ã"): -50,
                    ("Ú", "Ä"): -50,
                    ("Ú", "Å"): -50,
                    ("Û", ","): -30,
                    ("Û", "."): -30,
                    ("Û", "A"): -50,
                    ("Û", "À"): -50,
                    ("Û", "Á"): -50,
                    ("Û", "Â"): -50,
                    ("Û", "Ã"): -50,
                    ("Û", "Ä"): -50,
                    ("Û", "Å"): -50,
                    ("Ü", ","): -30,
                    ("Ü", "."): -30,
                    ("Ü", "A"): -50,
                    ("Ü", "À"): -50,
                    ("Ü", "Á"): -50,
                    ("Ü", "Â"): -50,
                    ("Ü", "Ã"): -50,
                    ("Ü", "Ä"): -50,
                    ("Ü", "Å"): -50,
                    ("Ý", ","): -100,
                    ("Ý", "."): -100,
                    ("Ý", ":"): -50,
                    ("Ý", ";"): -50,
                    ("Ý", "A"): -110,
                    ("Ý", "O"): -70,
                    ("Ý", "a"): -90,
                    ("Ý", "e"): -80,
                    ("Ý", "o"): -100,
                    ("Ý", "u"): -100,
                    ("Ý", "À"): -110,
                    ("Ý", "Á"): -110,
                    ("Ý", "Â"): -110,
                    ("Ý", "Ã"): -110,
                    ("Ý", "Ä"): -110,
                    ("Ý", "Å"): -110,
                    ("Ý", "Ò"): -70,
                    ("Ý", "Ó"): -70,
                    ("Ý", "Ô"): -70,
                    ("Ý", "Õ"): -70,
                    ("Ý", "Ö"): -70,
                    ("Ý", "Ø"): -70,
                    ("Ý", "à"): -90,
                    ("Ý", "á"): -90,
                    ("Ý", "â"): -90,
                    ("Ý", "ã"): -90,
                    ("Ý", "ä"): -90,
                    ("Ý", "å"): -90,
                    ("Ý", "è"): -80,
                    ("Ý", "é"): -80,
                    ("Ý", "ê"): -80,
                    ("Ý", "ë"): -80,
                    ("Ý", "ò"): -100,
                    ("Ý", "ó"): -100,
                    ("Ý", "ô"): -100,
                    ("Ý", "õ"): -100,
                    ("Ý", "ö"): -100,
                    ("Ý", "ø"): -100,
                    ("Ý", "ù"): -100,
                    ("Ý", "ú"): -100,
                    ("Ý", "û"): -100,
                    ("Ý", "ü"): -100,
                    ("à", "g"): -10,
                    ("à", "v"): -15,
                    ("à", "w"): -15,
                    ("à", "y"): -20,
                    ("à", "ý"): -20,
                    ("à", "ÿ"): -20,
                    ("á", "g"): -10,
                    ("á", "v"): -15,
                    ("á", "w"): -15,
                    ("á", "y"): -20,
                    ("á", "ý"): -20,
                    ("á", "ÿ"): -20,
                    ("â", "g"): -10,
                    ("â", "v"): -15,
                    ("â", "w"): -15,
                    ("â", "y"): -20,
                    ("â", "ý"): -20,
                    ("â", "ÿ"): -20,
                    ("ã", "g"): -10,
                    ("ã", "v"): -15,
                    ("ã", "w"): -15,
                    ("ã", "y"): -20,
                    ("ã", "ý"): -20,
                    ("ã", "ÿ"): -20,
                    ("ä", "g"): -10,
                    ("ä", "v"): -15,
                    ("ä", "w"): -15,
                    ("ä", "y"): -20,
                    ("ä", "ý"): -20,
                    ("ä", "ÿ"): -20,
                    ("å", "g"): -10,
                    ("å", "v"): -15,
                    ("å", "w"): -15,
                    ("å", "y"): -20,
                    ("å", "ý"): -20,
                    ("å", "ÿ"): -20,
                    ("ç", "h"): -10,
                    ("ç", "k"): -20,
                    ("ç", "l"): -20,
                    ("ç", "y"): -10,
                    ("ç", "ý"): -10,
                    ("ç", "ÿ"): -10,
                    ("ç", "ł"): -20,
                    ("è", ","): 10,
                    ("è", "."): 20,
                    ("è", "v"): -15,
                    ("è", "w"): -15,
                    ("è", "x"): -15,
                    ("è", "y"): -15,
                    ("è", "ý"): -15,
                    ("è", "ÿ"): -15,
                    ("é", ","): 10,
                    ("é", "."): 20,
                    ("é", "v"): -15,
                    ("é", "w"): -15,
                    ("é", "x"): -15,
                    ("é", "y"): -15,
                    ("é", "ý"): -15,
                    ("é", "ÿ"): -15,
                    ("ê", ","): 10,
                    ("ê", "."): 20,
                    ("ê", "v"): -15,
                    ("ê", "w"): -15,
                    ("ê", "x"): -15,
                    ("ê", "y"): -15,
                    ("ê", "ý"): -15,
                    ("ê", "ÿ"): -15,
                    ("ë", ","): 10,
                    ("ë", "."): 20,
                    ("ë", "v"): -15,
                    ("ë", "w"): -15,
                    ("ë", "x"): -15,
                    ("ë", "y"): -15,
                    ("ë", "ý"): -15,
                    ("ë", "ÿ"): -15,
                    ("ñ", "u"): -10,
                    ("ñ", "v"): -40,
                    ("ñ", "y"): -20,
                    ("ñ", "ù"): -10,
                    ("ñ", "ú"): -10,
                    ("ñ", "û"): -10,
                    ("ñ", "ü"): -10,
                    ("ñ", "ý"): -20,
                    ("ñ", "ÿ"): -20,
                    ("ò", "v"): -20,
                    ("ò", "w"): -15,
                    ("ò", "x"): -30,
                    ("ò", "y"): -20,
                    ("ò", "ý"): -20,
                    ("ò", "ÿ"): -20,
                    ("ó", "v"): -20,
                    ("ó", "w"): -15,
                    ("ó", "x"): -30,
                    ("ó", "y"): -20,
                    ("ó", "ý"): -20,
                    ("ó", "ÿ"): -20,
                    ("ô", "v"): -20,
                    ("ô", "w"): -15,
                    ("ô", "x"): -30,
                    ("ô", "y"): -20,
                    ("ô", "ý"): -20,
                    ("ô", "ÿ"): -20,
                    ("õ", "v"): -20,
                    ("õ", "w"): -15,
                    ("õ", "x"): -30,
                    ("õ", "y"): -20,
                    ("õ", "ý"): -20,
                    ("õ", "ÿ"): -20,
                    ("ö", "v"): -20,
                    ("ö", "w"): -15,
                    ("ö", "x"): -30,
                    ("ö", "y"): -20,
                    ("ö", "ý"): -20,
                    ("ö", "ÿ"): -20,
                    ("ø", "v"): -20,
                    ("ø", "w"): -15,
                    ("ø", "x"): -30,
                    ("ø", "y"): -20,
                    ("ø", "ý"): -20,
                    ("ø", "ÿ"): -20,
                    ("ý", ","): -80,
                    ("ý", "."): -80,
                    ("ý", "a"): -30,
                    ("ý", "e"): -10,
                    ("ý", "o"): -25,
                    ("ý", "à"): -30,
                    ("ý", "á"): -30,
                    ("ý", "â"): -30,
                    ("ý", "ã"): -30,
                    ("ý", "ä"): -30,
                    ("ý", "å"): -30,
                    ("ý", "è"): -10,
                    ("ý", "é"): -10,
                    ("ý", "ê"): -10,
                    ("ý", "ë"): -10,
                    ("ý", "ò"): -25,
                    ("ý", "ó"): -25,
                    ("ý", "ô"): -25,
                    ("ý", "õ"): -25,
                    ("ý", "ö"): -25,
                    ("ý", "ø"): -25,
                    ("ÿ", ","): -80,
                    ("ÿ", "."): -80,
                    ("ÿ", "a"): -30,
                    ("ÿ", "e"): -10,
                    ("ÿ", "o"): -25,
                    ("ÿ", "à"): -30,
                    ("ÿ", "á"): -30,
                    ("ÿ", "â"): -30,
                    ("ÿ", "ã"): -30,
                    ("ÿ", "ä"): -30,
                    ("ÿ", "å"): -30,
                    ("ÿ", "è"): -10,
                    ("ÿ", "é"): -10,
                    ("ÿ", "ê"): -10,
                    ("ÿ", "ë"): -10,
                    ("ÿ", "ò"): -25,
                    ("ÿ", "ó"): -25,
                    ("ÿ", "ô"): -25,
                    ("ÿ", "õ"): -25,
                    ("ÿ", "ö"): -25,
                    ("ÿ", "ø"): -25,
                    ("Ł", "T"): -90,
                    ("Ł", "V"): -110,
                    ("Ł", "W"): -80,
                    ("Ł", "Y"): -120,
                    ("Ł", "y"): -30,
                    ("Ł", "Ý"): -120,
                    ("Ł", "ý"): -30,
                    ("Ł", "ÿ"): -30,
                    ("Ł", "Ÿ"): -120,
                    ("Ł", "’"): -140,
                    ("Ł", "”"): -140,
                    ("ł", "w"): -15,
                    ("ł", "y"): -15,
                    ("ł", "ý"): -15,
                    ("ł", "ÿ"): -15,
                    ("š", "w"): -15,
                    ("Ÿ", ","): -100,
                    ("Ÿ", "."): -100,
                    ("Ÿ", ":"): -50,
                    ("Ÿ", ";"): -50,
                    ("Ÿ", "A"): -110,
                    ("Ÿ", "O"): -70,
                    ("Ÿ", "a"): -90,
                    ("Ÿ", "e"): -80,
                    ("Ÿ", "o"): -100,
                    ("Ÿ", "u"): -100,
                    ("Ÿ", "À"): -110,
                    ("Ÿ", "Á"): -110,
                    ("Ÿ", "Â"): -110,
                    ("Ÿ", "Ã"): -110,
                    ("Ÿ", "Ä"): -110,
                    ("Ÿ", "Å"): -110,
                    ("Ÿ", "Ò"): -70,
                    ("Ÿ", "Ó"): -70,
                    ("Ÿ", "Ô"): -70,
                    ("Ÿ", "Õ"): -70,
                    ("Ÿ", "Ö"): -70,
                    ("Ÿ", "Ø"): -70,
                    ("Ÿ", "à"): -90,
                    ("Ÿ", "á"): -90,
                    ("Ÿ", "â"): -90,
                    ("Ÿ", "ã"): -90,
                    ("Ÿ", "ä"): -90,
                    ("Ÿ", "å"): -90,
                    ("Ÿ", "è"): -80,
                    ("Ÿ", "é"): -80,
                    ("Ÿ", "ê"): -80,
                    ("Ÿ", "ë"): -80,
                    ("Ÿ", "ò"): -100,
                    ("Ÿ", "ó"): -100,
                    ("Ÿ", "ô"): -100,
                    ("Ÿ", "õ"): -100,
                    ("Ÿ", "ö"): -100,
                    ("Ÿ", "ø"): -100,
                    ("Ÿ", "ù"): -100,
                    ("Ÿ", "ú"): -100,
                    ("Ÿ", "û"): -100,
                    ("Ÿ", "ü"): -100,
                    ("ž", "e"): 10,
                    ("ž", "è"): 10,
                    ("ž", "é"): 10,
                    ("ž", "ê"): 10,
                    ("ž", "ë"): 10,
                    ("‘", "‘"): -46,
                    ("’", " "): -80,
                    ("’", "d"): -80,
                    ("’", "l"): -20,
                    ("’", "r"): -40,
                    ("’", "s"): -60,
                    ("’", "v"): -20,
                    ("’", "ł"): -20,
                    ("’", "š"): -60,
                    ("’", "’"): -46,
                    ("”", " "): -80,
                },
                0,
            ),
        ),
    )
    times_roman = BuiltinTypeface(
        BuiltinFont(
            b"Times-Roman",
            b"f4",
            dictget(
                {
                    " ": 250,
                    "!": 333,
                    '"': 408,
                    "#": 500,
                    "$": 500,
                    "%": 833,
                    "&": 778,
                    "'": 180,
                    "(": 333,
                    ")": 333,
                    "*": 500,
                    "+": 564,
                    ",": 250,
                    "-": 333,
                    ".": 250,
                    "/": 278,
                    "0": 500,
                    "1": 500,
                    "2": 500,
                    "3": 500,
                    "4": 500,
                    "5": 500,
                    "6": 500,
                    "7": 500,
                    "8": 500,
                    "9": 500,
                    ":": 278,
                    ";": 278,
                    "<": 564,
                    "=": 564,
                    ">": 564,
                    "?": 444,
                    "@": 921,
                    "A": 722,
                    "B": 667,
                    "C": 667,
                    "D": 722,
                    "E": 611,
                    "F": 556,
                    "G": 722,
                    "H": 722,
                    "I": 333,
                    "J": 389,
                    "K": 722,
                    "L": 611,
                    "M": 889,
                    "N": 722,
                    "O": 722,
                    "P": 556,
                    "Q": 722,
                    "R": 667,
                    "S": 556,
                    "T": 611,
                    "U": 722,
                    "V": 722,
                    "W": 944,
                    "X": 722,
                    "Y": 722,
                    "Z": 611,
                    "[": 333,
                    "\\": 278,
                    "]": 333,
                    "^": 469,
                    "_": 500,
                    "`": 333,
                    "a": 444,
                    "b": 500,
                    "c": 444,
                    "d": 500,
                    "e": 444,
                    "f": 333,
                    "g": 500,
                    "h": 500,
                    "i": 278,
                    "j": 278,
                    "k": 500,
                    "l": 278,
                    "m": 778,
                    "n": 500,
                    "o": 500,
                    "p": 500,
                    "q": 500,
                    "r": 333,
                    "s": 389,
                    "t": 278,
                    "u": 500,
                    "v": 500,
                    "w": 722,
                    "x": 500,
                    "y": 500,
                    "z": 444,
                    "{": 480,
                    "|": 200,
                    "}": 480,
                    "~": 541,
                    "¡": 333,
                    "¢": 500,
                    "£": 500,
                    "¤": 500,
                    "¥": 500,
                    "¦": 200,
                    "§": 500,
                    "©": 760,
                    "ª": 276,
                    "«": 500,
                    "¬": 564,
                    "®": 760,
                    "°": 400,
                    "±": 564,
                    "²": 300,
                    "³": 300,
                    "¶": 453,
                    "·": 250,
                    "¹": 300,
                    "º": 310,
                    "»": 500,
                    "¼": 750,
                    "½": 750,
                    "¾": 750,
                    "¿": 444,
                    "À": 722,
                    "Á": 722,
                    "Â": 722,
                    "Ã": 722,
                    "Ä": 722,
                    "Å": 722,
                    "Æ": 889,
                    "Ç": 667,
                    "È": 611,
                    "É": 611,
                    "Ê": 611,
                    "Ë": 611,
                    "Ì": 333,
                    "Í": 333,
                    "Î": 333,
                    "Ï": 333,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 722,
                    "Ó": 722,
                    "Ô": 722,
                    "Õ": 722,
                    "Ö": 722,
                    "×": 564,
                    "Ø": 722,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 722,
                    "Þ": 556,
                    "ß": 500,
                    "à": 444,
                    "á": 444,
                    "â": 444,
                    "ã": 444,
                    "ä": 444,
                    "å": 444,
                    "æ": 667,
                    "ç": 444,
                    "è": 444,
                    "é": 444,
                    "ê": 444,
                    "ë": 444,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 500,
                    "ñ": 500,
                    "ò": 500,
                    "ó": 500,
                    "ô": 500,
                    "õ": 500,
                    "ö": 500,
                    "÷": 564,
                    "ø": 500,
                    "ù": 500,
                    "ú": 500,
                    "û": 500,
                    "ü": 500,
                    "ý": 500,
                    "þ": 500,
                    "ÿ": 500,
                    "ı": 278,
                    "Ł": 611,
                    "ł": 278,
                    "Œ": 889,
                    "œ": 722,
                    "Š": 556,
                    "š": 389,
                    "Ÿ": 722,
                    "Ž": 611,
                    "ž": 444,
                    "ƒ": 500,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 500,
                    "–": 500,
                    "—": 1000,
                    "‘": 333,
                    "’": 333,
                    "‚": 333,
                    "“": 444,
                    "”": 444,
                    "„": 444,
                    "†": 500,
                    "‡": 500,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 500,
                    "™": 980,
                    "−": 564,
                    "ﬁ": 556,
                    "ﬂ": 556,
                },
                444,
            ),
            dictget(
                {
                    (" ", "A"): -55,
                    (" ", "T"): -18,
                    (" ", "V"): -50,
                    (" ", "W"): -30,
                    (" ", "Y"): -90,
                    (" ", "À"): -55,
                    (" ", "Á"): -55,
                    (" ", "Â"): -55,
                    (" ", "Ã"): -55,
                    (" ", "Ä"): -55,
                    (" ", "Å"): -55,
                    (" ", "Ý"): -90,
                    (" ", "Ÿ"): -90,
                    (",", "’"): -70,
                    (",", "”"): -70,
                    (".", "’"): -70,
                    (".", "”"): -70,
                    ("A", "C"): -40,
                    ("A", "G"): -40,
                    ("A", "O"): -55,
                    ("A", "Q"): -55,
                    ("A", "T"): -111,
                    ("A", "U"): -55,
                    ("A", "V"): -135,
                    ("A", "W"): -90,
                    ("A", "Y"): -105,
                    ("A", "v"): -74,
                    ("A", "w"): -92,
                    ("A", "y"): -92,
                    ("A", "Ç"): -40,
                    ("A", "Ò"): -55,
                    ("A", "Ó"): -55,
                    ("A", "Ô"): -55,
                    ("A", "Õ"): -55,
                    ("A", "Ö"): -55,
                    ("A", "Ø"): -55,
                    ("A", "Ù"): -55,
                    ("A", "Ú"): -55,
                    ("A", "Û"): -55,
                    ("A", "Ü"): -55,
                    ("A", "Ý"): -105,
                    ("A", "ý"): -92,
                    ("A", "ÿ"): -92,
                    ("A", "Ÿ"): -105,
                    ("A", "’"): -111,
                    ("B", "A"): -35,
                    ("B", "U"): -10,
                    ("B", "À"): -35,
                    ("B", "Á"): -35,
                    ("B", "Â"): -35,
                    ("B", "Ã"): -35,
                    ("B", "Ä"): -35,
                    ("B", "Å"): -35,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("D", "A"): -40,
                    ("D", "V"): -40,
                    ("D", "W"): -30,
                    ("D", "Y"): -55,
                    ("D", "À"): -40,
                    ("D", "Á"): -40,
                    ("D", "Â"): -40,
                    ("D", "Ã"): -40,
                    ("D", "Ä"): -40,
                    ("D", "Å"): -40,
                    ("D", "Ý"): -55,
                    ("D", "Ÿ"): -55,
                    ("F", ","): -80,
                    ("F", "."): -80,
                    ("F", "A"): -74,
                    ("F", "a"): -15,
                    ("F", "o"): -15,
                    ("F", "À"): -74,
                    ("F", "Á"): -74,
                    ("F", "Â"): -74,
                    ("F", "Ã"): -74,
                    ("F", "Ä"): -74,
                    ("F", "Å"): -74,
                    ("F", "à"): -15,
                    ("F", "á"): -15,
                    ("F", "â"): -15,
                    ("F", "ã"): -15,
                    ("F", "ä"): -15,
                    ("F", "å"): -15,
                    ("F", "ò"): -15,
                    ("F", "ó"): -15,
                    ("F", "ô"): -15,
                    ("F", "õ"): -15,
                    ("F", "ö"): -15,
                    ("F", "ø"): -15,
                    ("J", "A"): -60,
                    ("J", "À"): -60,
                    ("J", "Á"): -60,
                    ("J", "Â"): -60,
                    ("J", "Ã"): -60,
                    ("J", "Ä"): -60,
                    ("J", "Å"): -60,
                    ("K", "O"): -30,
                    ("K", "e"): -25,
                    ("K", "o"): -35,
                    ("K", "u"): -15,
                    ("K", "y"): -25,
                    ("K", "Ò"): -30,
                    ("K", "Ó"): -30,
                    ("K", "Ô"): -30,
                    ("K", "Õ"): -30,
                    ("K", "Ö"): -30,
                    ("K", "Ø"): -30,
                    ("K", "è"): -25,
                    ("K", "é"): -25,
                    ("K", "ê"): -25,
                    ("K", "ë"): -25,
                    ("K", "ò"): -35,
                    ("K", "ó"): -35,
                    ("K", "ô"): -35,
                    ("K", "õ"): -35,
                    ("K", "ö"): -35,
                    ("K", "ø"): -35,
                    ("K", "ù"): -15,
                    ("K", "ú"): -15,
                    ("K", "û"): -15,
                    ("K", "ü"): -15,
                    ("K", "ý"): -25,
                    ("K", "ÿ"): -25,
                    ("L", "T"): -92,
                    ("L", "V"): -100,
                    ("L", "W"): -74,
                    ("L", "Y"): -100,
                    ("L", "y"): -55,
                    ("L", "Ý"): -100,
                    ("L", "ý"): -55,
                    ("L", "ÿ"): -55,
                    ("L", "Ÿ"): -100,
                    ("L", "’"): -92,
                    ("N", "A"): -35,
                    ("N", "À"): -35,
                    ("N", "Á"): -35,
                    ("N", "Â"): -35,
                    ("N", "Ã"): -35,
                    ("N", "Ä"): -35,
                    ("N", "Å"): -35,
                    ("O", "A"): -35,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -35,
                    ("O", "X"): -40,
                    ("O", "Y"): -50,
                    ("O", "À"): -35,
                    ("O", "Á"): -35,
                    ("O", "Â"): -35,
                    ("O", "Ã"): -35,
                    ("O", "Ä"): -35,
                    ("O", "Å"): -35,
                    ("O", "Ý"): -50,
                    ("O", "Ÿ"): -50,
                    ("P", ","): -111,
                    ("P", "."): -111,
                    ("P", "A"): -92,
                    ("P", "a"): -15,
                    ("P", "À"): -92,
                    ("P", "Á"): -92,
                    ("P", "Â"): -92,
                    ("P", "Ã"): -92,
                    ("P", "Ä"): -92,
                    ("P", "Å"): -92,
                    ("P", "à"): -15,
                    ("P", "á"): -15,
                    ("P", "â"): -15,
                    ("P", "ã"): -15,
                    ("P", "ä"): -15,
                    ("P", "å"): -15,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -40,
                    ("R", "T"): -60,
                    ("R", "U"): -40,
                    ("R", "V"): -80,
                    ("R", "W"): -55,
                    ("R", "Y"): -65,
                    ("R", "Ò"): -40,
                    ("R", "Ó"): -40,
                    ("R", "Ô"): -40,
                    ("R", "Õ"): -40,
                    ("R", "Ö"): -40,
                    ("R", "Ø"): -40,
                    ("R", "Ù"): -40,
                    ("R", "Ú"): -40,
                    ("R", "Û"): -40,
                    ("R", "Ü"): -40,
                    ("R", "Ý"): -65,
                    ("R", "Ÿ"): -65,
                    ("T", ","): -74,
                    ("T", "-"): -92,
                    ("T", "."): -74,
                    ("T", ":"): -50,
                    ("T", ";"): -55,
                    ("T", "A"): -93,
                    ("T", "O"): -18,
                    ("T", "a"): -80,
                    ("T", "e"): -70,
                    ("T", "i"): -35,
                    ("T", "o"): -80,
                    ("T", "r"): -35,
                    ("T", "u"): -45,
                    ("T", "w"): -80,
                    ("T", "y"): -80,
                    ("T", "À"): -93,
                    ("T", "Á"): -93,
                    ("T", "Â"): -93,
                    ("T", "Ã"): -93,
                    ("T", "Ä"): -93,
                    ("T", "Å"): -93,
                    ("T", "Ò"): -18,
                    ("T", "Ó"): -18,
                    ("T", "Ô"): -18,
                    ("T", "Õ"): -18,
                    ("T", "Ö"): -18,
                    ("T", "Ø"): -18,
                    ("T", "à"): -40,
                    ("T", "á"): -80,
                    ("T", "â"): -80,
                    ("T", "ã"): -40,
                    ("T", "ä"): -40,
                    ("T", "å"): -80,
                    ("T", "è"): -70,
                    ("T", "é"): -70,
                    ("T", "ê"): -70,
                    ("T", "ë"): -30,
                    ("T", "í"): -35,
                    ("T", "ò"): -80,
                    ("T", "ó"): -80,
                    ("T", "ô"): -80,
                    ("T", "õ"): -80,
                    ("T", "ö"): -80,
                    ("T", "ø"): -80,
                    ("T", "ù"): -45,
                    ("T", "ú"): -45,
                    ("T", "û"): -45,
                    ("T", "ü"): -45,
                    ("T", "ý"): -80,
                    ("T", "ÿ"): -80,
                    ("U", "A"): -40,
                    ("U", "À"): -40,
                    ("U", "Á"): -40,
                    ("U", "Â"): -40,
                    ("U", "Ã"): -40,
                    ("U", "Ä"): -40,
                    ("U", "Å"): -40,
                    ("V", ","): -129,
                    ("V", "-"): -100,
                    ("V", "."): -129,
                    ("V", ":"): -74,
                    ("V", ";"): -74,
                    ("V", "A"): -135,
                    ("V", "G"): -15,
                    ("V", "O"): -40,
                    ("V", "a"): -111,
                    ("V", "e"): -111,
                    ("V", "i"): -60,
                    ("V", "o"): -129,
                    ("V", "u"): -75,
                    ("V", "À"): -135,
                    ("V", "Á"): -135,
                    ("V", "Â"): -135,
                    ("V", "Ã"): -135,
                    ("V", "Ä"): -135,
                    ("V", "Å"): -135,
                    ("V", "Ò"): -40,
                    ("V", "Ó"): -40,
                    ("V", "Ô"): -40,
                    ("V", "Õ"): -40,
                    ("V", "Ö"): -40,
                    ("V", "Ø"): -40,
                    ("V", "à"): -71,
                    ("V", "á"): -111,
                    ("V", "â"): -71,
                    ("V", "ã"): -71,
                    ("V", "ä"): -71,
                    ("V", "å"): -111,
                    ("V", "è"): -71,
                    ("V", "é"): -111,
                    ("V", "ê"): -71,
                    ("V", "ë"): -71,
                    ("V", "ì"): -20,
                    ("V", "í"): -60,
                    ("V", "î"): -20,
                    ("V", "ï"): -20,
                    ("V", "ò"): -89,
                    ("V", "ó"): -129,
                    ("V", "ô"): -129,
                    ("V", "õ"): -89,
                    ("V", "ö"): -89,
                    ("V", "ø"): -129,
                    ("V", "ù"): -75,
                    ("V", "ú"): -75,
                    ("V", "û"): -75,
                    ("V", "ü"): -75,
                    ("W", ","): -92,
                    ("W", "-"): -65,
                    ("W", "."): -92,
                    ("W", ":"): -37,
                    ("W", ";"): -37,
                    ("W", "A"): -120,
                    ("W", "O"): -10,
                    ("W", "a"): -80,
                    ("W", "e"): -80,
                    ("W", "i"): -40,
                    ("W", "o"): -80,
                    ("W", "u"): -50,
                    ("W", "y"): -73,
                    ("W", "À"): -120,
                    ("W", "Á"): -120,
                    ("W", "Â"): -120,
                    ("W", "Ã"): -120,
                    ("W", "Ä"): -120,
                    ("W", "Å"): -120,
                    ("W", "Ò"): -10,
                    ("W", "Ó"): -10,
                    ("W", "Ô"): -10,
                    ("W", "Õ"): -10,
                    ("W", "Ö"): -10,
                    ("W", "Ø"): -10,
                    ("W", "à"): -80,
                    ("W", "á"): -80,
                    ("W", "â"): -80,
                    ("W", "ã"): -80,
                    ("W", "ä"): -80,
                    ("W", "å"): -80,
                    ("W", "è"): -40,
                    ("W", "é"): -80,
                    ("W", "ê"): -80,
                    ("W", "ë"): -40,
                    ("W", "í"): -40,
                    ("W", "ò"): -80,
                    ("W", "ó"): -80,
                    ("W", "ô"): -80,
                    ("W", "õ"): -80,
                    ("W", "ö"): -80,
                    ("W", "ø"): -80,
                    ("W", "ù"): -50,
                    ("W", "ú"): -50,
                    ("W", "û"): -50,
                    ("W", "ü"): -50,
                    ("W", "ý"): -73,
                    ("W", "ÿ"): -73,
                    ("Y", ","): -129,
                    ("Y", "-"): -111,
                    ("Y", "."): -129,
                    ("Y", ":"): -92,
                    ("Y", ";"): -92,
                    ("Y", "A"): -120,
                    ("Y", "O"): -30,
                    ("Y", "a"): -100,
                    ("Y", "e"): -100,
                    ("Y", "i"): -55,
                    ("Y", "o"): -110,
                    ("Y", "u"): -111,
                    ("Y", "À"): -120,
                    ("Y", "Á"): -120,
                    ("Y", "Â"): -120,
                    ("Y", "Ã"): -120,
                    ("Y", "Ä"): -120,
                    ("Y", "Å"): -120,
                    ("Y", "Ò"): -30,
                    ("Y", "Ó"): -30,
                    ("Y", "Ô"): -30,
                    ("Y", "Õ"): -30,
                    ("Y", "Ö"): -30,
                    ("Y", "Ø"): -30,
                    ("Y", "à"): -60,
                    ("Y", "á"): -100,
                    ("Y", "â"): -100,
                    ("Y", "ã"): -60,
                    ("Y", "ä"): -60,
                    ("Y", "å"): -100,
                    ("Y", "è"): -60,
                    ("Y", "é"): -100,
                    ("Y", "ê"): -100,
                    ("Y", "ë"): -60,
                    ("Y", "í"): -55,
                    ("Y", "ò"): -70,
                    ("Y", "ó"): -110,
                    ("Y", "ô"): -110,
                    ("Y", "õ"): -70,
                    ("Y", "ö"): -70,
                    ("Y", "ø"): -110,
                    ("Y", "ù"): -71,
                    ("Y", "ú"): -111,
                    ("Y", "û"): -111,
                    ("Y", "ü"): -71,
                    ("a", "v"): -20,
                    ("a", "w"): -15,
                    ("b", "."): -40,
                    ("b", "u"): -20,
                    ("b", "v"): -15,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("c", "y"): -15,
                    ("c", "ý"): -15,
                    ("c", "ÿ"): -15,
                    ("e", "g"): -15,
                    ("e", "v"): -25,
                    ("e", "w"): -25,
                    ("e", "x"): -15,
                    ("e", "y"): -15,
                    ("e", "ý"): -15,
                    ("e", "ÿ"): -15,
                    ("f", "a"): -10,
                    ("f", "f"): -25,
                    ("f", "i"): -20,
                    ("f", "à"): -10,
                    ("f", "á"): -10,
                    ("f", "â"): -10,
                    ("f", "ã"): -10,
                    ("f", "ä"): -10,
                    ("f", "å"): -10,
                    ("f", "í"): -20,
                    ("f", "ı"): -50,
                    ("f", "’"): 55,
                    ("g", "a"): -5,
                    ("g", "à"): -5,
                    ("g", "á"): -5,
                    ("g", "â"): -5,
                    ("g", "ã"): -5,
                    ("g", "ä"): -5,
                    ("g", "å"): -5,
                    ("h", "y"): -5,
                    ("h", "ý"): -5,
                    ("h", "ÿ"): -5,
                    ("i", "v"): -25,
                    ("k", "e"): -10,
                    ("k", "o"): -10,
                    ("k", "y"): -15,
                    ("k", "è"): -10,
                    ("k", "é"): -10,
                    ("k", "ê"): -10,
                    ("k", "ë"): -10,
                    ("k", "ò"): -10,
                    ("k", "ó"): -10,
                    ("k", "ô"): -10,
                    ("k", "õ"): -10,
                    ("k", "ö"): -10,
                    ("k", "ø"): -10,
                    ("k", "ý"): -15,
                    ("k", "ÿ"): -15,
                    ("l", "w"): -10,
                    ("n", "v"): -40,
                    ("n", "y"): -15,
                    ("n", "ý"): -15,
                    ("n", "ÿ"): -15,
                    ("o", "v"): -15,
                    ("o", "w"): -25,
                    ("o", "y"): -10,
                    ("o", "ý"): -10,
                    ("o", "ÿ"): -10,
                    ("p", "y"): -10,
                    ("p", "ý"): -10,
                    ("p", "ÿ"): -10,
                    ("r", ","): -40,
                    ("r", "-"): -20,
                    ("r", "."): -55,
                    ("r", "g"): -18,
                    ("v", ","): -65,
                    ("v", "."): -65,
                    ("v", "a"): -25,
                    ("v", "e"): -15,
                    ("v", "o"): -20,
                    ("v", "à"): -25,
                    ("v", "á"): -25,
                    ("v", "â"): -25,
                    ("v", "ã"): -25,
                    ("v", "ä"): -25,
                    ("v", "å"): -25,
                    ("v", "è"): -15,
                    ("v", "é"): -15,
                    ("v", "ê"): -15,
                    ("v", "ë"): -15,
                    ("v", "ò"): -20,
                    ("v", "ó"): -20,
                    ("v", "ô"): -20,
                    ("v", "õ"): -20,
                    ("v", "ö"): -20,
                    ("v", "ø"): -20,
                    ("w", ","): -65,
                    ("w", "."): -65,
                    ("w", "a"): -10,
                    ("w", "o"): -10,
                    ("w", "à"): -10,
                    ("w", "á"): -10,
                    ("w", "â"): -10,
                    ("w", "ã"): -10,
                    ("w", "ä"): -10,
                    ("w", "å"): -10,
                    ("w", "ò"): -10,
                    ("w", "ó"): -10,
                    ("w", "ô"): -10,
                    ("w", "õ"): -10,
                    ("w", "ö"): -10,
                    ("w", "ø"): -10,
                    ("x", "e"): -15,
                    ("x", "è"): -15,
                    ("x", "é"): -15,
                    ("x", "ê"): -15,
                    ("x", "ë"): -15,
                    ("y", ","): -65,
                    ("y", "."): -65,
                    ("À", "C"): -40,
                    ("À", "G"): -40,
                    ("À", "O"): -55,
                    ("À", "Q"): -55,
                    ("À", "T"): -111,
                    ("À", "U"): -55,
                    ("À", "V"): -135,
                    ("À", "W"): -90,
                    ("À", "Y"): -105,
                    ("À", "v"): -74,
                    ("À", "w"): -92,
                    ("À", "y"): -92,
                    ("À", "Ç"): -40,
                    ("À", "Ò"): -55,
                    ("À", "Ó"): -55,
                    ("À", "Ô"): -55,
                    ("À", "Õ"): -55,
                    ("À", "Ö"): -55,
                    ("À", "Ø"): -55,
                    ("À", "Ù"): -55,
                    ("À", "Ú"): -55,
                    ("À", "Û"): -55,
                    ("À", "Ü"): -55,
                    ("À", "Ý"): -105,
                    ("À", "ý"): -92,
                    ("À", "ÿ"): -92,
                    ("À", "Ÿ"): -105,
                    ("À", "’"): -111,
                    ("Á", "C"): -40,
                    ("Á", "G"): -40,
                    ("Á", "O"): -55,
                    ("Á", "Q"): -55,
                    ("Á", "T"): -111,
                    ("Á", "U"): -55,
                    ("Á", "V"): -135,
                    ("Á", "W"): -90,
                    ("Á", "Y"): -105,
                    ("Á", "v"): -74,
                    ("Á", "w"): -92,
                    ("Á", "y"): -92,
                    ("Á", "Ç"): -40,
                    ("Á", "Ò"): -55,
                    ("Á", "Ó"): -55,
                    ("Á", "Ô"): -55,
                    ("Á", "Õ"): -55,
                    ("Á", "Ö"): -55,
                    ("Á", "Ø"): -55,
                    ("Á", "Ù"): -55,
                    ("Á", "Ú"): -55,
                    ("Á", "Û"): -55,
                    ("Á", "Ü"): -55,
                    ("Á", "Ý"): -105,
                    ("Á", "ý"): -92,
                    ("Á", "ÿ"): -92,
                    ("Á", "Ÿ"): -105,
                    ("Á", "’"): -111,
                    ("Â", "C"): -40,
                    ("Â", "G"): -40,
                    ("Â", "O"): -55,
                    ("Â", "Q"): -55,
                    ("Â", "T"): -111,
                    ("Â", "U"): -55,
                    ("Â", "V"): -135,
                    ("Â", "W"): -90,
                    ("Â", "Y"): -105,
                    ("Â", "v"): -74,
                    ("Â", "w"): -92,
                    ("Â", "y"): -92,
                    ("Â", "Ç"): -40,
                    ("Â", "Ò"): -55,
                    ("Â", "Ó"): -55,
                    ("Â", "Ô"): -55,
                    ("Â", "Õ"): -55,
                    ("Â", "Ö"): -55,
                    ("Â", "Ø"): -55,
                    ("Â", "Ù"): -55,
                    ("Â", "Ú"): -55,
                    ("Â", "Û"): -55,
                    ("Â", "Ü"): -55,
                    ("Â", "Ý"): -105,
                    ("Â", "ý"): -92,
                    ("Â", "ÿ"): -92,
                    ("Â", "Ÿ"): -105,
                    ("Â", "’"): -111,
                    ("Ã", "C"): -40,
                    ("Ã", "G"): -40,
                    ("Ã", "O"): -55,
                    ("Ã", "Q"): -55,
                    ("Ã", "T"): -111,
                    ("Ã", "U"): -55,
                    ("Ã", "V"): -135,
                    ("Ã", "W"): -90,
                    ("Ã", "Y"): -105,
                    ("Ã", "v"): -74,
                    ("Ã", "w"): -92,
                    ("Ã", "y"): -92,
                    ("Ã", "Ç"): -40,
                    ("Ã", "Ò"): -55,
                    ("Ã", "Ó"): -55,
                    ("Ã", "Ô"): -55,
                    ("Ã", "Õ"): -55,
                    ("Ã", "Ö"): -55,
                    ("Ã", "Ø"): -55,
                    ("Ã", "Ù"): -55,
                    ("Ã", "Ú"): -55,
                    ("Ã", "Û"): -55,
                    ("Ã", "Ü"): -55,
                    ("Ã", "Ý"): -105,
                    ("Ã", "ý"): -92,
                    ("Ã", "ÿ"): -92,
                    ("Ã", "Ÿ"): -105,
                    ("Ã", "’"): -111,
                    ("Ä", "C"): -40,
                    ("Ä", "G"): -40,
                    ("Ä", "O"): -55,
                    ("Ä", "Q"): -55,
                    ("Ä", "T"): -111,
                    ("Ä", "U"): -55,
                    ("Ä", "V"): -135,
                    ("Ä", "W"): -90,
                    ("Ä", "Y"): -105,
                    ("Ä", "v"): -74,
                    ("Ä", "w"): -92,
                    ("Ä", "y"): -92,
                    ("Ä", "Ç"): -40,
                    ("Ä", "Ò"): -55,
                    ("Ä", "Ó"): -55,
                    ("Ä", "Ô"): -55,
                    ("Ä", "Õ"): -55,
                    ("Ä", "Ö"): -55,
                    ("Ä", "Ø"): -55,
                    ("Ä", "Ù"): -55,
                    ("Ä", "Ú"): -55,
                    ("Ä", "Û"): -55,
                    ("Ä", "Ü"): -55,
                    ("Ä", "Ý"): -105,
                    ("Ä", "ý"): -92,
                    ("Ä", "ÿ"): -92,
                    ("Ä", "Ÿ"): -105,
                    ("Ä", "’"): -111,
                    ("Å", "C"): -40,
                    ("Å", "G"): -40,
                    ("Å", "O"): -55,
                    ("Å", "Q"): -55,
                    ("Å", "T"): -111,
                    ("Å", "U"): -55,
                    ("Å", "V"): -135,
                    ("Å", "W"): -90,
                    ("Å", "Y"): -105,
                    ("Å", "v"): -74,
                    ("Å", "w"): -92,
                    ("Å", "y"): -92,
                    ("Å", "Ç"): -40,
                    ("Å", "Ò"): -55,
                    ("Å", "Ó"): -55,
                    ("Å", "Ô"): -55,
                    ("Å", "Õ"): -55,
                    ("Å", "Ö"): -55,
                    ("Å", "Ø"): -55,
                    ("Å", "Ù"): -55,
                    ("Å", "Ú"): -55,
                    ("Å", "Û"): -55,
                    ("Å", "Ü"): -55,
                    ("Å", "Ý"): -105,
                    ("Å", "ý"): -92,
                    ("Å", "ÿ"): -92,
                    ("Å", "Ÿ"): -105,
                    ("Å", "’"): -111,
                    ("Ñ", "A"): -35,
                    ("Ñ", "À"): -35,
                    ("Ñ", "Á"): -35,
                    ("Ñ", "Â"): -35,
                    ("Ñ", "Ã"): -35,
                    ("Ñ", "Ä"): -35,
                    ("Ñ", "Å"): -35,
                    ("Ò", "A"): -35,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -35,
                    ("Ò", "X"): -40,
                    ("Ò", "Y"): -50,
                    ("Ò", "À"): -35,
                    ("Ò", "Á"): -35,
                    ("Ò", "Â"): -35,
                    ("Ò", "Ã"): -35,
                    ("Ò", "Ä"): -35,
                    ("Ò", "Å"): -35,
                    ("Ò", "Ý"): -50,
                    ("Ò", "Ÿ"): -50,
                    ("Ó", "A"): -35,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -35,
                    ("Ó", "X"): -40,
                    ("Ó", "Y"): -50,
                    ("Ó", "À"): -35,
                    ("Ó", "Á"): -35,
                    ("Ó", "Â"): -35,
                    ("Ó", "Ã"): -35,
                    ("Ó", "Ä"): -35,
                    ("Ó", "Å"): -35,
                    ("Ó", "Ý"): -50,
                    ("Ó", "Ÿ"): -50,
                    ("Ô", "A"): -35,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -35,
                    ("Ô", "X"): -40,
                    ("Ô", "Y"): -50,
                    ("Ô", "À"): -35,
                    ("Ô", "Á"): -35,
                    ("Ô", "Â"): -35,
                    ("Ô", "Ã"): -35,
                    ("Ô", "Ä"): -35,
                    ("Ô", "Å"): -35,
                    ("Ô", "Ý"): -50,
                    ("Ô", "Ÿ"): -50,
                    ("Õ", "A"): -35,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -35,
                    ("Õ", "X"): -40,
                    ("Õ", "Y"): -50,
                    ("Õ", "À"): -35,
                    ("Õ", "Á"): -35,
                    ("Õ", "Â"): -35,
                    ("Õ", "Ã"): -35,
                    ("Õ", "Ä"): -35,
                    ("Õ", "Å"): -35,
                    ("Õ", "Ý"): -50,
                    ("Õ", "Ÿ"): -50,
                    ("Ö", "A"): -35,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -35,
                    ("Ö", "X"): -40,
                    ("Ö", "Y"): -50,
                    ("Ö", "À"): -35,
                    ("Ö", "Á"): -35,
                    ("Ö", "Â"): -35,
                    ("Ö", "Ã"): -35,
                    ("Ö", "Ä"): -35,
                    ("Ö", "Å"): -35,
                    ("Ö", "Ý"): -50,
                    ("Ö", "Ÿ"): -50,
                    ("Ø", "A"): -35,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -35,
                    ("Ø", "X"): -40,
                    ("Ø", "Y"): -50,
                    ("Ø", "À"): -35,
                    ("Ø", "Á"): -35,
                    ("Ø", "Â"): -35,
                    ("Ø", "Ã"): -35,
                    ("Ø", "Ä"): -35,
                    ("Ø", "Å"): -35,
                    ("Ø", "Ý"): -50,
                    ("Ø", "Ÿ"): -50,
                    ("Ù", "A"): -40,
                    ("Ù", "À"): -40,
                    ("Ù", "Á"): -40,
                    ("Ù", "Â"): -40,
                    ("Ù", "Ã"): -40,
                    ("Ù", "Ä"): -40,
                    ("Ù", "Å"): -40,
                    ("Ú", "A"): -40,
                    ("Ú", "À"): -40,
                    ("Ú", "Á"): -40,
                    ("Ú", "Â"): -40,
                    ("Ú", "Ã"): -40,
                    ("Ú", "Ä"): -40,
                    ("Ú", "Å"): -40,
                    ("Û", "A"): -40,
                    ("Û", "À"): -40,
                    ("Û", "Á"): -40,
                    ("Û", "Â"): -40,
                    ("Û", "Ã"): -40,
                    ("Û", "Ä"): -40,
                    ("Û", "Å"): -40,
                    ("Ü", "A"): -40,
                    ("Ü", "À"): -40,
                    ("Ü", "Á"): -40,
                    ("Ü", "Â"): -40,
                    ("Ü", "Ã"): -40,
                    ("Ü", "Ä"): -40,
                    ("Ü", "Å"): -40,
                    ("Ý", ","): -129,
                    ("Ý", "-"): -111,
                    ("Ý", "."): -129,
                    ("Ý", ":"): -92,
                    ("Ý", ";"): -92,
                    ("Ý", "A"): -120,
                    ("Ý", "O"): -30,
                    ("Ý", "a"): -100,
                    ("Ý", "e"): -100,
                    ("Ý", "i"): -55,
                    ("Ý", "o"): -110,
                    ("Ý", "u"): -111,
                    ("Ý", "À"): -120,
                    ("Ý", "Á"): -120,
                    ("Ý", "Â"): -120,
                    ("Ý", "Ã"): -120,
                    ("Ý", "Ä"): -120,
                    ("Ý", "Å"): -120,
                    ("Ý", "Ò"): -30,
                    ("Ý", "Ó"): -30,
                    ("Ý", "Ô"): -30,
                    ("Ý", "Õ"): -30,
                    ("Ý", "Ö"): -30,
                    ("Ý", "Ø"): -30,
                    ("Ý", "à"): -60,
                    ("Ý", "á"): -100,
                    ("Ý", "â"): -100,
                    ("Ý", "ã"): -60,
                    ("Ý", "ä"): -60,
                    ("Ý", "å"): -100,
                    ("Ý", "è"): -60,
                    ("Ý", "é"): -100,
                    ("Ý", "ê"): -100,
                    ("Ý", "ë"): -60,
                    ("Ý", "í"): -55,
                    ("Ý", "ò"): -70,
                    ("Ý", "ó"): -110,
                    ("Ý", "ô"): -110,
                    ("Ý", "õ"): -70,
                    ("Ý", "ö"): -70,
                    ("Ý", "ø"): -110,
                    ("Ý", "ù"): -71,
                    ("Ý", "ú"): -111,
                    ("Ý", "û"): -111,
                    ("Ý", "ü"): -71,
                    ("à", "v"): -20,
                    ("à", "w"): -15,
                    ("á", "v"): -20,
                    ("á", "w"): -15,
                    ("â", "v"): -20,
                    ("â", "w"): -15,
                    ("ã", "v"): -20,
                    ("ã", "w"): -15,
                    ("ä", "v"): -20,
                    ("ä", "w"): -15,
                    ("å", "v"): -20,
                    ("å", "w"): -15,
                    ("ç", "y"): -15,
                    ("ç", "ý"): -15,
                    ("ç", "ÿ"): -15,
                    ("è", "g"): -15,
                    ("è", "v"): -25,
                    ("è", "w"): -25,
                    ("è", "x"): -15,
                    ("è", "y"): -15,
                    ("è", "ý"): -15,
                    ("è", "ÿ"): -15,
                    ("é", "g"): -15,
                    ("é", "v"): -25,
                    ("é", "w"): -25,
                    ("é", "x"): -15,
                    ("é", "y"): -15,
                    ("é", "ý"): -15,
                    ("é", "ÿ"): -15,
                    ("ê", "g"): -15,
                    ("ê", "v"): -25,
                    ("ê", "w"): -25,
                    ("ê", "x"): -15,
                    ("ê", "y"): -15,
                    ("ê", "ý"): -15,
                    ("ê", "ÿ"): -15,
                    ("ë", "g"): -15,
                    ("ë", "v"): -25,
                    ("ë", "w"): -25,
                    ("ë", "x"): -15,
                    ("ë", "y"): -15,
                    ("ë", "ý"): -15,
                    ("ë", "ÿ"): -15,
                    ("ì", "v"): -25,
                    ("í", "v"): -25,
                    ("î", "v"): -25,
                    ("ï", "v"): -25,
                    ("ñ", "v"): -40,
                    ("ñ", "y"): -15,
                    ("ñ", "ý"): -15,
                    ("ñ", "ÿ"): -15,
                    ("ò", "v"): -15,
                    ("ò", "w"): -25,
                    ("ò", "y"): -10,
                    ("ò", "ý"): -10,
                    ("ò", "ÿ"): -10,
                    ("ó", "v"): -15,
                    ("ó", "w"): -25,
                    ("ó", "y"): -10,
                    ("ó", "ý"): -10,
                    ("ó", "ÿ"): -10,
                    ("ô", "v"): -15,
                    ("ô", "w"): -25,
                    ("ô", "y"): -10,
                    ("ô", "ý"): -10,
                    ("ô", "ÿ"): -10,
                    ("õ", "v"): -15,
                    ("õ", "w"): -25,
                    ("õ", "y"): -10,
                    ("õ", "ý"): -10,
                    ("õ", "ÿ"): -10,
                    ("ö", "v"): -15,
                    ("ö", "w"): -25,
                    ("ö", "y"): -10,
                    ("ö", "ý"): -10,
                    ("ö", "ÿ"): -10,
                    ("ø", "v"): -15,
                    ("ø", "w"): -25,
                    ("ø", "y"): -10,
                    ("ø", "ý"): -10,
                    ("ø", "ÿ"): -10,
                    ("ý", ","): -65,
                    ("ý", "."): -65,
                    ("ÿ", ","): -65,
                    ("ÿ", "."): -65,
                    ("Ł", "T"): -92,
                    ("Ł", "V"): -100,
                    ("Ł", "W"): -74,
                    ("Ł", "Y"): -100,
                    ("Ł", "y"): -55,
                    ("Ł", "Ý"): -100,
                    ("Ł", "ý"): -55,
                    ("Ł", "ÿ"): -55,
                    ("Ł", "Ÿ"): -100,
                    ("Ł", "’"): -92,
                    ("ł", "w"): -10,
                    ("Ÿ", ","): -129,
                    ("Ÿ", "-"): -111,
                    ("Ÿ", "."): -129,
                    ("Ÿ", ":"): -92,
                    ("Ÿ", ";"): -92,
                    ("Ÿ", "A"): -120,
                    ("Ÿ", "O"): -30,
                    ("Ÿ", "a"): -100,
                    ("Ÿ", "e"): -100,
                    ("Ÿ", "i"): -55,
                    ("Ÿ", "o"): -110,
                    ("Ÿ", "u"): -111,
                    ("Ÿ", "À"): -120,
                    ("Ÿ", "Á"): -120,
                    ("Ÿ", "Â"): -120,
                    ("Ÿ", "Ã"): -120,
                    ("Ÿ", "Ä"): -120,
                    ("Ÿ", "Å"): -120,
                    ("Ÿ", "Ò"): -30,
                    ("Ÿ", "Ó"): -30,
                    ("Ÿ", "Ô"): -30,
                    ("Ÿ", "Õ"): -30,
                    ("Ÿ", "Ö"): -30,
                    ("Ÿ", "Ø"): -30,
                    ("Ÿ", "à"): -60,
                    ("Ÿ", "á"): -100,
                    ("Ÿ", "â"): -100,
                    ("Ÿ", "ã"): -100,
                    ("Ÿ", "ä"): -60,
                    ("Ÿ", "å"): -100,
                    ("Ÿ", "è"): -60,
                    ("Ÿ", "é"): -100,
                    ("Ÿ", "ê"): -100,
                    ("Ÿ", "ë"): -60,
                    ("Ÿ", "í"): -55,
                    ("Ÿ", "ò"): -70,
                    ("Ÿ", "ó"): -110,
                    ("Ÿ", "ô"): -110,
                    ("Ÿ", "õ"): -70,
                    ("Ÿ", "ö"): -70,
                    ("Ÿ", "ø"): -110,
                    ("Ÿ", "ù"): -71,
                    ("Ÿ", "ú"): -111,
                    ("Ÿ", "û"): -111,
                    ("Ÿ", "ü"): -71,
                    ("‘", "A"): -80,
                    ("‘", "À"): -80,
                    ("‘", "Á"): -80,
                    ("‘", "Â"): -80,
                    ("‘", "Ã"): -80,
                    ("‘", "Ä"): -80,
                    ("‘", "Å"): -80,
                    ("‘", "‘"): -74,
                    ("’", " "): -74,
                    ("’", "d"): -50,
                    ("’", "l"): -10,
                    ("’", "r"): -50,
                    ("’", "s"): -55,
                    ("’", "t"): -18,
                    ("’", "v"): -50,
                    ("’", "ł"): -10,
                    ("’", "š"): -55,
                    ("’", "’"): -74,
                    ("“", "A"): -80,
                    ("“", "À"): -80,
                    ("“", "Á"): -80,
                    ("“", "Â"): -80,
                    ("“", "Ã"): -80,
                    ("“", "Ä"): -80,
                    ("“", "Å"): -80,
                },
                0,
            ),
        ),
        BuiltinFont(
            b"Times-Bold",
            b"f5",
            dictget(
                {
                    " ": 250,
                    "!": 333,
                    '"': 555,
                    "#": 500,
                    "$": 500,
                    "%": 1000,
                    "&": 833,
                    "'": 278,
                    "(": 333,
                    ")": 333,
                    "*": 500,
                    "+": 570,
                    ",": 250,
                    "-": 333,
                    ".": 250,
                    "/": 278,
                    "0": 500,
                    "1": 500,
                    "2": 500,
                    "3": 500,
                    "4": 500,
                    "5": 500,
                    "6": 500,
                    "7": 500,
                    "8": 500,
                    "9": 500,
                    ":": 333,
                    ";": 333,
                    "<": 570,
                    "=": 570,
                    ">": 570,
                    "?": 500,
                    "@": 930,
                    "A": 722,
                    "B": 667,
                    "C": 722,
                    "D": 722,
                    "E": 667,
                    "F": 611,
                    "G": 778,
                    "H": 778,
                    "I": 389,
                    "J": 500,
                    "K": 778,
                    "L": 667,
                    "M": 944,
                    "N": 722,
                    "O": 778,
                    "P": 611,
                    "Q": 778,
                    "R": 722,
                    "S": 556,
                    "T": 667,
                    "U": 722,
                    "V": 722,
                    "W": 1000,
                    "X": 722,
                    "Y": 722,
                    "Z": 667,
                    "[": 333,
                    "\\": 278,
                    "]": 333,
                    "^": 581,
                    "_": 500,
                    "`": 333,
                    "a": 500,
                    "b": 556,
                    "c": 444,
                    "d": 556,
                    "e": 444,
                    "f": 333,
                    "g": 500,
                    "h": 556,
                    "i": 278,
                    "j": 333,
                    "k": 556,
                    "l": 278,
                    "m": 833,
                    "n": 556,
                    "o": 500,
                    "p": 556,
                    "q": 556,
                    "r": 444,
                    "s": 389,
                    "t": 333,
                    "u": 556,
                    "v": 500,
                    "w": 722,
                    "x": 500,
                    "y": 500,
                    "z": 444,
                    "{": 394,
                    "|": 220,
                    "}": 394,
                    "~": 520,
                    "¡": 333,
                    "¢": 500,
                    "£": 500,
                    "¤": 500,
                    "¥": 500,
                    "¦": 220,
                    "§": 500,
                    "©": 747,
                    "ª": 300,
                    "«": 500,
                    "¬": 570,
                    "®": 747,
                    "°": 400,
                    "±": 570,
                    "²": 300,
                    "³": 300,
                    "¶": 540,
                    "·": 250,
                    "¹": 300,
                    "º": 330,
                    "»": 500,
                    "¼": 750,
                    "½": 750,
                    "¾": 750,
                    "¿": 500,
                    "À": 722,
                    "Á": 722,
                    "Â": 722,
                    "Ã": 722,
                    "Ä": 722,
                    "Å": 722,
                    "Æ": 1000,
                    "Ç": 722,
                    "È": 667,
                    "É": 667,
                    "Ê": 667,
                    "Ë": 667,
                    "Ì": 389,
                    "Í": 389,
                    "Î": 389,
                    "Ï": 389,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 778,
                    "Ó": 778,
                    "Ô": 778,
                    "Õ": 778,
                    "Ö": 778,
                    "×": 570,
                    "Ø": 778,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 722,
                    "Þ": 611,
                    "ß": 556,
                    "à": 500,
                    "á": 500,
                    "â": 500,
                    "ã": 500,
                    "ä": 500,
                    "å": 500,
                    "æ": 722,
                    "ç": 444,
                    "è": 444,
                    "é": 444,
                    "ê": 444,
                    "ë": 444,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 500,
                    "ñ": 556,
                    "ò": 500,
                    "ó": 500,
                    "ô": 500,
                    "õ": 500,
                    "ö": 500,
                    "÷": 570,
                    "ø": 500,
                    "ù": 556,
                    "ú": 556,
                    "û": 556,
                    "ü": 556,
                    "ý": 500,
                    "þ": 556,
                    "ÿ": 500,
                    "ı": 278,
                    "Ł": 667,
                    "ł": 278,
                    "Œ": 1000,
                    "œ": 722,
                    "Š": 556,
                    "š": 389,
                    "Ÿ": 722,
                    "Ž": 667,
                    "ž": 444,
                    "ƒ": 500,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 556,
                    "–": 500,
                    "—": 1000,
                    "‘": 333,
                    "’": 333,
                    "‚": 333,
                    "“": 500,
                    "”": 500,
                    "„": 500,
                    "†": 500,
                    "‡": 500,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 500,
                    "™": 1000,
                    "−": 570,
                    "ﬁ": 556,
                    "ﬂ": 556,
                },
                500,
            ),
            dictget(
                {
                    (" ", "A"): -55,
                    (" ", "T"): -30,
                    (" ", "V"): -45,
                    (" ", "W"): -30,
                    (" ", "Y"): -55,
                    (" ", "À"): -55,
                    (" ", "Á"): -55,
                    (" ", "Â"): -55,
                    (" ", "Ã"): -55,
                    (" ", "Ä"): -55,
                    (" ", "Å"): -55,
                    (" ", "Ý"): -55,
                    (" ", "Ÿ"): -55,
                    (",", "’"): -55,
                    (",", "”"): -45,
                    (".", "’"): -55,
                    (".", "”"): -55,
                    ("A", "C"): -55,
                    ("A", "G"): -55,
                    ("A", "O"): -45,
                    ("A", "Q"): -45,
                    ("A", "T"): -95,
                    ("A", "U"): -50,
                    ("A", "V"): -145,
                    ("A", "W"): -130,
                    ("A", "Y"): -100,
                    ("A", "p"): -25,
                    ("A", "u"): -50,
                    ("A", "v"): -100,
                    ("A", "w"): -90,
                    ("A", "y"): -74,
                    ("A", "Ç"): -55,
                    ("A", "Ò"): -45,
                    ("A", "Ó"): -45,
                    ("A", "Ô"): -45,
                    ("A", "Õ"): -45,
                    ("A", "Ö"): -45,
                    ("A", "Ø"): -45,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -100,
                    ("A", "ù"): -50,
                    ("A", "ú"): -50,
                    ("A", "û"): -50,
                    ("A", "ü"): -50,
                    ("A", "ý"): -74,
                    ("A", "ÿ"): -74,
                    ("A", "Ÿ"): -100,
                    ("A", "’"): -74,
                    ("B", "A"): -30,
                    ("B", "U"): -10,
                    ("B", "À"): -30,
                    ("B", "Á"): -30,
                    ("B", "Â"): -30,
                    ("B", "Ã"): -30,
                    ("B", "Ä"): -30,
                    ("B", "Å"): -30,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("D", "."): -20,
                    ("D", "A"): -35,
                    ("D", "V"): -40,
                    ("D", "W"): -40,
                    ("D", "Y"): -40,
                    ("D", "À"): -35,
                    ("D", "Á"): -35,
                    ("D", "Â"): -35,
                    ("D", "Ã"): -35,
                    ("D", "Ä"): -35,
                    ("D", "Å"): -35,
                    ("D", "Ý"): -40,
                    ("D", "Ÿ"): -40,
                    ("F", ","): -92,
                    ("F", "."): -110,
                    ("F", "A"): -90,
                    ("F", "a"): -25,
                    ("F", "e"): -25,
                    ("F", "o"): -25,
                    ("F", "À"): -90,
                    ("F", "Á"): -90,
                    ("F", "Â"): -90,
                    ("F", "Ã"): -90,
                    ("F", "Ä"): -90,
                    ("F", "Å"): -90,
                    ("F", "à"): -25,
                    ("F", "á"): -25,
                    ("F", "â"): -25,
                    ("F", "ã"): -25,
                    ("F", "ä"): -25,
                    ("F", "å"): -25,
                    ("F", "è"): -25,
                    ("F", "é"): -25,
                    ("F", "ê"): -25,
                    ("F", "ë"): -25,
                    ("F", "ò"): -25,
                    ("F", "ó"): -25,
                    ("F", "ô"): -25,
                    ("F", "õ"): -25,
                    ("F", "ö"): -25,
                    ("F", "ø"): -25,
                    ("J", "."): -20,
                    ("J", "A"): -30,
                    ("J", "a"): -15,
                    ("J", "e"): -15,
                    ("J", "o"): -15,
                    ("J", "u"): -15,
                    ("J", "À"): -30,
                    ("J", "Á"): -30,
                    ("J", "Â"): -30,
                    ("J", "Ã"): -30,
                    ("J", "Ä"): -30,
                    ("J", "Å"): -30,
                    ("J", "à"): -15,
                    ("J", "á"): -15,
                    ("J", "â"): -15,
                    ("J", "ã"): -15,
                    ("J", "ä"): -15,
                    ("J", "å"): -15,
                    ("J", "è"): -15,
                    ("J", "é"): -15,
                    ("J", "ê"): -15,
                    ("J", "ë"): -15,
                    ("J", "ò"): -15,
                    ("J", "ó"): -15,
                    ("J", "ô"): -15,
                    ("J", "õ"): -15,
                    ("J", "ö"): -15,
                    ("J", "ø"): -15,
                    ("J", "ù"): -15,
                    ("J", "ú"): -15,
                    ("J", "û"): -15,
                    ("J", "ü"): -15,
                    ("K", "O"): -30,
                    ("K", "e"): -25,
                    ("K", "o"): -25,
                    ("K", "u"): -15,
                    ("K", "y"): -45,
                    ("K", "Ò"): -30,
                    ("K", "Ó"): -30,
                    ("K", "Ô"): -30,
                    ("K", "Õ"): -30,
                    ("K", "Ö"): -30,
                    ("K", "Ø"): -30,
                    ("K", "è"): -25,
                    ("K", "é"): -25,
                    ("K", "ê"): -25,
                    ("K", "ë"): -25,
                    ("K", "ò"): -25,
                    ("K", "ó"): -25,
                    ("K", "ô"): -25,
                    ("K", "õ"): -25,
                    ("K", "ö"): -25,
                    ("K", "ø"): -25,
                    ("K", "ù"): -15,
                    ("K", "ú"): -15,
                    ("K", "û"): -15,
                    ("K", "ü"): -15,
                    ("K", "ý"): -45,
                    ("K", "ÿ"): -45,
                    ("L", "T"): -92,
                    ("L", "V"): -92,
                    ("L", "W"): -92,
                    ("L", "Y"): -92,
                    ("L", "y"): -55,
                    ("L", "Ý"): -92,
                    ("L", "ý"): -55,
                    ("L", "ÿ"): -55,
                    ("L", "Ÿ"): -92,
                    ("L", "’"): -110,
                    ("L", "”"): -20,
                    ("N", "A"): -20,
                    ("N", "À"): -20,
                    ("N", "Á"): -20,
                    ("N", "Â"): -20,
                    ("N", "Ã"): -20,
                    ("N", "Ä"): -20,
                    ("N", "Å"): -20,
                    ("O", "A"): -40,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -50,
                    ("O", "X"): -40,
                    ("O", "Y"): -50,
                    ("O", "À"): -40,
                    ("O", "Á"): -40,
                    ("O", "Â"): -40,
                    ("O", "Ã"): -40,
                    ("O", "Ä"): -40,
                    ("O", "Å"): -40,
                    ("O", "Ý"): -50,
                    ("O", "Ÿ"): -50,
                    ("P", ","): -92,
                    ("P", "."): -110,
                    ("P", "A"): -74,
                    ("P", "a"): -10,
                    ("P", "e"): -20,
                    ("P", "o"): -20,
                    ("P", "À"): -74,
                    ("P", "Á"): -74,
                    ("P", "Â"): -74,
                    ("P", "Ã"): -74,
                    ("P", "Ä"): -74,
                    ("P", "Å"): -74,
                    ("P", "à"): -10,
                    ("P", "á"): -10,
                    ("P", "â"): -10,
                    ("P", "ã"): -10,
                    ("P", "ä"): -10,
                    ("P", "å"): -10,
                    ("P", "è"): -20,
                    ("P", "é"): -20,
                    ("P", "ê"): -20,
                    ("P", "ë"): -20,
                    ("P", "ò"): -20,
                    ("P", "ó"): -20,
                    ("P", "ô"): -20,
                    ("P", "õ"): -20,
                    ("P", "ö"): -20,
                    ("P", "ø"): -20,
                    ("Q", "."): -20,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -30,
                    ("R", "T"): -40,
                    ("R", "U"): -30,
                    ("R", "V"): -55,
                    ("R", "W"): -35,
                    ("R", "Y"): -35,
                    ("R", "Ò"): -30,
                    ("R", "Ó"): -30,
                    ("R", "Ô"): -30,
                    ("R", "Õ"): -30,
                    ("R", "Ö"): -30,
                    ("R", "Ø"): -30,
                    ("R", "Ù"): -30,
                    ("R", "Ú"): -30,
                    ("R", "Û"): -30,
                    ("R", "Ü"): -30,
                    ("R", "Ý"): -35,
                    ("R", "Ÿ"): -35,
                    ("T", ","): -74,
                    ("T", "-"): -92,
                    ("T", "."): -90,
                    ("T", ":"): -74,
                    ("T", ";"): -74,
                    ("T", "A"): -90,
                    ("T", "O"): -18,
                    ("T", "a"): -92,
                    ("T", "e"): -92,
                    ("T", "i"): -18,
                    ("T", "o"): -92,
                    ("T", "r"): -74,
                    ("T", "u"): -92,
                    ("T", "w"): -74,
                    ("T", "y"): -34,
                    ("T", "À"): -90,
                    ("T", "Á"): -90,
                    ("T", "Â"): -90,
                    ("T", "Ã"): -90,
                    ("T", "Ä"): -90,
                    ("T", "Å"): -90,
                    ("T", "Ò"): -18,
                    ("T", "Ó"): -18,
                    ("T", "Ô"): -18,
                    ("T", "Õ"): -18,
                    ("T", "Ö"): -18,
                    ("T", "Ø"): -18,
                    ("T", "à"): -52,
                    ("T", "á"): -92,
                    ("T", "â"): -52,
                    ("T", "ã"): -52,
                    ("T", "ä"): -52,
                    ("T", "å"): -92,
                    ("T", "è"): -52,
                    ("T", "é"): -92,
                    ("T", "ê"): -92,
                    ("T", "ë"): -52,
                    ("T", "í"): -18,
                    ("T", "ò"): -92,
                    ("T", "ó"): -92,
                    ("T", "ô"): -92,
                    ("T", "õ"): -92,
                    ("T", "ö"): -92,
                    ("T", "ø"): -92,
                    ("T", "ù"): -92,
                    ("T", "ú"): -92,
                    ("T", "û"): -92,
                    ("T", "ü"): -92,
                    ("T", "ý"): -34,
                    ("T", "ÿ"): -34,
                    ("U", ","): -50,
                    ("U", "."): -50,
                    ("U", "A"): -60,
                    ("U", "À"): -60,
                    ("U", "Á"): -60,
                    ("U", "Â"): -60,
                    ("U", "Ã"): -60,
                    ("U", "Ä"): -60,
                    ("U", "Å"): -60,
                    ("V", ","): -129,
                    ("V", "-"): -74,
                    ("V", "."): -145,
                    ("V", ":"): -92,
                    ("V", ";"): -92,
                    ("V", "A"): -135,
                    ("V", "G"): -30,
                    ("V", "O"): -45,
                    ("V", "a"): -92,
                    ("V", "e"): -100,
                    ("V", "i"): -37,
                    ("V", "o"): -100,
                    ("V", "u"): -92,
                    ("V", "À"): -135,
                    ("V", "Á"): -135,
                    ("V", "Â"): -135,
                    ("V", "Ã"): -135,
                    ("V", "Ä"): -135,
                    ("V", "Å"): -135,
                    ("V", "Ò"): -45,
                    ("V", "Ó"): -45,
                    ("V", "Ô"): -45,
                    ("V", "Õ"): -45,
                    ("V", "Ö"): -45,
                    ("V", "Ø"): -45,
                    ("V", "à"): -92,
                    ("V", "á"): -92,
                    ("V", "â"): -92,
                    ("V", "ã"): -92,
                    ("V", "ä"): -92,
                    ("V", "å"): -92,
                    ("V", "è"): -100,
                    ("V", "é"): -100,
                    ("V", "ê"): -100,
                    ("V", "ë"): -100,
                    ("V", "ì"): -37,
                    ("V", "í"): -37,
                    ("V", "î"): -37,
                    ("V", "ï"): -37,
                    ("V", "ò"): -100,
                    ("V", "ó"): -100,
                    ("V", "ô"): -100,
                    ("V", "õ"): -100,
                    ("V", "ö"): -100,
                    ("V", "ø"): -100,
                    ("V", "ù"): -92,
                    ("V", "ú"): -92,
                    ("V", "û"): -92,
                    ("V", "ü"): -92,
                    ("W", ","): -92,
                    ("W", "-"): -37,
                    ("W", "."): -92,
                    ("W", ":"): -55,
                    ("W", ";"): -55,
                    ("W", "A"): -120,
                    ("W", "O"): -10,
                    ("W", "a"): -65,
                    ("W", "e"): -65,
                    ("W", "i"): -18,
                    ("W", "o"): -75,
                    ("W", "u"): -50,
                    ("W", "y"): -60,
                    ("W", "À"): -120,
                    ("W", "Á"): -120,
                    ("W", "Â"): -120,
                    ("W", "Ã"): -120,
                    ("W", "Ä"): -120,
                    ("W", "Å"): -120,
                    ("W", "Ò"): -10,
                    ("W", "Ó"): -10,
                    ("W", "Ô"): -10,
                    ("W", "Õ"): -10,
                    ("W", "Ö"): -10,
                    ("W", "Ø"): -10,
                    ("W", "à"): -65,
                    ("W", "á"): -65,
                    ("W", "â"): -65,
                    ("W", "ã"): -65,
                    ("W", "ä"): -65,
                    ("W", "å"): -65,
                    ("W", "è"): -65,
                    ("W", "é"): -65,
                    ("W", "ê"): -65,
                    ("W", "ë"): -65,
                    ("W", "í"): -18,
                    ("W", "ò"): -75,
                    ("W", "ó"): -75,
                    ("W", "ô"): -75,
                    ("W", "õ"): -75,
                    ("W", "ö"): -75,
                    ("W", "ø"): -75,
                    ("W", "ù"): -50,
                    ("W", "ú"): -50,
                    ("W", "û"): -50,
                    ("W", "ü"): -50,
                    ("W", "ý"): -60,
                    ("W", "ÿ"): -60,
                    ("Y", ","): -92,
                    ("Y", "-"): -92,
                    ("Y", "."): -92,
                    ("Y", ":"): -92,
                    ("Y", ";"): -92,
                    ("Y", "A"): -110,
                    ("Y", "O"): -35,
                    ("Y", "a"): -85,
                    ("Y", "e"): -111,
                    ("Y", "i"): -37,
                    ("Y", "o"): -111,
                    ("Y", "u"): -92,
                    ("Y", "À"): -110,
                    ("Y", "Á"): -110,
                    ("Y", "Â"): -110,
                    ("Y", "Ã"): -110,
                    ("Y", "Ä"): -110,
                    ("Y", "Å"): -110,
                    ("Y", "Ò"): -35,
                    ("Y", "Ó"): -35,
                    ("Y", "Ô"): -35,
                    ("Y", "Õ"): -35,
                    ("Y", "Ö"): -35,
                    ("Y", "Ø"): -35,
                    ("Y", "à"): -85,
                    ("Y", "á"): -85,
                    ("Y", "â"): -85,
                    ("Y", "ã"): -85,
                    ("Y", "ä"): -85,
                    ("Y", "å"): -85,
                    ("Y", "è"): -71,
                    ("Y", "é"): -111,
                    ("Y", "ê"): -111,
                    ("Y", "ë"): -71,
                    ("Y", "í"): -37,
                    ("Y", "ò"): -111,
                    ("Y", "ó"): -111,
                    ("Y", "ô"): -111,
                    ("Y", "õ"): -111,
                    ("Y", "ö"): -111,
                    ("Y", "ø"): -111,
                    ("Y", "ù"): -92,
                    ("Y", "ú"): -92,
                    ("Y", "û"): -92,
                    ("Y", "ü"): -92,
                    ("a", "v"): -25,
                    ("b", "."): -40,
                    ("b", "b"): -10,
                    ("b", "u"): -20,
                    ("b", "v"): -15,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("d", "w"): -15,
                    ("e", "v"): -15,
                    ("f", ","): -15,
                    ("f", "."): -15,
                    ("f", "i"): -25,
                    ("f", "o"): -25,
                    ("f", "ò"): -25,
                    ("f", "ó"): -25,
                    ("f", "ô"): -25,
                    ("f", "õ"): -25,
                    ("f", "ö"): -25,
                    ("f", "ø"): -25,
                    ("f", "ı"): -35,
                    ("f", "’"): 55,
                    ("f", "”"): 50,
                    ("g", "."): -15,
                    ("h", "y"): -15,
                    ("h", "ý"): -15,
                    ("h", "ÿ"): -15,
                    ("i", "v"): -10,
                    ("k", "e"): -10,
                    ("k", "o"): -15,
                    ("k", "y"): -15,
                    ("k", "è"): -10,
                    ("k", "é"): -10,
                    ("k", "ê"): -10,
                    ("k", "ë"): -10,
                    ("k", "ò"): -15,
                    ("k", "ó"): -15,
                    ("k", "ô"): -15,
                    ("k", "õ"): -15,
                    ("k", "ö"): -15,
                    ("k", "ø"): -15,
                    ("k", "ý"): -15,
                    ("k", "ÿ"): -15,
                    ("n", "v"): -40,
                    ("o", "v"): -10,
                    ("o", "w"): -10,
                    ("r", ","): -92,
                    ("r", "-"): -37,
                    ("r", "."): -100,
                    ("r", "c"): -18,
                    ("r", "e"): -18,
                    ("r", "g"): -10,
                    ("r", "n"): -15,
                    ("r", "o"): -18,
                    ("r", "p"): -10,
                    ("r", "q"): -18,
                    ("r", "v"): -10,
                    ("r", "ç"): -18,
                    ("r", "è"): -18,
                    ("r", "é"): -18,
                    ("r", "ê"): -18,
                    ("r", "ë"): -18,
                    ("r", "ñ"): -15,
                    ("r", "ò"): -18,
                    ("r", "ó"): -18,
                    ("r", "ô"): -18,
                    ("r", "õ"): -18,
                    ("r", "ö"): -18,
                    ("r", "ø"): -18,
                    ("v", ","): -55,
                    ("v", "."): -70,
                    ("v", "a"): -10,
                    ("v", "e"): -10,
                    ("v", "o"): -10,
                    ("v", "à"): -10,
                    ("v", "á"): -10,
                    ("v", "â"): -10,
                    ("v", "ã"): -10,
                    ("v", "ä"): -10,
                    ("v", "å"): -10,
                    ("v", "è"): -10,
                    ("v", "é"): -10,
                    ("v", "ê"): -10,
                    ("v", "ë"): -10,
                    ("v", "ò"): -10,
                    ("v", "ó"): -10,
                    ("v", "ô"): -10,
                    ("v", "õ"): -10,
                    ("v", "ö"): -10,
                    ("v", "ø"): -10,
                    ("w", ","): -55,
                    ("w", "."): -70,
                    ("w", "o"): -10,
                    ("w", "ò"): -10,
                    ("w", "ó"): -10,
                    ("w", "ô"): -10,
                    ("w", "õ"): -10,
                    ("w", "ö"): -10,
                    ("w", "ø"): -10,
                    ("y", ","): -55,
                    ("y", "."): -70,
                    ("y", "e"): -10,
                    ("y", "o"): -25,
                    ("y", "è"): -10,
                    ("y", "é"): -10,
                    ("y", "ê"): -10,
                    ("y", "ë"): -10,
                    ("y", "ò"): -25,
                    ("y", "ó"): -25,
                    ("y", "ô"): -25,
                    ("y", "õ"): -25,
                    ("y", "ö"): -25,
                    ("y", "ø"): -25,
                    ("À", "C"): -55,
                    ("À", "G"): -55,
                    ("À", "O"): -45,
                    ("À", "Q"): -45,
                    ("À", "T"): -95,
                    ("À", "U"): -50,
                    ("À", "V"): -145,
                    ("À", "W"): -130,
                    ("À", "Y"): -100,
                    ("À", "p"): -25,
                    ("À", "u"): -50,
                    ("À", "v"): -100,
                    ("À", "w"): -90,
                    ("À", "y"): -74,
                    ("À", "Ç"): -55,
                    ("À", "Ò"): -45,
                    ("À", "Ó"): -45,
                    ("À", "Ô"): -45,
                    ("À", "Õ"): -45,
                    ("À", "Ö"): -45,
                    ("À", "Ø"): -45,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -100,
                    ("À", "ù"): -50,
                    ("À", "ú"): -50,
                    ("À", "û"): -50,
                    ("À", "ü"): -50,
                    ("À", "ý"): -74,
                    ("À", "ÿ"): -74,
                    ("À", "Ÿ"): -100,
                    ("À", "’"): -74,
                    ("Á", "C"): -55,
                    ("Á", "G"): -55,
                    ("Á", "O"): -45,
                    ("Á", "Q"): -45,
                    ("Á", "T"): -95,
                    ("Á", "U"): -50,
                    ("Á", "V"): -145,
                    ("Á", "W"): -130,
                    ("Á", "Y"): -100,
                    ("Á", "p"): -25,
                    ("Á", "u"): -50,
                    ("Á", "v"): -100,
                    ("Á", "w"): -90,
                    ("Á", "y"): -74,
                    ("Á", "Ç"): -55,
                    ("Á", "Ò"): -45,
                    ("Á", "Ó"): -45,
                    ("Á", "Ô"): -45,
                    ("Á", "Õ"): -45,
                    ("Á", "Ö"): -45,
                    ("Á", "Ø"): -45,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -100,
                    ("Á", "ù"): -50,
                    ("Á", "ú"): -50,
                    ("Á", "û"): -50,
                    ("Á", "ü"): -50,
                    ("Á", "ý"): -74,
                    ("Á", "ÿ"): -74,
                    ("Á", "Ÿ"): -100,
                    ("Á", "’"): -74,
                    ("Â", "C"): -55,
                    ("Â", "G"): -55,
                    ("Â", "O"): -45,
                    ("Â", "Q"): -45,
                    ("Â", "T"): -95,
                    ("Â", "U"): -50,
                    ("Â", "V"): -145,
                    ("Â", "W"): -130,
                    ("Â", "Y"): -100,
                    ("Â", "p"): -25,
                    ("Â", "u"): -50,
                    ("Â", "v"): -100,
                    ("Â", "w"): -90,
                    ("Â", "y"): -74,
                    ("Â", "Ç"): -55,
                    ("Â", "Ò"): -45,
                    ("Â", "Ó"): -45,
                    ("Â", "Ô"): -45,
                    ("Â", "Õ"): -45,
                    ("Â", "Ö"): -45,
                    ("Â", "Ø"): -45,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -100,
                    ("Â", "ù"): -50,
                    ("Â", "ú"): -50,
                    ("Â", "û"): -50,
                    ("Â", "ü"): -50,
                    ("Â", "ý"): -74,
                    ("Â", "ÿ"): -74,
                    ("Â", "Ÿ"): -100,
                    ("Â", "’"): -74,
                    ("Ã", "C"): -55,
                    ("Ã", "G"): -55,
                    ("Ã", "O"): -45,
                    ("Ã", "Q"): -45,
                    ("Ã", "T"): -95,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -145,
                    ("Ã", "W"): -130,
                    ("Ã", "Y"): -100,
                    ("Ã", "p"): -25,
                    ("Ã", "u"): -50,
                    ("Ã", "v"): -100,
                    ("Ã", "w"): -90,
                    ("Ã", "y"): -74,
                    ("Ã", "Ç"): -55,
                    ("Ã", "Ò"): -45,
                    ("Ã", "Ó"): -45,
                    ("Ã", "Ô"): -45,
                    ("Ã", "Õ"): -45,
                    ("Ã", "Ö"): -45,
                    ("Ã", "Ø"): -45,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -100,
                    ("Ã", "ù"): -50,
                    ("Ã", "ú"): -50,
                    ("Ã", "û"): -50,
                    ("Ã", "ü"): -50,
                    ("Ã", "ý"): -74,
                    ("Ã", "ÿ"): -74,
                    ("Ã", "Ÿ"): -100,
                    ("Ã", "’"): -74,
                    ("Ä", "C"): -55,
                    ("Ä", "G"): -55,
                    ("Ä", "O"): -45,
                    ("Ä", "Q"): -45,
                    ("Ä", "T"): -95,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -145,
                    ("Ä", "W"): -130,
                    ("Ä", "Y"): -100,
                    ("Ä", "p"): -25,
                    ("Ä", "u"): -50,
                    ("Ä", "v"): -100,
                    ("Ä", "w"): -90,
                    ("Ä", "y"): -74,
                    ("Ä", "Ç"): -55,
                    ("Ä", "Ò"): -45,
                    ("Ä", "Ó"): -45,
                    ("Ä", "Ô"): -45,
                    ("Ä", "Õ"): -45,
                    ("Ä", "Ö"): -45,
                    ("Ä", "Ø"): -45,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -100,
                    ("Ä", "ù"): -50,
                    ("Ä", "ú"): -50,
                    ("Ä", "û"): -50,
                    ("Ä", "ü"): -50,
                    ("Ä", "ý"): -74,
                    ("Ä", "ÿ"): -74,
                    ("Ä", "Ÿ"): -100,
                    ("Ä", "’"): -74,
                    ("Å", "C"): -55,
                    ("Å", "G"): -55,
                    ("Å", "O"): -45,
                    ("Å", "Q"): -45,
                    ("Å", "T"): -95,
                    ("Å", "U"): -50,
                    ("Å", "V"): -145,
                    ("Å", "W"): -130,
                    ("Å", "Y"): -100,
                    ("Å", "p"): -25,
                    ("Å", "u"): -50,
                    ("Å", "v"): -100,
                    ("Å", "w"): -90,
                    ("Å", "y"): -74,
                    ("Å", "Ç"): -55,
                    ("Å", "Ò"): -45,
                    ("Å", "Ó"): -45,
                    ("Å", "Ô"): -45,
                    ("Å", "Õ"): -45,
                    ("Å", "Ö"): -45,
                    ("Å", "Ø"): -45,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -100,
                    ("Å", "ù"): -50,
                    ("Å", "ú"): -50,
                    ("Å", "û"): -50,
                    ("Å", "ü"): -50,
                    ("Å", "ý"): -74,
                    ("Å", "ÿ"): -74,
                    ("Å", "Ÿ"): -100,
                    ("Å", "’"): -74,
                    ("Ñ", "A"): -20,
                    ("Ñ", "À"): -20,
                    ("Ñ", "Á"): -20,
                    ("Ñ", "Â"): -20,
                    ("Ñ", "Ã"): -20,
                    ("Ñ", "Ä"): -20,
                    ("Ñ", "Å"): -20,
                    ("Ò", "A"): -40,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -50,
                    ("Ò", "X"): -40,
                    ("Ò", "Y"): -50,
                    ("Ò", "À"): -40,
                    ("Ò", "Á"): -40,
                    ("Ò", "Â"): -40,
                    ("Ò", "Ã"): -40,
                    ("Ò", "Ä"): -40,
                    ("Ò", "Å"): -40,
                    ("Ò", "Ý"): -50,
                    ("Ò", "Ÿ"): -50,
                    ("Ó", "A"): -40,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -50,
                    ("Ó", "X"): -40,
                    ("Ó", "Y"): -50,
                    ("Ó", "À"): -40,
                    ("Ó", "Á"): -40,
                    ("Ó", "Â"): -40,
                    ("Ó", "Ã"): -40,
                    ("Ó", "Ä"): -40,
                    ("Ó", "Å"): -40,
                    ("Ó", "Ý"): -50,
                    ("Ó", "Ÿ"): -50,
                    ("Ô", "A"): -40,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -50,
                    ("Ô", "X"): -40,
                    ("Ô", "Y"): -50,
                    ("Ô", "À"): -40,
                    ("Ô", "Á"): -40,
                    ("Ô", "Â"): -40,
                    ("Ô", "Ã"): -40,
                    ("Ô", "Ä"): -40,
                    ("Ô", "Å"): -40,
                    ("Ô", "Ý"): -50,
                    ("Ô", "Ÿ"): -50,
                    ("Õ", "A"): -40,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -50,
                    ("Õ", "X"): -40,
                    ("Õ", "Y"): -50,
                    ("Õ", "À"): -40,
                    ("Õ", "Á"): -40,
                    ("Õ", "Â"): -40,
                    ("Õ", "Ã"): -40,
                    ("Õ", "Ä"): -40,
                    ("Õ", "Å"): -40,
                    ("Õ", "Ý"): -50,
                    ("Õ", "Ÿ"): -50,
                    ("Ö", "A"): -40,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -50,
                    ("Ö", "X"): -40,
                    ("Ö", "Y"): -50,
                    ("Ö", "À"): -40,
                    ("Ö", "Á"): -40,
                    ("Ö", "Â"): -40,
                    ("Ö", "Ã"): -40,
                    ("Ö", "Ä"): -40,
                    ("Ö", "Å"): -40,
                    ("Ö", "Ý"): -50,
                    ("Ö", "Ÿ"): -50,
                    ("Ø", "A"): -40,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -50,
                    ("Ø", "X"): -40,
                    ("Ø", "Y"): -50,
                    ("Ø", "À"): -40,
                    ("Ø", "Á"): -40,
                    ("Ø", "Â"): -40,
                    ("Ø", "Ã"): -40,
                    ("Ø", "Ä"): -40,
                    ("Ø", "Å"): -40,
                    ("Ø", "Ý"): -50,
                    ("Ø", "Ÿ"): -50,
                    ("Ù", ","): -50,
                    ("Ù", "."): -50,
                    ("Ù", "A"): -60,
                    ("Ù", "À"): -60,
                    ("Ù", "Á"): -60,
                    ("Ù", "Â"): -60,
                    ("Ù", "Ã"): -60,
                    ("Ù", "Ä"): -60,
                    ("Ù", "Å"): -60,
                    ("Ú", ","): -50,
                    ("Ú", "."): -50,
                    ("Ú", "A"): -60,
                    ("Ú", "À"): -60,
                    ("Ú", "Á"): -60,
                    ("Ú", "Â"): -60,
                    ("Ú", "Ã"): -60,
                    ("Ú", "Ä"): -60,
                    ("Ú", "Å"): -60,
                    ("Û", ","): -50,
                    ("Û", "."): -50,
                    ("Û", "A"): -60,
                    ("Û", "À"): -60,
                    ("Û", "Á"): -60,
                    ("Û", "Â"): -60,
                    ("Û", "Ã"): -60,
                    ("Û", "Ä"): -60,
                    ("Û", "Å"): -60,
                    ("Ü", ","): -50,
                    ("Ü", "."): -50,
                    ("Ü", "A"): -60,
                    ("Ü", "À"): -60,
                    ("Ü", "Á"): -60,
                    ("Ü", "Â"): -60,
                    ("Ü", "Ã"): -60,
                    ("Ü", "Ä"): -60,
                    ("Ü", "Å"): -60,
                    ("Ý", ","): -92,
                    ("Ý", "-"): -92,
                    ("Ý", "."): -92,
                    ("Ý", ":"): -92,
                    ("Ý", ";"): -92,
                    ("Ý", "A"): -110,
                    ("Ý", "O"): -35,
                    ("Ý", "a"): -85,
                    ("Ý", "e"): -111,
                    ("Ý", "i"): -37,
                    ("Ý", "o"): -111,
                    ("Ý", "u"): -92,
                    ("Ý", "À"): -110,
                    ("Ý", "Á"): -110,
                    ("Ý", "Â"): -110,
                    ("Ý", "Ã"): -110,
                    ("Ý", "Ä"): -110,
                    ("Ý", "Å"): -110,
                    ("Ý", "Ò"): -35,
                    ("Ý", "Ó"): -35,
                    ("Ý", "Ô"): -35,
                    ("Ý", "Õ"): -35,
                    ("Ý", "Ö"): -35,
                    ("Ý", "Ø"): -35,
                    ("Ý", "à"): -85,
                    ("Ý", "á"): -85,
                    ("Ý", "â"): -85,
                    ("Ý", "ã"): -85,
                    ("Ý", "ä"): -85,
                    ("Ý", "å"): -85,
                    ("Ý", "è"): -71,
                    ("Ý", "é"): -111,
                    ("Ý", "ê"): -111,
                    ("Ý", "ë"): -71,
                    ("Ý", "í"): -37,
                    ("Ý", "ò"): -111,
                    ("Ý", "ó"): -111,
                    ("Ý", "ô"): -111,
                    ("Ý", "õ"): -111,
                    ("Ý", "ö"): -111,
                    ("Ý", "ø"): -111,
                    ("Ý", "ù"): -92,
                    ("Ý", "ú"): -92,
                    ("Ý", "û"): -92,
                    ("Ý", "ü"): -92,
                    ("à", "v"): -25,
                    ("á", "v"): -25,
                    ("â", "v"): -25,
                    ("ã", "v"): -25,
                    ("ä", "v"): -25,
                    ("å", "v"): -25,
                    ("è", "v"): -15,
                    ("é", "v"): -15,
                    ("ê", "v"): -15,
                    ("ë", "v"): -15,
                    ("ì", "v"): -10,
                    ("í", "v"): -10,
                    ("î", "v"): -10,
                    ("ï", "v"): -10,
                    ("ñ", "v"): -40,
                    ("ò", "v"): -10,
                    ("ò", "w"): -10,
                    ("ó", "v"): -10,
                    ("ó", "w"): -10,
                    ("ô", "v"): -10,
                    ("ô", "w"): -10,
                    ("õ", "v"): -10,
                    ("õ", "w"): -10,
                    ("ö", "v"): -10,
                    ("ö", "w"): -10,
                    ("ø", "v"): -10,
                    ("ø", "w"): -10,
                    ("ý", ","): -55,
                    ("ý", "."): -70,
                    ("ý", "e"): -10,
                    ("ý", "o"): -25,
                    ("ý", "è"): -10,
                    ("ý", "é"): -10,
                    ("ý", "ê"): -10,
                    ("ý", "ë"): -10,
                    ("ý", "ò"): -25,
                    ("ý", "ó"): -25,
                    ("ý", "ô"): -25,
                    ("ý", "õ"): -25,
                    ("ý", "ö"): -25,
                    ("ý", "ø"): -25,
                    ("ÿ", ","): -55,
                    ("ÿ", "."): -70,
                    ("ÿ", "e"): -10,
                    ("ÿ", "o"): -25,
                    ("ÿ", "è"): -10,
                    ("ÿ", "é"): -10,
                    ("ÿ", "ê"): -10,
                    ("ÿ", "ë"): -10,
                    ("ÿ", "ò"): -25,
                    ("ÿ", "ó"): -25,
                    ("ÿ", "ô"): -25,
                    ("ÿ", "õ"): -25,
                    ("ÿ", "ö"): -25,
                    ("ÿ", "ø"): -25,
                    ("Ł", "T"): -92,
                    ("Ł", "V"): -92,
                    ("Ł", "W"): -92,
                    ("Ł", "Y"): -92,
                    ("Ł", "y"): -55,
                    ("Ł", "Ý"): -92,
                    ("Ł", "ý"): -55,
                    ("Ł", "ÿ"): -55,
                    ("Ł", "Ÿ"): -92,
                    ("Ł", "’"): -110,
                    ("Ł", "”"): -20,
                    ("Ÿ", ","): -92,
                    ("Ÿ", "-"): -92,
                    ("Ÿ", "."): -92,
                    ("Ÿ", ":"): -92,
                    ("Ÿ", ";"): -92,
                    ("Ÿ", "A"): -110,
                    ("Ÿ", "O"): -35,
                    ("Ÿ", "a"): -85,
                    ("Ÿ", "e"): -111,
                    ("Ÿ", "i"): -37,
                    ("Ÿ", "o"): -111,
                    ("Ÿ", "u"): -92,
                    ("Ÿ", "À"): -110,
                    ("Ÿ", "Á"): -110,
                    ("Ÿ", "Â"): -110,
                    ("Ÿ", "Ã"): -110,
                    ("Ÿ", "Ä"): -110,
                    ("Ÿ", "Å"): -110,
                    ("Ÿ", "Ò"): -35,
                    ("Ÿ", "Ó"): -35,
                    ("Ÿ", "Ô"): -35,
                    ("Ÿ", "Õ"): -35,
                    ("Ÿ", "Ö"): -35,
                    ("Ÿ", "Ø"): -35,
                    ("Ÿ", "à"): -85,
                    ("Ÿ", "á"): -85,
                    ("Ÿ", "â"): -85,
                    ("Ÿ", "ã"): -85,
                    ("Ÿ", "ä"): -85,
                    ("Ÿ", "å"): -85,
                    ("Ÿ", "è"): -71,
                    ("Ÿ", "é"): -111,
                    ("Ÿ", "ê"): -111,
                    ("Ÿ", "ë"): -71,
                    ("Ÿ", "í"): -37,
                    ("Ÿ", "ò"): -111,
                    ("Ÿ", "ó"): -111,
                    ("Ÿ", "ô"): -111,
                    ("Ÿ", "õ"): -111,
                    ("Ÿ", "ö"): -111,
                    ("Ÿ", "ø"): -111,
                    ("Ÿ", "ù"): -92,
                    ("Ÿ", "ú"): -92,
                    ("Ÿ", "û"): -92,
                    ("Ÿ", "ü"): -92,
                    ("‘", "A"): -10,
                    ("‘", "À"): -10,
                    ("‘", "Á"): -10,
                    ("‘", "Â"): -10,
                    ("‘", "Ã"): -10,
                    ("‘", "Ä"): -10,
                    ("‘", "Å"): -10,
                    ("‘", "‘"): -63,
                    ("’", " "): -74,
                    ("’", "d"): -20,
                    ("’", "r"): -20,
                    ("’", "s"): -37,
                    ("’", "v"): -20,
                    ("’", "š"): -37,
                    ("’", "’"): -63,
                    ("“", "A"): -10,
                    ("“", "À"): -10,
                    ("“", "Á"): -10,
                    ("“", "Â"): -10,
                    ("“", "Ã"): -10,
                    ("“", "Ä"): -10,
                    ("“", "Å"): -10,
                },
                0,
            ),
        ),
        BuiltinFont(
            b"Times-Italic",
            b"f6",
            dictget(
                {
                    " ": 250,
                    "!": 333,
                    '"': 420,
                    "#": 500,
                    "$": 500,
                    "%": 833,
                    "&": 778,
                    "'": 214,
                    "(": 333,
                    ")": 333,
                    "*": 500,
                    "+": 675,
                    ",": 250,
                    "-": 333,
                    ".": 250,
                    "/": 278,
                    "0": 500,
                    "1": 500,
                    "2": 500,
                    "3": 500,
                    "4": 500,
                    "5": 500,
                    "6": 500,
                    "7": 500,
                    "8": 500,
                    "9": 500,
                    ":": 333,
                    ";": 333,
                    "<": 675,
                    "=": 675,
                    ">": 675,
                    "?": 500,
                    "@": 920,
                    "A": 611,
                    "B": 611,
                    "C": 667,
                    "D": 722,
                    "E": 611,
                    "F": 611,
                    "G": 722,
                    "H": 722,
                    "I": 333,
                    "J": 444,
                    "K": 667,
                    "L": 556,
                    "M": 833,
                    "N": 667,
                    "O": 722,
                    "P": 611,
                    "Q": 722,
                    "R": 611,
                    "S": 500,
                    "T": 556,
                    "U": 722,
                    "V": 611,
                    "W": 833,
                    "X": 611,
                    "Y": 556,
                    "Z": 556,
                    "[": 389,
                    "\\": 278,
                    "]": 389,
                    "^": 422,
                    "_": 500,
                    "`": 333,
                    "a": 500,
                    "b": 500,
                    "c": 444,
                    "d": 500,
                    "e": 444,
                    "f": 278,
                    "g": 500,
                    "h": 500,
                    "i": 278,
                    "j": 278,
                    "k": 444,
                    "l": 278,
                    "m": 722,
                    "n": 500,
                    "o": 500,
                    "p": 500,
                    "q": 500,
                    "r": 389,
                    "s": 389,
                    "t": 278,
                    "u": 500,
                    "v": 444,
                    "w": 667,
                    "x": 444,
                    "y": 444,
                    "z": 389,
                    "{": 400,
                    "|": 275,
                    "}": 400,
                    "~": 541,
                    "¡": 389,
                    "¢": 500,
                    "£": 500,
                    "¤": 500,
                    "¥": 500,
                    "¦": 275,
                    "§": 500,
                    "©": 760,
                    "ª": 276,
                    "«": 500,
                    "¬": 675,
                    "®": 760,
                    "°": 400,
                    "±": 675,
                    "²": 300,
                    "³": 300,
                    "¶": 523,
                    "·": 250,
                    "¹": 300,
                    "º": 310,
                    "»": 500,
                    "¼": 750,
                    "½": 750,
                    "¾": 750,
                    "¿": 500,
                    "À": 611,
                    "Á": 611,
                    "Â": 611,
                    "Ã": 611,
                    "Ä": 611,
                    "Å": 611,
                    "Æ": 889,
                    "Ç": 667,
                    "È": 611,
                    "É": 611,
                    "Ê": 611,
                    "Ë": 611,
                    "Ì": 333,
                    "Í": 333,
                    "Î": 333,
                    "Ï": 333,
                    "Ð": 722,
                    "Ñ": 667,
                    "Ò": 722,
                    "Ó": 722,
                    "Ô": 722,
                    "Õ": 722,
                    "Ö": 722,
                    "×": 675,
                    "Ø": 722,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 556,
                    "Þ": 611,
                    "ß": 500,
                    "à": 500,
                    "á": 500,
                    "â": 500,
                    "ã": 500,
                    "ä": 500,
                    "å": 500,
                    "æ": 667,
                    "ç": 444,
                    "è": 444,
                    "é": 444,
                    "ê": 444,
                    "ë": 444,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 500,
                    "ñ": 500,
                    "ò": 500,
                    "ó": 500,
                    "ô": 500,
                    "õ": 500,
                    "ö": 500,
                    "÷": 675,
                    "ø": 500,
                    "ù": 500,
                    "ú": 500,
                    "û": 500,
                    "ü": 500,
                    "ý": 444,
                    "þ": 500,
                    "ÿ": 444,
                    "ı": 278,
                    "Ł": 556,
                    "ł": 278,
                    "Œ": 944,
                    "œ": 667,
                    "Š": 500,
                    "š": 389,
                    "Ÿ": 556,
                    "Ž": 556,
                    "ž": 389,
                    "ƒ": 500,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 500,
                    "–": 500,
                    "—": 889,
                    "‘": 333,
                    "’": 333,
                    "‚": 333,
                    "“": 556,
                    "”": 556,
                    "„": 556,
                    "†": 500,
                    "‡": 500,
                    "•": 350,
                    "…": 889,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 500,
                    "™": 980,
                    "−": 675,
                    "ﬁ": 500,
                    "ﬂ": 500,
                },
                500,
            ),
            dictget(
                {
                    (" ", "A"): -18,
                    (" ", "T"): -18,
                    (" ", "V"): -35,
                    (" ", "W"): -40,
                    (" ", "Y"): -75,
                    (" ", "À"): -18,
                    (" ", "Á"): -18,
                    (" ", "Â"): -18,
                    (" ", "Ã"): -18,
                    (" ", "Ä"): -18,
                    (" ", "Å"): -18,
                    (" ", "Ý"): -75,
                    (" ", "Ÿ"): -75,
                    (",", "’"): -140,
                    (",", "”"): -140,
                    (".", "’"): -140,
                    (".", "”"): -140,
                    ("A", "C"): -30,
                    ("A", "G"): -35,
                    ("A", "O"): -40,
                    ("A", "Q"): -40,
                    ("A", "T"): -37,
                    ("A", "U"): -50,
                    ("A", "V"): -105,
                    ("A", "W"): -95,
                    ("A", "Y"): -55,
                    ("A", "u"): -20,
                    ("A", "v"): -55,
                    ("A", "w"): -55,
                    ("A", "y"): -55,
                    ("A", "Ç"): -30,
                    ("A", "Ò"): -40,
                    ("A", "Ó"): -40,
                    ("A", "Ô"): -40,
                    ("A", "Õ"): -40,
                    ("A", "Ö"): -40,
                    ("A", "Ø"): -40,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -55,
                    ("A", "ù"): -20,
                    ("A", "ú"): -20,
                    ("A", "û"): -20,
                    ("A", "ü"): -20,
                    ("A", "ý"): -55,
                    ("A", "ÿ"): -55,
                    ("A", "Ÿ"): -55,
                    ("A", "’"): -37,
                    ("B", "A"): -25,
                    ("B", "U"): -10,
                    ("B", "À"): -25,
                    ("B", "Á"): -25,
                    ("B", "Â"): -25,
                    ("B", "Ã"): -25,
                    ("B", "Ä"): -25,
                    ("B", "Å"): -25,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("D", "A"): -35,
                    ("D", "V"): -40,
                    ("D", "W"): -40,
                    ("D", "Y"): -40,
                    ("D", "À"): -35,
                    ("D", "Á"): -35,
                    ("D", "Â"): -35,
                    ("D", "Ã"): -35,
                    ("D", "Ä"): -35,
                    ("D", "Å"): -35,
                    ("D", "Ý"): -40,
                    ("D", "Ÿ"): -40,
                    ("F", ","): -135,
                    ("F", "."): -135,
                    ("F", "A"): -115,
                    ("F", "a"): -75,
                    ("F", "e"): -75,
                    ("F", "i"): -45,
                    ("F", "o"): -105,
                    ("F", "r"): -55,
                    ("F", "À"): -115,
                    ("F", "Á"): -115,
                    ("F", "Â"): -115,
                    ("F", "Ã"): -115,
                    ("F", "Ä"): -115,
                    ("F", "Å"): -115,
                    ("F", "à"): -75,
                    ("F", "á"): -75,
                    ("F", "â"): -75,
                    ("F", "ã"): -75,
                    ("F", "ä"): -75,
                    ("F", "å"): -75,
                    ("F", "è"): -75,
                    ("F", "é"): -75,
                    ("F", "ê"): -75,
                    ("F", "ë"): -75,
                    ("F", "ì"): -45,
                    ("F", "í"): -45,
                    ("F", "î"): -45,
                    ("F", "ï"): -45,
                    ("F", "ò"): -105,
                    ("F", "ó"): -105,
                    ("F", "ô"): -105,
                    ("F", "õ"): -105,
                    ("F", "ö"): -105,
                    ("F", "ø"): -105,
                    ("J", ","): -25,
                    ("J", "."): -25,
                    ("J", "A"): -40,
                    ("J", "a"): -35,
                    ("J", "e"): -25,
                    ("J", "o"): -25,
                    ("J", "u"): -35,
                    ("J", "À"): -40,
                    ("J", "Á"): -40,
                    ("J", "Â"): -40,
                    ("J", "Ã"): -40,
                    ("J", "Ä"): -40,
                    ("J", "Å"): -40,
                    ("J", "à"): -35,
                    ("J", "á"): -35,
                    ("J", "â"): -35,
                    ("J", "ã"): -35,
                    ("J", "ä"): -35,
                    ("J", "å"): -35,
                    ("J", "è"): -25,
                    ("J", "é"): -25,
                    ("J", "ê"): -25,
                    ("J", "ë"): -25,
                    ("J", "ò"): -25,
                    ("J", "ó"): -25,
                    ("J", "ô"): -25,
                    ("J", "õ"): -25,
                    ("J", "ö"): -25,
                    ("J", "ø"): -25,
                    ("J", "ù"): -35,
                    ("J", "ú"): -35,
                    ("J", "û"): -35,
                    ("J", "ü"): -35,
                    ("K", "O"): -50,
                    ("K", "e"): -35,
                    ("K", "o"): -40,
                    ("K", "u"): -40,
                    ("K", "y"): -40,
                    ("K", "Ò"): -50,
                    ("K", "Ó"): -50,
                    ("K", "Ô"): -50,
                    ("K", "Õ"): -50,
                    ("K", "Ö"): -50,
                    ("K", "Ø"): -50,
                    ("K", "è"): -35,
                    ("K", "é"): -35,
                    ("K", "ê"): -35,
                    ("K", "ë"): -35,
                    ("K", "ò"): -40,
                    ("K", "ó"): -40,
                    ("K", "ô"): -40,
                    ("K", "õ"): -40,
                    ("K", "ö"): -40,
                    ("K", "ø"): -40,
                    ("K", "ù"): -40,
                    ("K", "ú"): -40,
                    ("K", "û"): -40,
                    ("K", "ü"): -40,
                    ("K", "ý"): -40,
                    ("K", "ÿ"): -40,
                    ("L", "T"): -20,
                    ("L", "V"): -55,
                    ("L", "W"): -55,
                    ("L", "Y"): -20,
                    ("L", "y"): -30,
                    ("L", "Ý"): -20,
                    ("L", "ý"): -30,
                    ("L", "ÿ"): -30,
                    ("L", "Ÿ"): -20,
                    ("L", "’"): -37,
                    ("N", "A"): -27,
                    ("N", "À"): -27,
                    ("N", "Á"): -27,
                    ("N", "Â"): -27,
                    ("N", "Ã"): -27,
                    ("N", "Ä"): -27,
                    ("N", "Å"): -27,
                    ("O", "A"): -55,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -50,
                    ("O", "X"): -40,
                    ("O", "Y"): -50,
                    ("O", "À"): -55,
                    ("O", "Á"): -55,
                    ("O", "Â"): -55,
                    ("O", "Ã"): -55,
                    ("O", "Ä"): -55,
                    ("O", "Å"): -55,
                    ("O", "Ý"): -50,
                    ("O", "Ÿ"): -50,
                    ("P", ","): -135,
                    ("P", "."): -135,
                    ("P", "A"): -90,
                    ("P", "a"): -80,
                    ("P", "e"): -80,
                    ("P", "o"): -80,
                    ("P", "À"): -90,
                    ("P", "Á"): -90,
                    ("P", "Â"): -90,
                    ("P", "Ã"): -90,
                    ("P", "Ä"): -90,
                    ("P", "Å"): -90,
                    ("P", "à"): -80,
                    ("P", "á"): -80,
                    ("P", "â"): -80,
                    ("P", "ã"): -80,
                    ("P", "ä"): -80,
                    ("P", "å"): -80,
                    ("P", "è"): -80,
                    ("P", "é"): -80,
                    ("P", "ê"): -80,
                    ("P", "ë"): -80,
                    ("P", "ò"): -80,
                    ("P", "ó"): -80,
                    ("P", "ô"): -80,
                    ("P", "õ"): -80,
                    ("P", "ö"): -80,
                    ("P", "ø"): -80,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -40,
                    ("R", "U"): -40,
                    ("R", "V"): -18,
                    ("R", "W"): -18,
                    ("R", "Y"): -18,
                    ("R", "Ò"): -40,
                    ("R", "Ó"): -40,
                    ("R", "Ô"): -40,
                    ("R", "Õ"): -40,
                    ("R", "Ö"): -40,
                    ("R", "Ø"): -40,
                    ("R", "Ù"): -40,
                    ("R", "Ú"): -40,
                    ("R", "Û"): -40,
                    ("R", "Ü"): -40,
                    ("R", "Ý"): -18,
                    ("R", "Ÿ"): -18,
                    ("T", ","): -74,
                    ("T", "-"): -74,
                    ("T", "."): -74,
                    ("T", ":"): -55,
                    ("T", ";"): -65,
                    ("T", "A"): -50,
                    ("T", "O"): -18,
                    ("T", "a"): -92,
                    ("T", "e"): -92,
                    ("T", "i"): -55,
                    ("T", "o"): -92,
                    ("T", "r"): -55,
                    ("T", "u"): -55,
                    ("T", "w"): -74,
                    ("T", "y"): -74,
                    ("T", "À"): -50,
                    ("T", "Á"): -50,
                    ("T", "Â"): -50,
                    ("T", "Ã"): -50,
                    ("T", "Ä"): -50,
                    ("T", "Å"): -50,
                    ("T", "Ò"): -18,
                    ("T", "Ó"): -18,
                    ("T", "Ô"): -18,
                    ("T", "Õ"): -18,
                    ("T", "Ö"): -18,
                    ("T", "Ø"): -18,
                    ("T", "à"): -92,
                    ("T", "á"): -92,
                    ("T", "â"): -92,
                    ("T", "ã"): -92,
                    ("T", "ä"): -92,
                    ("T", "å"): -92,
                    ("T", "è"): -52,
                    ("T", "é"): -92,
                    ("T", "ê"): -52,
                    ("T", "ë"): -52,
                    ("T", "í"): -55,
                    ("T", "ò"): -92,
                    ("T", "ó"): -92,
                    ("T", "ô"): -92,
                    ("T", "õ"): -92,
                    ("T", "ö"): -92,
                    ("T", "ø"): -92,
                    ("T", "ù"): -55,
                    ("T", "ú"): -55,
                    ("T", "û"): -55,
                    ("T", "ü"): -55,
                    ("T", "ý"): -74,
                    ("T", "ÿ"): -34,
                    ("U", ","): -25,
                    ("U", "."): -25,
                    ("U", "A"): -40,
                    ("U", "À"): -40,
                    ("U", "Á"): -40,
                    ("U", "Â"): -40,
                    ("U", "Ã"): -40,
                    ("U", "Ä"): -40,
                    ("U", "Å"): -40,
                    ("V", ","): -129,
                    ("V", "-"): -55,
                    ("V", "."): -129,
                    ("V", ":"): -65,
                    ("V", ";"): -74,
                    ("V", "A"): -60,
                    ("V", "O"): -30,
                    ("V", "a"): -111,
                    ("V", "e"): -111,
                    ("V", "i"): -74,
                    ("V", "o"): -111,
                    ("V", "u"): -74,
                    ("V", "À"): -60,
                    ("V", "Á"): -60,
                    ("V", "Â"): -60,
                    ("V", "Ã"): -60,
                    ("V", "Ä"): -60,
                    ("V", "Å"): -60,
                    ("V", "Ò"): -30,
                    ("V", "Ó"): -30,
                    ("V", "Ô"): -30,
                    ("V", "Õ"): -30,
                    ("V", "Ö"): -30,
                    ("V", "Ø"): -30,
                    ("V", "à"): -111,
                    ("V", "á"): -111,
                    ("V", "â"): -111,
                    ("V", "ã"): -111,
                    ("V", "ä"): -111,
                    ("V", "å"): -111,
                    ("V", "è"): -71,
                    ("V", "é"): -111,
                    ("V", "ê"): -111,
                    ("V", "ë"): -71,
                    ("V", "ì"): -34,
                    ("V", "í"): -74,
                    ("V", "î"): -34,
                    ("V", "ï"): -34,
                    ("V", "ò"): -111,
                    ("V", "ó"): -111,
                    ("V", "ô"): -111,
                    ("V", "õ"): -111,
                    ("V", "ö"): -111,
                    ("V", "ø"): -111,
                    ("V", "ù"): -74,
                    ("V", "ú"): -74,
                    ("V", "û"): -74,
                    ("V", "ü"): -74,
                    ("W", ","): -92,
                    ("W", "-"): -37,
                    ("W", "."): -92,
                    ("W", ":"): -65,
                    ("W", ";"): -65,
                    ("W", "A"): -60,
                    ("W", "O"): -25,
                    ("W", "a"): -92,
                    ("W", "e"): -92,
                    ("W", "i"): -55,
                    ("W", "o"): -92,
                    ("W", "u"): -55,
                    ("W", "y"): -70,
                    ("W", "À"): -60,
                    ("W", "Á"): -60,
                    ("W", "Â"): -60,
                    ("W", "Ã"): -60,
                    ("W", "Ä"): -60,
                    ("W", "Å"): -60,
                    ("W", "Ò"): -25,
                    ("W", "Ó"): -25,
                    ("W", "Ô"): -25,
                    ("W", "Õ"): -25,
                    ("W", "Ö"): -25,
                    ("W", "Ø"): -25,
                    ("W", "à"): -92,
                    ("W", "á"): -92,
                    ("W", "â"): -92,
                    ("W", "ã"): -92,
                    ("W", "ä"): -92,
                    ("W", "å"): -92,
                    ("W", "è"): -52,
                    ("W", "é"): -92,
                    ("W", "ê"): -92,
                    ("W", "ë"): -52,
                    ("W", "í"): -55,
                    ("W", "ò"): -92,
                    ("W", "ó"): -92,
                    ("W", "ô"): -92,
                    ("W", "õ"): -92,
                    ("W", "ö"): -92,
                    ("W", "ø"): -92,
                    ("W", "ù"): -55,
                    ("W", "ú"): -55,
                    ("W", "û"): -55,
                    ("W", "ü"): -55,
                    ("W", "ý"): -70,
                    ("W", "ÿ"): -70,
                    ("Y", ","): -92,
                    ("Y", "-"): -74,
                    ("Y", "."): -92,
                    ("Y", ":"): -65,
                    ("Y", ";"): -65,
                    ("Y", "A"): -50,
                    ("Y", "O"): -15,
                    ("Y", "a"): -92,
                    ("Y", "e"): -92,
                    ("Y", "i"): -74,
                    ("Y", "o"): -92,
                    ("Y", "u"): -92,
                    ("Y", "À"): -50,
                    ("Y", "Á"): -50,
                    ("Y", "Â"): -50,
                    ("Y", "Ã"): -50,
                    ("Y", "Ä"): -50,
                    ("Y", "Å"): -50,
                    ("Y", "Ò"): -15,
                    ("Y", "Ó"): -15,
                    ("Y", "Ô"): -15,
                    ("Y", "Õ"): -15,
                    ("Y", "Ö"): -15,
                    ("Y", "Ø"): -15,
                    ("Y", "à"): -92,
                    ("Y", "á"): -92,
                    ("Y", "â"): -92,
                    ("Y", "ã"): -92,
                    ("Y", "ä"): -92,
                    ("Y", "å"): -92,
                    ("Y", "è"): -52,
                    ("Y", "é"): -92,
                    ("Y", "ê"): -92,
                    ("Y", "ë"): -52,
                    ("Y", "ì"): -34,
                    ("Y", "í"): -74,
                    ("Y", "î"): -34,
                    ("Y", "ï"): -34,
                    ("Y", "ò"): -92,
                    ("Y", "ó"): -92,
                    ("Y", "ô"): -92,
                    ("Y", "õ"): -92,
                    ("Y", "ö"): -92,
                    ("Y", "ø"): -92,
                    ("Y", "ù"): -92,
                    ("Y", "ú"): -92,
                    ("Y", "û"): -92,
                    ("Y", "ü"): -92,
                    ("a", "g"): -10,
                    ("b", "."): -40,
                    ("b", "u"): -20,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("c", "h"): -15,
                    ("c", "k"): -20,
                    ("e", ","): -10,
                    ("e", "."): -15,
                    ("e", "g"): -40,
                    ("e", "v"): -15,
                    ("e", "w"): -15,
                    ("e", "x"): -20,
                    ("e", "y"): -30,
                    ("e", "ý"): -30,
                    ("e", "ÿ"): -30,
                    ("f", ","): -10,
                    ("f", "."): -15,
                    ("f", "f"): -18,
                    ("f", "i"): -20,
                    ("f", "ı"): -60,
                    ("f", "’"): 92,
                    ("g", ","): -10,
                    ("g", "."): -15,
                    ("g", "e"): -10,
                    ("g", "g"): -10,
                    ("g", "è"): -10,
                    ("g", "é"): -10,
                    ("g", "ê"): -10,
                    ("g", "ë"): -10,
                    ("k", "e"): -10,
                    ("k", "o"): -10,
                    ("k", "y"): -10,
                    ("k", "è"): -10,
                    ("k", "é"): -10,
                    ("k", "ê"): -10,
                    ("k", "ë"): -10,
                    ("k", "ò"): -10,
                    ("k", "ó"): -10,
                    ("k", "ô"): -10,
                    ("k", "õ"): -10,
                    ("k", "ö"): -10,
                    ("k", "ø"): -10,
                    ("k", "ý"): -10,
                    ("k", "ÿ"): -10,
                    ("n", "v"): -40,
                    ("o", "g"): -10,
                    ("o", "v"): -10,
                    ("r", ","): -111,
                    ("r", "-"): -20,
                    ("r", "."): -111,
                    ("r", "a"): -15,
                    ("r", "c"): -37,
                    ("r", "d"): -37,
                    ("r", "e"): -37,
                    ("r", "g"): -37,
                    ("r", "o"): -45,
                    ("r", "q"): -37,
                    ("r", "s"): -10,
                    ("r", "à"): -15,
                    ("r", "á"): -15,
                    ("r", "â"): -15,
                    ("r", "ã"): -15,
                    ("r", "ä"): -15,
                    ("r", "å"): -15,
                    ("r", "ç"): -37,
                    ("r", "è"): -37,
                    ("r", "é"): -37,
                    ("r", "ê"): -37,
                    ("r", "ë"): -37,
                    ("r", "ò"): -45,
                    ("r", "ó"): -45,
                    ("r", "ô"): -45,
                    ("r", "õ"): -45,
                    ("r", "ö"): -45,
                    ("r", "ø"): -45,
                    ("r", "š"): -10,
                    ("v", ","): -74,
                    ("v", "."): -74,
                    ("w", ","): -74,
                    ("w", "."): -74,
                    ("y", ","): -55,
                    ("y", "."): -55,
                    ("À", "C"): -30,
                    ("À", "G"): -35,
                    ("À", "O"): -40,
                    ("À", "Q"): -40,
                    ("À", "T"): -37,
                    ("À", "U"): -50,
                    ("À", "V"): -105,
                    ("À", "W"): -95,
                    ("À", "Y"): -55,
                    ("À", "u"): -20,
                    ("À", "v"): -55,
                    ("À", "w"): -55,
                    ("À", "y"): -55,
                    ("À", "Ç"): -30,
                    ("À", "Ò"): -40,
                    ("À", "Ó"): -40,
                    ("À", "Ô"): -40,
                    ("À", "Õ"): -40,
                    ("À", "Ö"): -40,
                    ("À", "Ø"): -40,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -55,
                    ("À", "ù"): -20,
                    ("À", "ú"): -20,
                    ("À", "û"): -20,
                    ("À", "ü"): -20,
                    ("À", "ý"): -55,
                    ("À", "ÿ"): -55,
                    ("À", "Ÿ"): -55,
                    ("À", "’"): -37,
                    ("Á", "C"): -30,
                    ("Á", "G"): -35,
                    ("Á", "O"): -40,
                    ("Á", "Q"): -40,
                    ("Á", "T"): -37,
                    ("Á", "U"): -50,
                    ("Á", "V"): -105,
                    ("Á", "W"): -95,
                    ("Á", "Y"): -55,
                    ("Á", "u"): -20,
                    ("Á", "v"): -55,
                    ("Á", "w"): -55,
                    ("Á", "y"): -55,
                    ("Á", "Ç"): -30,
                    ("Á", "Ò"): -40,
                    ("Á", "Ó"): -40,
                    ("Á", "Ô"): -40,
                    ("Á", "Õ"): -40,
                    ("Á", "Ö"): -40,
                    ("Á", "Ø"): -40,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -55,
                    ("Á", "ù"): -20,
                    ("Á", "ú"): -20,
                    ("Á", "û"): -20,
                    ("Á", "ü"): -20,
                    ("Á", "ý"): -55,
                    ("Á", "ÿ"): -55,
                    ("Á", "Ÿ"): -55,
                    ("Á", "’"): -37,
                    ("Â", "C"): -30,
                    ("Â", "G"): -35,
                    ("Â", "O"): -40,
                    ("Â", "Q"): -40,
                    ("Â", "T"): -37,
                    ("Â", "U"): -50,
                    ("Â", "V"): -105,
                    ("Â", "W"): -95,
                    ("Â", "Y"): -55,
                    ("Â", "u"): -20,
                    ("Â", "v"): -55,
                    ("Â", "w"): -55,
                    ("Â", "y"): -55,
                    ("Â", "Ç"): -30,
                    ("Â", "Ò"): -40,
                    ("Â", "Ó"): -40,
                    ("Â", "Ô"): -40,
                    ("Â", "Õ"): -40,
                    ("Â", "Ö"): -40,
                    ("Â", "Ø"): -40,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -55,
                    ("Â", "ù"): -20,
                    ("Â", "ú"): -20,
                    ("Â", "û"): -20,
                    ("Â", "ü"): -20,
                    ("Â", "ý"): -55,
                    ("Â", "ÿ"): -55,
                    ("Â", "Ÿ"): -55,
                    ("Â", "’"): -37,
                    ("Ã", "C"): -30,
                    ("Ã", "G"): -35,
                    ("Ã", "O"): -40,
                    ("Ã", "Q"): -40,
                    ("Ã", "T"): -37,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -105,
                    ("Ã", "W"): -95,
                    ("Ã", "Y"): -55,
                    ("Ã", "u"): -20,
                    ("Ã", "v"): -55,
                    ("Ã", "w"): -55,
                    ("Ã", "y"): -55,
                    ("Ã", "Ç"): -30,
                    ("Ã", "Ò"): -40,
                    ("Ã", "Ó"): -40,
                    ("Ã", "Ô"): -40,
                    ("Ã", "Õ"): -40,
                    ("Ã", "Ö"): -40,
                    ("Ã", "Ø"): -40,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -55,
                    ("Ã", "ù"): -20,
                    ("Ã", "ú"): -20,
                    ("Ã", "û"): -20,
                    ("Ã", "ü"): -20,
                    ("Ã", "ý"): -55,
                    ("Ã", "ÿ"): -55,
                    ("Ã", "Ÿ"): -55,
                    ("Ã", "’"): -37,
                    ("Ä", "C"): -30,
                    ("Ä", "G"): -35,
                    ("Ä", "O"): -40,
                    ("Ä", "Q"): -40,
                    ("Ä", "T"): -37,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -105,
                    ("Ä", "W"): -95,
                    ("Ä", "Y"): -55,
                    ("Ä", "u"): -20,
                    ("Ä", "v"): -55,
                    ("Ä", "w"): -55,
                    ("Ä", "y"): -55,
                    ("Ä", "Ç"): -30,
                    ("Ä", "Ò"): -40,
                    ("Ä", "Ó"): -40,
                    ("Ä", "Ô"): -40,
                    ("Ä", "Õ"): -40,
                    ("Ä", "Ö"): -40,
                    ("Ä", "Ø"): -40,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -55,
                    ("Ä", "ù"): -20,
                    ("Ä", "ú"): -20,
                    ("Ä", "û"): -20,
                    ("Ä", "ü"): -20,
                    ("Ä", "ý"): -55,
                    ("Ä", "ÿ"): -55,
                    ("Ä", "Ÿ"): -55,
                    ("Ä", "’"): -37,
                    ("Å", "C"): -30,
                    ("Å", "G"): -35,
                    ("Å", "O"): -40,
                    ("Å", "Q"): -40,
                    ("Å", "T"): -37,
                    ("Å", "U"): -50,
                    ("Å", "V"): -105,
                    ("Å", "W"): -95,
                    ("Å", "Y"): -55,
                    ("Å", "u"): -20,
                    ("Å", "v"): -55,
                    ("Å", "w"): -55,
                    ("Å", "y"): -55,
                    ("Å", "Ç"): -30,
                    ("Å", "Ò"): -40,
                    ("Å", "Ó"): -40,
                    ("Å", "Ô"): -40,
                    ("Å", "Õ"): -40,
                    ("Å", "Ö"): -40,
                    ("Å", "Ø"): -40,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -55,
                    ("Å", "ù"): -20,
                    ("Å", "ú"): -20,
                    ("Å", "û"): -20,
                    ("Å", "ü"): -20,
                    ("Å", "ý"): -55,
                    ("Å", "ÿ"): -55,
                    ("Å", "Ÿ"): -55,
                    ("Å", "’"): -37,
                    ("Ñ", "A"): -27,
                    ("Ñ", "À"): -27,
                    ("Ñ", "Á"): -27,
                    ("Ñ", "Â"): -27,
                    ("Ñ", "Ã"): -27,
                    ("Ñ", "Ä"): -27,
                    ("Ñ", "Å"): -27,
                    ("Ò", "A"): -55,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -50,
                    ("Ò", "X"): -40,
                    ("Ò", "Y"): -50,
                    ("Ò", "À"): -55,
                    ("Ò", "Á"): -55,
                    ("Ò", "Â"): -55,
                    ("Ò", "Ã"): -55,
                    ("Ò", "Ä"): -55,
                    ("Ò", "Å"): -55,
                    ("Ò", "Ý"): -50,
                    ("Ò", "Ÿ"): -50,
                    ("Ó", "A"): -55,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -50,
                    ("Ó", "X"): -40,
                    ("Ó", "Y"): -50,
                    ("Ó", "À"): -55,
                    ("Ó", "Á"): -55,
                    ("Ó", "Â"): -55,
                    ("Ó", "Ã"): -55,
                    ("Ó", "Ä"): -55,
                    ("Ó", "Å"): -55,
                    ("Ó", "Ý"): -50,
                    ("Ó", "Ÿ"): -50,
                    ("Ô", "A"): -55,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -50,
                    ("Ô", "X"): -40,
                    ("Ô", "Y"): -50,
                    ("Ô", "À"): -55,
                    ("Ô", "Á"): -55,
                    ("Ô", "Â"): -55,
                    ("Ô", "Ã"): -55,
                    ("Ô", "Ä"): -55,
                    ("Ô", "Å"): -55,
                    ("Ô", "Ý"): -50,
                    ("Ô", "Ÿ"): -50,
                    ("Õ", "A"): -55,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -50,
                    ("Õ", "X"): -40,
                    ("Õ", "Y"): -50,
                    ("Õ", "À"): -55,
                    ("Õ", "Á"): -55,
                    ("Õ", "Â"): -55,
                    ("Õ", "Ã"): -55,
                    ("Õ", "Ä"): -55,
                    ("Õ", "Å"): -55,
                    ("Õ", "Ý"): -50,
                    ("Õ", "Ÿ"): -50,
                    ("Ö", "A"): -55,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -50,
                    ("Ö", "X"): -40,
                    ("Ö", "Y"): -50,
                    ("Ö", "À"): -55,
                    ("Ö", "Á"): -55,
                    ("Ö", "Â"): -55,
                    ("Ö", "Ã"): -55,
                    ("Ö", "Ä"): -55,
                    ("Ö", "Å"): -55,
                    ("Ö", "Ý"): -50,
                    ("Ö", "Ÿ"): -50,
                    ("Ø", "A"): -55,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -50,
                    ("Ø", "X"): -40,
                    ("Ø", "Y"): -50,
                    ("Ø", "À"): -55,
                    ("Ø", "Á"): -55,
                    ("Ø", "Â"): -55,
                    ("Ø", "Ã"): -55,
                    ("Ø", "Ä"): -55,
                    ("Ø", "Å"): -55,
                    ("Ø", "Ý"): -50,
                    ("Ø", "Ÿ"): -50,
                    ("Ù", ","): -25,
                    ("Ù", "."): -25,
                    ("Ù", "A"): -40,
                    ("Ù", "À"): -40,
                    ("Ù", "Á"): -40,
                    ("Ù", "Â"): -40,
                    ("Ù", "Ã"): -40,
                    ("Ù", "Ä"): -40,
                    ("Ù", "Å"): -40,
                    ("Ú", ","): -25,
                    ("Ú", "."): -25,
                    ("Ú", "A"): -40,
                    ("Ú", "À"): -40,
                    ("Ú", "Á"): -40,
                    ("Ú", "Â"): -40,
                    ("Ú", "Ã"): -40,
                    ("Ú", "Ä"): -40,
                    ("Ú", "Å"): -40,
                    ("Û", ","): -25,
                    ("Û", "."): -25,
                    ("Û", "A"): -40,
                    ("Û", "À"): -40,
                    ("Û", "Á"): -40,
                    ("Û", "Â"): -40,
                    ("Û", "Ã"): -40,
                    ("Û", "Ä"): -40,
                    ("Û", "Å"): -40,
                    ("Ü", ","): -25,
                    ("Ü", "."): -25,
                    ("Ü", "A"): -40,
                    ("Ü", "À"): -40,
                    ("Ü", "Á"): -40,
                    ("Ü", "Â"): -40,
                    ("Ü", "Ã"): -40,
                    ("Ü", "Ä"): -40,
                    ("Ü", "Å"): -40,
                    ("Ý", ","): -92,
                    ("Ý", "-"): -74,
                    ("Ý", "."): -92,
                    ("Ý", ":"): -65,
                    ("Ý", ";"): -65,
                    ("Ý", "A"): -50,
                    ("Ý", "O"): -15,
                    ("Ý", "a"): -92,
                    ("Ý", "e"): -92,
                    ("Ý", "i"): -74,
                    ("Ý", "o"): -92,
                    ("Ý", "u"): -92,
                    ("Ý", "À"): -50,
                    ("Ý", "Á"): -50,
                    ("Ý", "Â"): -50,
                    ("Ý", "Ã"): -50,
                    ("Ý", "Ä"): -50,
                    ("Ý", "Å"): -50,
                    ("Ý", "Ò"): -15,
                    ("Ý", "Ó"): -15,
                    ("Ý", "Ô"): -15,
                    ("Ý", "Õ"): -15,
                    ("Ý", "Ö"): -15,
                    ("Ý", "Ø"): -15,
                    ("Ý", "à"): -92,
                    ("Ý", "á"): -92,
                    ("Ý", "â"): -92,
                    ("Ý", "ã"): -92,
                    ("Ý", "ä"): -92,
                    ("Ý", "å"): -92,
                    ("Ý", "è"): -52,
                    ("Ý", "é"): -92,
                    ("Ý", "ê"): -92,
                    ("Ý", "ë"): -52,
                    ("Ý", "ì"): -34,
                    ("Ý", "í"): -74,
                    ("Ý", "î"): -34,
                    ("Ý", "ï"): -34,
                    ("Ý", "ò"): -92,
                    ("Ý", "ó"): -92,
                    ("Ý", "ô"): -92,
                    ("Ý", "õ"): -92,
                    ("Ý", "ö"): -92,
                    ("Ý", "ø"): -92,
                    ("Ý", "ù"): -92,
                    ("Ý", "ú"): -92,
                    ("Ý", "û"): -92,
                    ("Ý", "ü"): -92,
                    ("à", "g"): -10,
                    ("á", "g"): -10,
                    ("â", "g"): -10,
                    ("ã", "g"): -10,
                    ("ä", "g"): -10,
                    ("å", "g"): -10,
                    ("ç", "h"): -15,
                    ("ç", "k"): -20,
                    ("è", ","): -10,
                    ("è", "."): -15,
                    ("è", "g"): -40,
                    ("è", "v"): -15,
                    ("è", "w"): -15,
                    ("è", "x"): -20,
                    ("è", "y"): -30,
                    ("è", "ý"): -30,
                    ("è", "ÿ"): -30,
                    ("é", ","): -10,
                    ("é", "."): -15,
                    ("é", "g"): -40,
                    ("é", "v"): -15,
                    ("é", "w"): -15,
                    ("é", "x"): -20,
                    ("é", "y"): -30,
                    ("é", "ý"): -30,
                    ("é", "ÿ"): -30,
                    ("ê", ","): -10,
                    ("ê", "."): -15,
                    ("ê", "g"): -40,
                    ("ê", "v"): -15,
                    ("ê", "w"): -15,
                    ("ê", "x"): -20,
                    ("ê", "y"): -30,
                    ("ê", "ý"): -30,
                    ("ê", "ÿ"): -30,
                    ("ë", ","): -10,
                    ("ë", "."): -15,
                    ("ë", "g"): -40,
                    ("ë", "v"): -15,
                    ("ë", "w"): -15,
                    ("ë", "x"): -20,
                    ("ë", "y"): -30,
                    ("ë", "ý"): -30,
                    ("ë", "ÿ"): -30,
                    ("ñ", "v"): -40,
                    ("ò", "g"): -10,
                    ("ò", "v"): -10,
                    ("ó", "g"): -10,
                    ("ó", "v"): -10,
                    ("ô", "g"): -10,
                    ("ô", "v"): -10,
                    ("õ", "g"): -10,
                    ("õ", "v"): -10,
                    ("ö", "g"): -10,
                    ("ö", "v"): -10,
                    ("ø", "g"): -10,
                    ("ø", "v"): -10,
                    ("ý", ","): -55,
                    ("ý", "."): -55,
                    ("ÿ", ","): -55,
                    ("ÿ", "."): -55,
                    ("Ł", "T"): -20,
                    ("Ł", "V"): -55,
                    ("Ł", "W"): -55,
                    ("Ł", "Y"): -20,
                    ("Ł", "y"): -30,
                    ("Ł", "Ý"): -20,
                    ("Ł", "ý"): -30,
                    ("Ł", "ÿ"): -30,
                    ("Ł", "Ÿ"): -20,
                    ("Ł", "’"): -37,
                    ("Ÿ", ","): -92,
                    ("Ÿ", "-"): -74,
                    ("Ÿ", "."): -92,
                    ("Ÿ", ":"): -65,
                    ("Ÿ", ";"): -65,
                    ("Ÿ", "A"): -50,
                    ("Ÿ", "O"): -15,
                    ("Ÿ", "a"): -92,
                    ("Ÿ", "e"): -92,
                    ("Ÿ", "i"): -74,
                    ("Ÿ", "o"): -92,
                    ("Ÿ", "u"): -92,
                    ("Ÿ", "À"): -50,
                    ("Ÿ", "Á"): -50,
                    ("Ÿ", "Â"): -50,
                    ("Ÿ", "Ã"): -50,
                    ("Ÿ", "Ä"): -50,
                    ("Ÿ", "Å"): -50,
                    ("Ÿ", "Ò"): -15,
                    ("Ÿ", "Ó"): -15,
                    ("Ÿ", "Ô"): -15,
                    ("Ÿ", "Õ"): -15,
                    ("Ÿ", "Ö"): -15,
                    ("Ÿ", "Ø"): -15,
                    ("Ÿ", "à"): -92,
                    ("Ÿ", "á"): -92,
                    ("Ÿ", "â"): -92,
                    ("Ÿ", "ã"): -92,
                    ("Ÿ", "ä"): -92,
                    ("Ÿ", "å"): -92,
                    ("Ÿ", "è"): -52,
                    ("Ÿ", "é"): -92,
                    ("Ÿ", "ê"): -92,
                    ("Ÿ", "ë"): -52,
                    ("Ÿ", "ì"): -34,
                    ("Ÿ", "í"): -74,
                    ("Ÿ", "î"): -34,
                    ("Ÿ", "ï"): -34,
                    ("Ÿ", "ò"): -92,
                    ("Ÿ", "ó"): -92,
                    ("Ÿ", "ô"): -92,
                    ("Ÿ", "õ"): -92,
                    ("Ÿ", "ö"): -92,
                    ("Ÿ", "ø"): -92,
                    ("Ÿ", "ù"): -92,
                    ("Ÿ", "ú"): -92,
                    ("Ÿ", "û"): -92,
                    ("Ÿ", "ü"): -92,
                    ("‘", "‘"): -111,
                    ("’", " "): -111,
                    ("’", "d"): -25,
                    ("’", "r"): -25,
                    ("’", "s"): -40,
                    ("’", "t"): -30,
                    ("’", "v"): -10,
                    ("’", "š"): -40,
                    ("’", "’"): -111,
                },
                0,
            ),
        ),
        BuiltinFont(
            b"Times-BoldItalic",
            b"f7",
            dictget(
                {
                    " ": 250,
                    "!": 389,
                    '"': 555,
                    "#": 500,
                    "$": 500,
                    "%": 833,
                    "&": 778,
                    "'": 278,
                    "(": 333,
                    ")": 333,
                    "*": 500,
                    "+": 570,
                    ",": 250,
                    "-": 333,
                    ".": 250,
                    "/": 278,
                    "0": 500,
                    "1": 500,
                    "2": 500,
                    "3": 500,
                    "4": 500,
                    "5": 500,
                    "6": 500,
                    "7": 500,
                    "8": 500,
                    "9": 500,
                    ":": 333,
                    ";": 333,
                    "<": 570,
                    "=": 570,
                    ">": 570,
                    "?": 500,
                    "@": 832,
                    "A": 667,
                    "B": 667,
                    "C": 667,
                    "D": 722,
                    "E": 667,
                    "F": 667,
                    "G": 722,
                    "H": 778,
                    "I": 389,
                    "J": 500,
                    "K": 667,
                    "L": 611,
                    "M": 889,
                    "N": 722,
                    "O": 722,
                    "P": 611,
                    "Q": 722,
                    "R": 667,
                    "S": 556,
                    "T": 611,
                    "U": 722,
                    "V": 667,
                    "W": 889,
                    "X": 667,
                    "Y": 611,
                    "Z": 611,
                    "[": 333,
                    "\\": 278,
                    "]": 333,
                    "^": 570,
                    "_": 500,
                    "`": 333,
                    "a": 500,
                    "b": 500,
                    "c": 444,
                    "d": 500,
                    "e": 444,
                    "f": 333,
                    "g": 500,
                    "h": 556,
                    "i": 278,
                    "j": 278,
                    "k": 500,
                    "l": 278,
                    "m": 778,
                    "n": 556,
                    "o": 500,
                    "p": 500,
                    "q": 500,
                    "r": 389,
                    "s": 389,
                    "t": 278,
                    "u": 556,
                    "v": 444,
                    "w": 667,
                    "x": 500,
                    "y": 444,
                    "z": 389,
                    "{": 348,
                    "|": 220,
                    "}": 348,
                    "~": 570,
                    "¡": 389,
                    "¢": 500,
                    "£": 500,
                    "¤": 500,
                    "¥": 500,
                    "¦": 220,
                    "§": 500,
                    "©": 747,
                    "ª": 266,
                    "«": 500,
                    "¬": 606,
                    "®": 747,
                    "°": 400,
                    "±": 570,
                    "²": 300,
                    "³": 300,
                    "¶": 500,
                    "·": 250,
                    "¹": 300,
                    "º": 300,
                    "»": 500,
                    "¼": 750,
                    "½": 750,
                    "¾": 750,
                    "¿": 500,
                    "À": 667,
                    "Á": 667,
                    "Â": 667,
                    "Ã": 667,
                    "Ä": 667,
                    "Å": 667,
                    "Æ": 944,
                    "Ç": 667,
                    "È": 667,
                    "É": 667,
                    "Ê": 667,
                    "Ë": 667,
                    "Ì": 389,
                    "Í": 389,
                    "Î": 389,
                    "Ï": 389,
                    "Ð": 722,
                    "Ñ": 722,
                    "Ò": 722,
                    "Ó": 722,
                    "Ô": 722,
                    "Õ": 722,
                    "Ö": 722,
                    "×": 570,
                    "Ø": 722,
                    "Ù": 722,
                    "Ú": 722,
                    "Û": 722,
                    "Ü": 722,
                    "Ý": 611,
                    "Þ": 611,
                    "ß": 500,
                    "à": 500,
                    "á": 500,
                    "â": 500,
                    "ã": 500,
                    "ä": 500,
                    "å": 500,
                    "æ": 722,
                    "ç": 444,
                    "è": 444,
                    "é": 444,
                    "ê": 444,
                    "ë": 444,
                    "ì": 278,
                    "í": 278,
                    "î": 278,
                    "ï": 278,
                    "ð": 500,
                    "ñ": 556,
                    "ò": 500,
                    "ó": 500,
                    "ô": 500,
                    "õ": 500,
                    "ö": 500,
                    "÷": 570,
                    "ø": 500,
                    "ù": 556,
                    "ú": 556,
                    "û": 556,
                    "ü": 556,
                    "ý": 444,
                    "þ": 500,
                    "ÿ": 444,
                    "ı": 278,
                    "Ł": 611,
                    "ł": 278,
                    "Œ": 944,
                    "œ": 722,
                    "Š": 556,
                    "š": 389,
                    "Ÿ": 611,
                    "Ž": 611,
                    "ž": 389,
                    "ƒ": 500,
                    "ˆ": 333,
                    "ˇ": 333,
                    "́": 333,
                    "̃": 333,
                    "̄": 333,
                    "̆": 333,
                    "̇": 333,
                    "̈": 333,
                    "̊": 333,
                    "̋": 333,
                    "̧": 333,
                    "̨": 333,
                    "μ": 576,
                    "–": 500,
                    "—": 1000,
                    "‘": 333,
                    "’": 333,
                    "‚": 333,
                    "“": 500,
                    "”": 500,
                    "„": 500,
                    "†": 500,
                    "‡": 500,
                    "•": 350,
                    "…": 1000,
                    "‰": 1000,
                    "‹": 333,
                    "›": 333,
                    "⁄": 167,
                    "€": 500,
                    "™": 1000,
                    "−": 606,
                    "ﬁ": 556,
                    "ﬂ": 556,
                },
                500,
            ),
            dictget(
                {
                    (" ", "A"): -37,
                    (" ", "V"): -70,
                    (" ", "W"): -70,
                    (" ", "Y"): -70,
                    (" ", "À"): -37,
                    (" ", "Á"): -37,
                    (" ", "Â"): -37,
                    (" ", "Ã"): -37,
                    (" ", "Ä"): -37,
                    (" ", "Å"): -37,
                    (" ", "Ý"): -70,
                    (" ", "Ÿ"): -70,
                    (",", "’"): -95,
                    (",", "”"): -95,
                    (".", "’"): -95,
                    (".", "”"): -95,
                    ("A", "C"): -65,
                    ("A", "G"): -60,
                    ("A", "O"): -50,
                    ("A", "Q"): -55,
                    ("A", "T"): -55,
                    ("A", "U"): -50,
                    ("A", "V"): -95,
                    ("A", "W"): -100,
                    ("A", "Y"): -70,
                    ("A", "u"): -30,
                    ("A", "v"): -74,
                    ("A", "w"): -74,
                    ("A", "y"): -74,
                    ("A", "Ç"): -65,
                    ("A", "Ò"): -50,
                    ("A", "Ó"): -50,
                    ("A", "Ô"): -50,
                    ("A", "Õ"): -50,
                    ("A", "Ö"): -50,
                    ("A", "Ø"): -50,
                    ("A", "Ù"): -50,
                    ("A", "Ú"): -50,
                    ("A", "Û"): -50,
                    ("A", "Ü"): -50,
                    ("A", "Ý"): -70,
                    ("A", "ù"): -30,
                    ("A", "ú"): -30,
                    ("A", "û"): -30,
                    ("A", "ü"): -30,
                    ("A", "ý"): -74,
                    ("A", "ÿ"): -74,
                    ("A", "Ÿ"): -70,
                    ("A", "’"): -74,
                    ("B", "A"): -25,
                    ("B", "U"): -10,
                    ("B", "À"): -25,
                    ("B", "Á"): -25,
                    ("B", "Â"): -25,
                    ("B", "Ã"): -25,
                    ("B", "Ä"): -25,
                    ("B", "Å"): -25,
                    ("B", "Ù"): -10,
                    ("B", "Ú"): -10,
                    ("B", "Û"): -10,
                    ("B", "Ü"): -10,
                    ("D", "A"): -25,
                    ("D", "V"): -50,
                    ("D", "W"): -40,
                    ("D", "Y"): -50,
                    ("D", "À"): -25,
                    ("D", "Á"): -25,
                    ("D", "Â"): -25,
                    ("D", "Ã"): -25,
                    ("D", "Ä"): -25,
                    ("D", "Å"): -25,
                    ("D", "Ý"): -50,
                    ("D", "Ÿ"): -50,
                    ("F", ","): -129,
                    ("F", "."): -129,
                    ("F", "A"): -100,
                    ("F", "a"): -95,
                    ("F", "e"): -100,
                    ("F", "i"): -40,
                    ("F", "o"): -70,
                    ("F", "r"): -50,
                    ("F", "À"): -100,
                    ("F", "Á"): -100,
                    ("F", "Â"): -100,
                    ("F", "Ã"): -100,
                    ("F", "Ä"): -100,
                    ("F", "Å"): -100,
                    ("F", "à"): -95,
                    ("F", "á"): -95,
                    ("F", "â"): -95,
                    ("F", "ã"): -95,
                    ("F", "ä"): -95,
                    ("F", "å"): -95,
                    ("F", "è"): -100,
                    ("F", "é"): -100,
                    ("F", "ê"): -100,
                    ("F", "ë"): -100,
                    ("F", "ì"): -40,
                    ("F", "í"): -40,
                    ("F", "î"): -40,
                    ("F", "ï"): -40,
                    ("F", "ò"): -70,
                    ("F", "ó"): -70,
                    ("F", "ô"): -70,
                    ("F", "õ"): -70,
                    ("F", "ö"): -70,
                    ("F", "ø"): -70,
                    ("J", ","): -10,
                    ("J", "."): -10,
                    ("J", "A"): -25,
                    ("J", "a"): -40,
                    ("J", "e"): -40,
                    ("J", "o"): -40,
                    ("J", "u"): -40,
                    ("J", "À"): -25,
                    ("J", "Á"): -25,
                    ("J", "Â"): -25,
                    ("J", "Ã"): -25,
                    ("J", "Ä"): -25,
                    ("J", "Å"): -25,
                    ("J", "à"): -40,
                    ("J", "á"): -40,
                    ("J", "â"): -40,
                    ("J", "ã"): -40,
                    ("J", "ä"): -40,
                    ("J", "å"): -40,
                    ("J", "è"): -40,
                    ("J", "é"): -40,
                    ("J", "ê"): -40,
                    ("J", "ë"): -40,
                    ("J", "ò"): -40,
                    ("J", "ó"): -40,
                    ("J", "ô"): -40,
                    ("J", "õ"): -40,
                    ("J", "ö"): -40,
                    ("J", "ø"): -40,
                    ("J", "ù"): -40,
                    ("J", "ú"): -40,
                    ("J", "û"): -40,
                    ("J", "ü"): -40,
                    ("K", "O"): -30,
                    ("K", "e"): -25,
                    ("K", "o"): -25,
                    ("K", "u"): -20,
                    ("K", "y"): -20,
                    ("K", "Ò"): -30,
                    ("K", "Ó"): -30,
                    ("K", "Ô"): -30,
                    ("K", "Õ"): -30,
                    ("K", "Ö"): -30,
                    ("K", "Ø"): -30,
                    ("K", "è"): -25,
                    ("K", "é"): -25,
                    ("K", "ê"): -25,
                    ("K", "ë"): -25,
                    ("K", "ò"): -25,
                    ("K", "ó"): -25,
                    ("K", "ô"): -25,
                    ("K", "õ"): -25,
                    ("K", "ö"): -25,
                    ("K", "ø"): -25,
                    ("K", "ù"): -20,
                    ("K", "ú"): -20,
                    ("K", "û"): -20,
                    ("K", "ü"): -20,
                    ("K", "ý"): -20,
                    ("K", "ÿ"): -20,
                    ("L", "T"): -18,
                    ("L", "V"): -37,
                    ("L", "W"): -37,
                    ("L", "Y"): -37,
                    ("L", "y"): -37,
                    ("L", "Ý"): -37,
                    ("L", "ý"): -37,
                    ("L", "ÿ"): -37,
                    ("L", "Ÿ"): -37,
                    ("L", "’"): -55,
                    ("N", "A"): -30,
                    ("N", "À"): -30,
                    ("N", "Á"): -30,
                    ("N", "Â"): -30,
                    ("N", "Ã"): -30,
                    ("N", "Ä"): -30,
                    ("N", "Å"): -30,
                    ("O", "A"): -40,
                    ("O", "T"): -40,
                    ("O", "V"): -50,
                    ("O", "W"): -50,
                    ("O", "X"): -40,
                    ("O", "Y"): -50,
                    ("O", "À"): -40,
                    ("O", "Á"): -40,
                    ("O", "Â"): -40,
                    ("O", "Ã"): -40,
                    ("O", "Ä"): -40,
                    ("O", "Å"): -40,
                    ("O", "Ý"): -50,
                    ("O", "Ÿ"): -50,
                    ("P", ","): -129,
                    ("P", "."): -129,
                    ("P", "A"): -85,
                    ("P", "a"): -40,
                    ("P", "e"): -50,
                    ("P", "o"): -55,
                    ("P", "À"): -85,
                    ("P", "Á"): -85,
                    ("P", "Â"): -85,
                    ("P", "Ã"): -85,
                    ("P", "Ä"): -85,
                    ("P", "Å"): -85,
                    ("P", "à"): -40,
                    ("P", "á"): -40,
                    ("P", "â"): -40,
                    ("P", "ã"): -40,
                    ("P", "ä"): -40,
                    ("P", "å"): -40,
                    ("P", "è"): -50,
                    ("P", "é"): -50,
                    ("P", "ê"): -50,
                    ("P", "ë"): -50,
                    ("P", "ò"): -55,
                    ("P", "ó"): -55,
                    ("P", "ô"): -55,
                    ("P", "õ"): -55,
                    ("P", "ö"): -55,
                    ("P", "ø"): -55,
                    ("Q", "U"): -10,
                    ("Q", "Ù"): -10,
                    ("Q", "Ú"): -10,
                    ("Q", "Û"): -10,
                    ("Q", "Ü"): -10,
                    ("R", "O"): -40,
                    ("R", "T"): -30,
                    ("R", "U"): -40,
                    ("R", "V"): -18,
                    ("R", "W"): -18,
                    ("R", "Y"): -18,
                    ("R", "Ò"): -40,
                    ("R", "Ó"): -40,
                    ("R", "Ô"): -40,
                    ("R", "Õ"): -40,
                    ("R", "Ö"): -40,
                    ("R", "Ø"): -40,
                    ("R", "Ù"): -40,
                    ("R", "Ú"): -40,
                    ("R", "Û"): -40,
                    ("R", "Ü"): -40,
                    ("R", "Ý"): -18,
                    ("R", "Ÿ"): -18,
                    ("T", ","): -92,
                    ("T", "-"): -92,
                    ("T", "."): -92,
                    ("T", ":"): -74,
                    ("T", ";"): -74,
                    ("T", "A"): -55,
                    ("T", "O"): -18,
                    ("T", "a"): -92,
                    ("T", "e"): -92,
                    ("T", "i"): -37,
                    ("T", "o"): -95,
                    ("T", "r"): -37,
                    ("T", "u"): -37,
                    ("T", "w"): -37,
                    ("T", "y"): -37,
                    ("T", "À"): -55,
                    ("T", "Á"): -55,
                    ("T", "Â"): -55,
                    ("T", "Ã"): -55,
                    ("T", "Ä"): -55,
                    ("T", "Å"): -55,
                    ("T", "Ò"): -18,
                    ("T", "Ó"): -18,
                    ("T", "Ô"): -18,
                    ("T", "Õ"): -18,
                    ("T", "Ö"): -18,
                    ("T", "Ø"): -18,
                    ("T", "à"): -92,
                    ("T", "á"): -92,
                    ("T", "â"): -92,
                    ("T", "ã"): -92,
                    ("T", "ä"): -92,
                    ("T", "å"): -92,
                    ("T", "è"): -52,
                    ("T", "é"): -92,
                    ("T", "ê"): -92,
                    ("T", "ë"): -52,
                    ("T", "í"): -37,
                    ("T", "ò"): -95,
                    ("T", "ó"): -95,
                    ("T", "ô"): -95,
                    ("T", "õ"): -95,
                    ("T", "ö"): -95,
                    ("T", "ø"): -95,
                    ("T", "ù"): -37,
                    ("T", "ú"): -37,
                    ("T", "û"): -37,
                    ("T", "ü"): -37,
                    ("T", "ý"): -37,
                    ("T", "ÿ"): -37,
                    ("U", "A"): -45,
                    ("U", "À"): -45,
                    ("U", "Á"): -45,
                    ("U", "Â"): -45,
                    ("U", "Ã"): -45,
                    ("U", "Ä"): -45,
                    ("U", "Å"): -45,
                    ("V", ","): -129,
                    ("V", "-"): -70,
                    ("V", "."): -129,
                    ("V", ":"): -74,
                    ("V", ";"): -74,
                    ("V", "A"): -85,
                    ("V", "G"): -10,
                    ("V", "O"): -30,
                    ("V", "a"): -111,
                    ("V", "e"): -111,
                    ("V", "i"): -55,
                    ("V", "o"): -111,
                    ("V", "u"): -55,
                    ("V", "À"): -85,
                    ("V", "Á"): -85,
                    ("V", "Â"): -85,
                    ("V", "Ã"): -85,
                    ("V", "Ä"): -85,
                    ("V", "Å"): -85,
                    ("V", "Ò"): -30,
                    ("V", "Ó"): -30,
                    ("V", "Ô"): -30,
                    ("V", "Õ"): -30,
                    ("V", "Ö"): -30,
                    ("V", "Ø"): -30,
                    ("V", "à"): -111,
                    ("V", "á"): -111,
                    ("V", "â"): -111,
                    ("V", "ã"): -111,
                    ("V", "ä"): -111,
                    ("V", "å"): -111,
                    ("V", "è"): -71,
                    ("V", "é"): -111,
                    ("V", "ê"): -111,
                    ("V", "ë"): -71,
                    ("V", "í"): -55,
                    ("V", "ò"): -111,
                    ("V", "ó"): -111,
                    ("V", "ô"): -111,
                    ("V", "õ"): -111,
                    ("V", "ö"): -111,
                    ("V", "ø"): -111,
                    ("V", "ù"): -55,
                    ("V", "ú"): -55,
                    ("V", "û"): -55,
                    ("V", "ü"): -55,
                    ("W", ","): -74,
                    ("W", "-"): -50,
                    ("W", "."): -74,
                    ("W", ":"): -55,
                    ("W", ";"): -55,
                    ("W", "A"): -74,
                    ("W", "O"): -15,
                    ("W", "a"): -85,
                    ("W", "e"): -90,
                    ("W", "i"): -37,
                    ("W", "o"): -80,
                    ("W", "u"): -55,
                    ("W", "y"): -55,
                    ("W", "À"): -74,
                    ("W", "Á"): -74,
                    ("W", "Â"): -74,
                    ("W", "Ã"): -74,
                    ("W", "Ä"): -74,
                    ("W", "Å"): -74,
                    ("W", "Ò"): -15,
                    ("W", "Ó"): -15,
                    ("W", "Ô"): -15,
                    ("W", "Õ"): -15,
                    ("W", "Ö"): -15,
                    ("W", "Ø"): -15,
                    ("W", "à"): -85,
                    ("W", "á"): -85,
                    ("W", "â"): -85,
                    ("W", "ã"): -85,
                    ("W", "ä"): -85,
                    ("W", "å"): -85,
                    ("W", "è"): -50,
                    ("W", "é"): -90,
                    ("W", "ê"): -90,
                    ("W", "ë"): -50,
                    ("W", "í"): -37,
                    ("W", "ò"): -80,
                    ("W", "ó"): -80,
                    ("W", "ô"): -80,
                    ("W", "õ"): -80,
                    ("W", "ö"): -80,
                    ("W", "ø"): -80,
                    ("W", "ù"): -55,
                    ("W", "ú"): -55,
                    ("W", "û"): -55,
                    ("W", "ü"): -55,
                    ("W", "ý"): -55,
                    ("W", "ÿ"): -55,
                    ("Y", ","): -92,
                    ("Y", "-"): -92,
                    ("Y", "."): -74,
                    ("Y", ":"): -92,
                    ("Y", ";"): -92,
                    ("Y", "A"): -74,
                    ("Y", "O"): -25,
                    ("Y", "a"): -92,
                    ("Y", "e"): -111,
                    ("Y", "i"): -55,
                    ("Y", "o"): -111,
                    ("Y", "u"): -92,
                    ("Y", "À"): -74,
                    ("Y", "Á"): -74,
                    ("Y", "Â"): -74,
                    ("Y", "Ã"): -74,
                    ("Y", "Ä"): -74,
                    ("Y", "Å"): -74,
                    ("Y", "Ò"): -25,
                    ("Y", "Ó"): -25,
                    ("Y", "Ô"): -25,
                    ("Y", "Õ"): -25,
                    ("Y", "Ö"): -25,
                    ("Y", "Ø"): -25,
                    ("Y", "à"): -92,
                    ("Y", "á"): -92,
                    ("Y", "â"): -92,
                    ("Y", "ã"): -92,
                    ("Y", "ä"): -92,
                    ("Y", "å"): -92,
                    ("Y", "è"): -71,
                    ("Y", "é"): -111,
                    ("Y", "ê"): -71,
                    ("Y", "ë"): -71,
                    ("Y", "í"): -55,
                    ("Y", "ò"): -111,
                    ("Y", "ó"): -111,
                    ("Y", "ô"): -111,
                    ("Y", "õ"): -111,
                    ("Y", "ö"): -111,
                    ("Y", "ø"): -111,
                    ("Y", "ù"): -92,
                    ("Y", "ú"): -92,
                    ("Y", "û"): -92,
                    ("Y", "ü"): -92,
                    ("b", "."): -40,
                    ("b", "b"): -10,
                    ("b", "u"): -20,
                    ("b", "ù"): -20,
                    ("b", "ú"): -20,
                    ("b", "û"): -20,
                    ("b", "ü"): -20,
                    ("c", "h"): -10,
                    ("c", "k"): -10,
                    ("e", "b"): -10,
                    ("f", ","): -10,
                    ("f", "."): -10,
                    ("f", "e"): -10,
                    ("f", "f"): -18,
                    ("f", "o"): -10,
                    ("f", "é"): -10,
                    ("f", "ò"): -10,
                    ("f", "ó"): -10,
                    ("f", "ô"): -10,
                    ("f", "õ"): -10,
                    ("f", "ø"): -10,
                    ("f", "ı"): -30,
                    ("f", "’"): 55,
                    ("k", "e"): -30,
                    ("k", "o"): -10,
                    ("k", "è"): -30,
                    ("k", "é"): -30,
                    ("k", "ê"): -30,
                    ("k", "ë"): -30,
                    ("k", "ò"): -10,
                    ("k", "ó"): -10,
                    ("k", "ô"): -10,
                    ("k", "õ"): -10,
                    ("k", "ö"): -10,
                    ("k", "ø"): -10,
                    ("n", "v"): -40,
                    ("o", "v"): -15,
                    ("o", "w"): -25,
                    ("o", "x"): -10,
                    ("o", "y"): -10,
                    ("o", "ý"): -10,
                    ("o", "ÿ"): -10,
                    ("r", ","): -65,
                    ("r", "."): -65,
                    ("v", ","): -37,
                    ("v", "."): -37,
                    ("v", "e"): -15,
                    ("v", "o"): -15,
                    ("v", "è"): -15,
                    ("v", "é"): -15,
                    ("v", "ê"): -15,
                    ("v", "ë"): -15,
                    ("v", "ò"): -15,
                    ("v", "ó"): -15,
                    ("v", "ô"): -15,
                    ("v", "õ"): -15,
                    ("v", "ö"): -15,
                    ("v", "ø"): -15,
                    ("w", ","): -37,
                    ("w", "."): -37,
                    ("w", "a"): -10,
                    ("w", "e"): -10,
                    ("w", "o"): -15,
                    ("w", "à"): -10,
                    ("w", "á"): -10,
                    ("w", "â"): -10,
                    ("w", "ã"): -10,
                    ("w", "ä"): -10,
                    ("w", "å"): -10,
                    ("w", "è"): -10,
                    ("w", "é"): -10,
                    ("w", "ê"): -10,
                    ("w", "ë"): -10,
                    ("w", "ò"): -15,
                    ("w", "ó"): -15,
                    ("w", "ô"): -15,
                    ("w", "õ"): -15,
                    ("w", "ö"): -15,
                    ("w", "ø"): -15,
                    ("x", "e"): -10,
                    ("x", "è"): -10,
                    ("x", "é"): -10,
                    ("x", "ê"): -10,
                    ("x", "ë"): -10,
                    ("y", ","): -37,
                    ("y", "."): -37,
                    ("À", "C"): -65,
                    ("À", "G"): -60,
                    ("À", "O"): -50,
                    ("À", "Q"): -55,
                    ("À", "T"): -55,
                    ("À", "U"): -50,
                    ("À", "V"): -95,
                    ("À", "W"): -100,
                    ("À", "Y"): -70,
                    ("À", "u"): -30,
                    ("À", "v"): -74,
                    ("À", "w"): -74,
                    ("À", "y"): -74,
                    ("À", "Ç"): -65,
                    ("À", "Ò"): -50,
                    ("À", "Ó"): -50,
                    ("À", "Ô"): -50,
                    ("À", "Õ"): -50,
                    ("À", "Ö"): -50,
                    ("À", "Ø"): -50,
                    ("À", "Ù"): -50,
                    ("À", "Ú"): -50,
                    ("À", "Û"): -50,
                    ("À", "Ü"): -50,
                    ("À", "Ý"): -70,
                    ("À", "ù"): -30,
                    ("À", "ú"): -30,
                    ("À", "û"): -30,
                    ("À", "ü"): -30,
                    ("À", "ý"): -74,
                    ("À", "ÿ"): -74,
                    ("À", "Ÿ"): -70,
                    ("À", "’"): -74,
                    ("Á", "C"): -65,
                    ("Á", "G"): -60,
                    ("Á", "O"): -50,
                    ("Á", "Q"): -55,
                    ("Á", "T"): -55,
                    ("Á", "U"): -50,
                    ("Á", "V"): -95,
                    ("Á", "W"): -100,
                    ("Á", "Y"): -70,
                    ("Á", "u"): -30,
                    ("Á", "v"): -74,
                    ("Á", "w"): -74,
                    ("Á", "y"): -74,
                    ("Á", "Ç"): -65,
                    ("Á", "Ò"): -50,
                    ("Á", "Ó"): -50,
                    ("Á", "Ô"): -50,
                    ("Á", "Õ"): -50,
                    ("Á", "Ö"): -50,
                    ("Á", "Ø"): -50,
                    ("Á", "Ù"): -50,
                    ("Á", "Ú"): -50,
                    ("Á", "Û"): -50,
                    ("Á", "Ü"): -50,
                    ("Á", "Ý"): -70,
                    ("Á", "ù"): -30,
                    ("Á", "ú"): -30,
                    ("Á", "û"): -30,
                    ("Á", "ü"): -30,
                    ("Á", "ý"): -74,
                    ("Á", "ÿ"): -74,
                    ("Á", "Ÿ"): -70,
                    ("Á", "’"): -74,
                    ("Â", "C"): -65,
                    ("Â", "G"): -60,
                    ("Â", "O"): -50,
                    ("Â", "Q"): -55,
                    ("Â", "T"): -55,
                    ("Â", "U"): -50,
                    ("Â", "V"): -95,
                    ("Â", "W"): -100,
                    ("Â", "Y"): -70,
                    ("Â", "u"): -30,
                    ("Â", "v"): -74,
                    ("Â", "w"): -74,
                    ("Â", "y"): -74,
                    ("Â", "Ç"): -65,
                    ("Â", "Ò"): -50,
                    ("Â", "Ó"): -50,
                    ("Â", "Ô"): -50,
                    ("Â", "Õ"): -50,
                    ("Â", "Ö"): -50,
                    ("Â", "Ø"): -50,
                    ("Â", "Ù"): -50,
                    ("Â", "Ú"): -50,
                    ("Â", "Û"): -50,
                    ("Â", "Ü"): -50,
                    ("Â", "Ý"): -70,
                    ("Â", "ù"): -30,
                    ("Â", "ú"): -30,
                    ("Â", "û"): -30,
                    ("Â", "ü"): -30,
                    ("Â", "ý"): -74,
                    ("Â", "ÿ"): -74,
                    ("Â", "Ÿ"): -70,
                    ("Â", "’"): -74,
                    ("Ã", "C"): -65,
                    ("Ã", "G"): -60,
                    ("Ã", "O"): -50,
                    ("Ã", "Q"): -55,
                    ("Ã", "T"): -55,
                    ("Ã", "U"): -50,
                    ("Ã", "V"): -95,
                    ("Ã", "W"): -100,
                    ("Ã", "Y"): -70,
                    ("Ã", "u"): -30,
                    ("Ã", "v"): -74,
                    ("Ã", "w"): -74,
                    ("Ã", "y"): -74,
                    ("Ã", "Ç"): -65,
                    ("Ã", "Ò"): -50,
                    ("Ã", "Ó"): -50,
                    ("Ã", "Ô"): -50,
                    ("Ã", "Õ"): -50,
                    ("Ã", "Ö"): -50,
                    ("Ã", "Ø"): -50,
                    ("Ã", "Ù"): -50,
                    ("Ã", "Ú"): -50,
                    ("Ã", "Û"): -50,
                    ("Ã", "Ü"): -50,
                    ("Ã", "Ý"): -70,
                    ("Ã", "ù"): -30,
                    ("Ã", "ú"): -30,
                    ("Ã", "û"): -30,
                    ("Ã", "ü"): -30,
                    ("Ã", "ý"): -74,
                    ("Ã", "ÿ"): -74,
                    ("Ã", "Ÿ"): -70,
                    ("Ã", "’"): -74,
                    ("Ä", "C"): -65,
                    ("Ä", "G"): -60,
                    ("Ä", "O"): -50,
                    ("Ä", "Q"): -55,
                    ("Ä", "T"): -55,
                    ("Ä", "U"): -50,
                    ("Ä", "V"): -95,
                    ("Ä", "W"): -100,
                    ("Ä", "Y"): -70,
                    ("Ä", "u"): -30,
                    ("Ä", "v"): -74,
                    ("Ä", "w"): -74,
                    ("Ä", "y"): -74,
                    ("Ä", "Ç"): -65,
                    ("Ä", "Ò"): -50,
                    ("Ä", "Ó"): -50,
                    ("Ä", "Ô"): -50,
                    ("Ä", "Õ"): -50,
                    ("Ä", "Ö"): -50,
                    ("Ä", "Ø"): -50,
                    ("Ä", "Ù"): -50,
                    ("Ä", "Ú"): -50,
                    ("Ä", "Û"): -50,
                    ("Ä", "Ü"): -50,
                    ("Ä", "Ý"): -70,
                    ("Ä", "ù"): -30,
                    ("Ä", "ú"): -30,
                    ("Ä", "û"): -30,
                    ("Ä", "ü"): -30,
                    ("Ä", "ý"): -74,
                    ("Ä", "ÿ"): -74,
                    ("Ä", "Ÿ"): -70,
                    ("Ä", "’"): -74,
                    ("Å", "C"): -65,
                    ("Å", "G"): -60,
                    ("Å", "O"): -50,
                    ("Å", "Q"): -55,
                    ("Å", "T"): -55,
                    ("Å", "U"): -50,
                    ("Å", "V"): -95,
                    ("Å", "W"): -100,
                    ("Å", "Y"): -70,
                    ("Å", "u"): -30,
                    ("Å", "v"): -74,
                    ("Å", "w"): -74,
                    ("Å", "y"): -74,
                    ("Å", "Ç"): -65,
                    ("Å", "Ò"): -50,
                    ("Å", "Ó"): -50,
                    ("Å", "Ô"): -50,
                    ("Å", "Õ"): -50,
                    ("Å", "Ö"): -50,
                    ("Å", "Ø"): -50,
                    ("Å", "Ù"): -50,
                    ("Å", "Ú"): -50,
                    ("Å", "Û"): -50,
                    ("Å", "Ü"): -50,
                    ("Å", "Ý"): -70,
                    ("Å", "ù"): -30,
                    ("Å", "ú"): -30,
                    ("Å", "û"): -30,
                    ("Å", "ü"): -30,
                    ("Å", "ý"): -74,
                    ("Å", "ÿ"): -74,
                    ("Å", "Ÿ"): -70,
                    ("Å", "’"): -74,
                    ("Ñ", "A"): -30,
                    ("Ñ", "À"): -30,
                    ("Ñ", "Á"): -30,
                    ("Ñ", "Â"): -30,
                    ("Ñ", "Ã"): -30,
                    ("Ñ", "Ä"): -30,
                    ("Ñ", "Å"): -30,
                    ("Ò", "A"): -40,
                    ("Ò", "T"): -40,
                    ("Ò", "V"): -50,
                    ("Ò", "W"): -50,
                    ("Ò", "X"): -40,
                    ("Ò", "Y"): -50,
                    ("Ò", "À"): -40,
                    ("Ò", "Á"): -40,
                    ("Ò", "Â"): -40,
                    ("Ò", "Ã"): -40,
                    ("Ò", "Ä"): -40,
                    ("Ò", "Å"): -40,
                    ("Ò", "Ý"): -50,
                    ("Ò", "Ÿ"): -50,
                    ("Ó", "A"): -40,
                    ("Ó", "T"): -40,
                    ("Ó", "V"): -50,
                    ("Ó", "W"): -50,
                    ("Ó", "X"): -40,
                    ("Ó", "Y"): -50,
                    ("Ó", "À"): -40,
                    ("Ó", "Á"): -40,
                    ("Ó", "Â"): -40,
                    ("Ó", "Ã"): -40,
                    ("Ó", "Ä"): -40,
                    ("Ó", "Å"): -40,
                    ("Ó", "Ý"): -50,
                    ("Ó", "Ÿ"): -50,
                    ("Ô", "A"): -40,
                    ("Ô", "T"): -40,
                    ("Ô", "V"): -50,
                    ("Ô", "W"): -50,
                    ("Ô", "X"): -40,
                    ("Ô", "Y"): -50,
                    ("Ô", "À"): -40,
                    ("Ô", "Á"): -40,
                    ("Ô", "Â"): -40,
                    ("Ô", "Ã"): -40,
                    ("Ô", "Ä"): -40,
                    ("Ô", "Å"): -40,
                    ("Ô", "Ý"): -50,
                    ("Ô", "Ÿ"): -50,
                    ("Õ", "A"): -40,
                    ("Õ", "T"): -40,
                    ("Õ", "V"): -50,
                    ("Õ", "W"): -50,
                    ("Õ", "X"): -40,
                    ("Õ", "Y"): -50,
                    ("Õ", "À"): -40,
                    ("Õ", "Á"): -40,
                    ("Õ", "Â"): -40,
                    ("Õ", "Ã"): -40,
                    ("Õ", "Ä"): -40,
                    ("Õ", "Å"): -40,
                    ("Õ", "Ý"): -50,
                    ("Õ", "Ÿ"): -50,
                    ("Ö", "A"): -40,
                    ("Ö", "T"): -40,
                    ("Ö", "V"): -50,
                    ("Ö", "W"): -50,
                    ("Ö", "X"): -40,
                    ("Ö", "Y"): -50,
                    ("Ö", "À"): -40,
                    ("Ö", "Á"): -40,
                    ("Ö", "Â"): -40,
                    ("Ö", "Ã"): -40,
                    ("Ö", "Ä"): -40,
                    ("Ö", "Å"): -40,
                    ("Ö", "Ý"): -50,
                    ("Ö", "Ÿ"): -50,
                    ("Ø", "A"): -40,
                    ("Ø", "T"): -40,
                    ("Ø", "V"): -50,
                    ("Ø", "W"): -50,
                    ("Ø", "X"): -40,
                    ("Ø", "Y"): -50,
                    ("Ø", "À"): -40,
                    ("Ø", "Á"): -40,
                    ("Ø", "Â"): -40,
                    ("Ø", "Ã"): -40,
                    ("Ø", "Ä"): -40,
                    ("Ø", "Å"): -40,
                    ("Ø", "Ý"): -50,
                    ("Ø", "Ÿ"): -50,
                    ("Ù", "A"): -45,
                    ("Ù", "À"): -45,
                    ("Ù", "Á"): -45,
                    ("Ù", "Â"): -45,
                    ("Ù", "Ã"): -45,
                    ("Ù", "Ä"): -45,
                    ("Ù", "Å"): -45,
                    ("Ú", "A"): -45,
                    ("Ú", "À"): -45,
                    ("Ú", "Á"): -45,
                    ("Ú", "Â"): -45,
                    ("Ú", "Ã"): -45,
                    ("Ú", "Ä"): -45,
                    ("Ú", "Å"): -45,
                    ("Û", "A"): -45,
                    ("Û", "À"): -45,
                    ("Û", "Á"): -45,
                    ("Û", "Â"): -45,
                    ("Û", "Ã"): -45,
                    ("Û", "Ä"): -45,
                    ("Û", "Å"): -45,
                    ("Ü", "A"): -45,
                    ("Ü", "À"): -45,
                    ("Ü", "Á"): -45,
                    ("Ü", "Â"): -45,
                    ("Ü", "Ã"): -45,
                    ("Ü", "Ä"): -45,
                    ("Ü", "Å"): -45,
                    ("Ý", ","): -92,
                    ("Ý", "-"): -92,
                    ("Ý", "."): -74,
                    ("Ý", ":"): -92,
                    ("Ý", ";"): -92,
                    ("Ý", "A"): -74,
                    ("Ý", "O"): -25,
                    ("Ý", "a"): -92,
                    ("Ý", "e"): -111,
                    ("Ý", "i"): -55,
                    ("Ý", "o"): -111,
                    ("Ý", "u"): -92,
                    ("Ý", "À"): -74,
                    ("Ý", "Á"): -74,
                    ("Ý", "Â"): -74,
                    ("Ý", "Ã"): -74,
                    ("Ý", "Ä"): -74,
                    ("Ý", "Å"): -74,
                    ("Ý", "Ò"): -25,
                    ("Ý", "Ó"): -25,
                    ("Ý", "Ô"): -25,
                    ("Ý", "Õ"): -25,
                    ("Ý", "Ö"): -25,
                    ("Ý", "Ø"): -25,
                    ("Ý", "à"): -92,
                    ("Ý", "á"): -92,
                    ("Ý", "â"): -92,
                    ("Ý", "ã"): -92,
                    ("Ý", "ä"): -92,
                    ("Ý", "å"): -92,
                    ("Ý", "è"): -71,
                    ("Ý", "é"): -111,
                    ("Ý", "ê"): -71,
                    ("Ý", "ë"): -71,
                    ("Ý", "í"): -55,
                    ("Ý", "ò"): -111,
                    ("Ý", "ó"): -111,
                    ("Ý", "ô"): -111,
                    ("Ý", "õ"): -111,
                    ("Ý", "ö"): -111,
                    ("Ý", "ø"): -111,
                    ("Ý", "ù"): -92,
                    ("Ý", "ú"): -92,
                    ("Ý", "û"): -92,
                    ("Ý", "ü"): -92,
                    ("ç", "h"): -10,
                    ("ç", "k"): -10,
                    ("è", "b"): -10,
                    ("é", "b"): -10,
                    ("ê", "b"): -10,
                    ("ë", "b"): -10,
                    ("ñ", "v"): -40,
                    ("ò", "v"): -15,
                    ("ò", "w"): -25,
                    ("ò", "x"): -10,
                    ("ò", "y"): -10,
                    ("ò", "ý"): -10,
                    ("ò", "ÿ"): -10,
                    ("ó", "v"): -15,
                    ("ó", "w"): -25,
                    ("ó", "x"): -10,
                    ("ó", "y"): -10,
                    ("ó", "ý"): -10,
                    ("ó", "ÿ"): -10,
                    ("ô", "v"): -15,
                    ("ô", "w"): -25,
                    ("ô", "x"): -10,
                    ("ô", "y"): -10,
                    ("ô", "ý"): -10,
                    ("ô", "ÿ"): -10,
                    ("õ", "v"): -15,
                    ("õ", "w"): -25,
                    ("õ", "x"): -10,
                    ("õ", "y"): -10,
                    ("õ", "ý"): -10,
                    ("õ", "ÿ"): -10,
                    ("ö", "v"): -15,
                    ("ö", "w"): -25,
                    ("ö", "x"): -10,
                    ("ö", "y"): -10,
                    ("ö", "ý"): -10,
                    ("ö", "ÿ"): -10,
                    ("ø", "v"): -15,
                    ("ø", "w"): -25,
                    ("ø", "x"): -10,
                    ("ø", "y"): -10,
                    ("ø", "ý"): -10,
                    ("ø", "ÿ"): -10,
                    ("ý", ","): -37,
                    ("ý", "."): -37,
                    ("ÿ", ","): -37,
                    ("ÿ", "."): -37,
                    ("Ł", "T"): -18,
                    ("Ł", "V"): -37,
                    ("Ł", "W"): -37,
                    ("Ł", "Y"): -37,
                    ("Ł", "y"): -37,
                    ("Ł", "Ý"): -37,
                    ("Ł", "ý"): -37,
                    ("Ł", "ÿ"): -37,
                    ("Ł", "Ÿ"): -37,
                    ("Ł", "’"): -55,
                    ("Ÿ", ","): -92,
                    ("Ÿ", "-"): -92,
                    ("Ÿ", "."): -74,
                    ("Ÿ", ":"): -92,
                    ("Ÿ", ";"): -92,
                    ("Ÿ", "A"): -74,
                    ("Ÿ", "O"): -25,
                    ("Ÿ", "a"): -92,
                    ("Ÿ", "e"): -111,
                    ("Ÿ", "i"): -55,
                    ("Ÿ", "o"): -111,
                    ("Ÿ", "u"): -92,
                    ("Ÿ", "À"): -74,
                    ("Ÿ", "Á"): -74,
                    ("Ÿ", "Â"): -74,
                    ("Ÿ", "Ã"): -74,
                    ("Ÿ", "Ä"): -74,
                    ("Ÿ", "Å"): -74,
                    ("Ÿ", "Ò"): -25,
                    ("Ÿ", "Ó"): -25,
                    ("Ÿ", "Ô"): -25,
                    ("Ÿ", "Õ"): -25,
                    ("Ÿ", "Ö"): -25,
                    ("Ÿ", "Ø"): -25,
                    ("Ÿ", "à"): -92,
                    ("Ÿ", "á"): -92,
                    ("Ÿ", "â"): -92,
                    ("Ÿ", "ã"): -92,
                    ("Ÿ", "ä"): -92,
                    ("Ÿ", "å"): -92,
                    ("Ÿ", "è"): -71,
                    ("Ÿ", "é"): -111,
                    ("Ÿ", "ê"): -71,
                    ("Ÿ", "ë"): -71,
                    ("Ÿ", "í"): -55,
                    ("Ÿ", "ò"): -111,
                    ("Ÿ", "ó"): -111,
                    ("Ÿ", "ô"): -111,
                    ("Ÿ", "õ"): -111,
                    ("Ÿ", "ö"): -111,
                    ("Ÿ", "ø"): -111,
                    ("Ÿ", "ù"): -92,
                    ("Ÿ", "ú"): -92,
                    ("Ÿ", "û"): -92,
                    ("Ÿ", "ü"): -92,
                    ("‘", "‘"): -74,
                    ("’", " "): -74,
                    ("’", "d"): -15,
                    ("’", "r"): -15,
                    ("’", "s"): -74,
                    ("’", "t"): -37,
                    ("’", "v"): -15,
                    ("’", "š"): -74,
                    ("’", "’"): -74,
                },
                0,
            ),
        ),
    )
    courier = BuiltinTypeface(
        BuiltinFont(b"Courier", b"f8", always(600), None),
        BuiltinFont(b"Courier-Bold", b"f9", always(600), None),
        BuiltinFont(b"Courier-Oblique", b"f10", always(600), None),
        BuiltinFont(b"Courier-BoldOblique", b"f11", always(600), None),
    )

    # FUTURE: actual widths
    symbol = BuiltinTypeface(
        BuiltinFont(b"Symbol", b"f12", always(1000), None),
        BuiltinFont(b"Symbol", b"f12", always(1000), None),
        BuiltinFont(b"Symbol", b"f12", always(1000), None),
        BuiltinFont(b"Symbol", b"f12", always(1000), None),
    )  # pragma: no cover
    zapf_dingbats = BuiltinTypeface(  # pragma: no cover
        BuiltinFont(b"ZapfDingbats", b"f13", always(1000), None),
        BuiltinFont(b"ZapfDingbats", b"f13", always(1000), None),
        BuiltinFont(b"ZapfDingbats", b"f13", always(1000), None),
        BuiltinFont(b"ZapfDingbats", b"f13", always(1000), None),
    )

BY_NAME: Mapping[ASCII, BuiltinTypeface] = {
    f.regular.name: f
    for f in (
        helvetica,
        times_roman,
        courier,
        symbol,
        zapf_dingbats,
    )
}
